(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    329177,       8117]*)
(*NotebookOutlinePosition[    329819,       8139]*)
(*  CellTagsIndexPosition[    329775,       8135]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Creating Synthetic Data Sets", "Section"],

Cell[BoxData[{
    \(<< Statistics`LinearRegression`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\)}], "Input"],

Cell[TextData[{
  "Many times in modeling, we need to simulate data sets. This can happen for \
a variety of reasons. We may have a proprietory data set, and we need to \
create a data set with the same properties of this data set that can be \
realeased to the public. You can see this if you read the",
  ButtonBox[" information for authors",
    ButtonData:>{
      URL[ "http://www.cs.ualberta.ca/~holte/mlj/info-for-authors.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " for The Machine Learning Journal. Proprietory data sets could contain \
information about a product that is not public, military information, or \
personal information. Even if your data set is not proprietory, you may want \
to create a group of data sets which have similar properties for use in the \
classroom.\n\nAlso, using simulated data sets gives you some method of \
estimating the errors in the parameters in your model directly. \n\nBesides \
which, it is fun."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
The True Reality Underlying Function: Mother Nature's True Function\
\>", "Subsubsection"],

Cell["\<\
Underlying the model, there is Mother Nature's True Function, the function \
that is guiding the creation of the data set you measure. Of course, random \
errors, measuring inaccuracies, and (hopefully not large) systematic errors \
make it impossible for you to realize Mother Nature's True Function \
exactly.\
\>", "Text"],

Cell[TextData[{
  "For example, say some physical process results in a linear relation \
between ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". The\nparameters in the relation, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\ and\ b\)\(,\)\)\)]],
  " are Mother Nature's True Parameters. For our discussion, we will say that \
the following function is Mother Nature's True Function, and Mother Nature's \
True Parameters are",
  StyleBox[" precisely",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(3.45\ and\ b = 0.067\)\)]],
  ". There is absolutely no error in Mother Nature's True Parameters."
}], "Text"],

Cell[BoxData[{
    \(\(a\  = \ 3.45;\)\), "\[IndentingNewLine]", 
    \(\(b = 0.067;\)\), "\[IndentingNewLine]", 
    \(\(ftrue[t_]\  = \ a\  + \ b\ t;\)\)}], "Input"],

Cell[TextData[{
  "Without the error that intrudes on any experiment, if we measured the \
system at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 8\)]],
  ", we would expect our measurement to be exactly 3.986."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ftrue[8]\)], "Input"],

Cell[BoxData[
    \(3.986`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Experimental Measurement of the System", "Subsubsection"],

Cell[TextData[{
  "You will forgive me if I don't conduct an experiment to get the data; \
instead, I will pretend that this first initial run is me doing some \
experiement or collecting some data from somewhere which forms my data set. \
The ",
  Cell[BoxData[
      \(TraditionalForm\`data0\)]],
  " represents, for us, the actual data set you have. The Random call \
represents the experimental error that is introduced when the experiment is \
performed. The SeedRandom makes sure that I get the same random number \
sequence each time I evaluate the cell."
}], "Text"],

Cell[TextData[{
  "Below, I create the experimental realization of Mother Nature's True \
Function, by collecting data and fitting (using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Fit, now that we know what it means) a linear equation to the data."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeedRandom[4];\)\), "\[IndentingNewLine]", 
    \(Clear[data0]\), "\[IndentingNewLine]", 
    \(\(data0\  = \ 
        Table[{t, ftrue[t] + Random[Real, {\(-2\), 2}]}, {t, 1, 
            200}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(f[t_]\  = Fit[data0, {1, t}, t]\), "\[IndentingNewLine]", 
    \(Regress[data0, {1, t}, t, 
      RegressionReport \[Rule] {RSquared, 
          EstimatedVariance}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(dataplot\  = \ 
        ListPlot[data0, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(modelplot\  = \ 
        Plot[f[t], {t, 0, 200}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(Show[dataplot, modelplot, 
      DisplayFunction \[Rule] $DisplayFunction]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(\(3.5879843020554905`\)\(\[InvisibleSpace]\)\) + 
      0.06622250707981435`\ t\)], "Output"],

Cell[BoxData[
    \({RSquared \[Rule] 0.909450774317366`, 
      EstimatedVariance \[Rule] 1.4701087884964261`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.0336268 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .09878 -18 -4.5 ]
[.01131 .09878 0 4.5 ]
[.01131 .18285 -6 -4.5 ]
[.01131 .18285 0 4.5 ]
[.01131 .26692 -18 -4.5 ]
[.01131 .26692 0 4.5 ]
[.01131 .35098 -12 -4.5 ]
[.01131 .35098 0 4.5 ]
[.01131 .43505 -24 -4.5 ]
[.01131 .43505 0 4.5 ]
[.01131 .51912 -12 -4.5 ]
[.01131 .51912 0 4.5 ]
[.01131 .60318 -24 -4.5 ]
[.01131 .60318 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09878 m
.03006 .09878 L
s
[(2.5)] .01131 .09878 1 0 Mshowa
.02381 .18285 m
.03006 .18285 L
s
[(5)] .01131 .18285 1 0 Mshowa
.02381 .26692 m
.03006 .26692 L
s
[(7.5)] .01131 .26692 1 0 Mshowa
.02381 .35098 m
.03006 .35098 L
s
[(10)] .01131 .35098 1 0 Mshowa
.02381 .43505 m
.03006 .43505 L
s
[(12.5)] .01131 .43505 1 0 Mshowa
.02381 .51912 m
.03006 .51912 L
s
[(15)] .01131 .51912 1 0 Mshowa
.02381 .60318 m
.03006 .60318 L
s
[(17.5)] .01131 .60318 1 0 Mshowa
.125 Mabswid
.02381 .03153 m
.02756 .03153 L
s
.02381 .04834 m
.02756 .04834 L
s
.02381 .06516 m
.02756 .06516 L
s
.02381 .08197 m
.02756 .08197 L
s
.02381 .1156 m
.02756 .1156 L
s
.02381 .13241 m
.02756 .13241 L
s
.02381 .14922 m
.02756 .14922 L
s
.02381 .16604 m
.02756 .16604 L
s
.02381 .19966 m
.02756 .19966 L
s
.02381 .21648 m
.02756 .21648 L
s
.02381 .23329 m
.02756 .23329 L
s
.02381 .2501 m
.02756 .2501 L
s
.02381 .28373 m
.02756 .28373 L
s
.02381 .30054 m
.02756 .30054 L
s
.02381 .31736 m
.02756 .31736 L
s
.02381 .33417 m
.02756 .33417 L
s
.02381 .3678 m
.02756 .3678 L
s
.02381 .38461 m
.02756 .38461 L
s
.02381 .40142 m
.02756 .40142 L
s
.02381 .41824 m
.02756 .41824 L
s
.02381 .45186 m
.02756 .45186 L
s
.02381 .46868 m
.02756 .46868 L
s
.02381 .48549 m
.02756 .48549 L
s
.02381 .5023 m
.02756 .5023 L
s
.02381 .53593 m
.02756 .53593 L
s
.02381 .55274 m
.02756 .55274 L
s
.02381 .56956 m
.02756 .56956 L
s
.02381 .58637 m
.02756 .58637 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .15614 Mdot
.03333 .11926 Mdot
.0381 .15955 Mdot
.04286 .18121 Mdot
.04762 .16181 Mdot
.05238 .09707 Mdot
.05714 .15334 Mdot
.0619 .2031 Mdot
.06667 .21702 Mdot
.07143 .17916 Mdot
.07619 .13598 Mdot
.08095 .09281 Mdot
.08571 .2023 Mdot
.09048 .13681 Mdot
.09524 .22633 Mdot
.1 .22861 Mdot
.10476 .22831 Mdot
.10952 .15575 Mdot
.11429 .17578 Mdot
.11905 .21839 Mdot
.12381 .16501 Mdot
.12857 .18619 Mdot
.13333 .14938 Mdot
.1381 .20223 Mdot
.14286 .21811 Mdot
.14762 .14392 Mdot
.15238 .20359 Mdot
.15714 .23702 Mdot
.1619 .14004 Mdot
.16667 .13285 Mdot
.17143 .1385 Mdot
.17619 .25894 Mdot
.18095 .1503 Mdot
.18571 .18322 Mdot
.19048 .2343 Mdot
.19524 .26566 Mdot
.2 .18428 Mdot
.20476 .15044 Mdot
.20952 .24876 Mdot
.21429 .28009 Mdot
.21905 .20127 Mdot
.22381 .24224 Mdot
.22857 .18828 Mdot
.23333 .17925 Mdot
.2381 .29057 Mdot
.24286 .1781 Mdot
.24762 .29771 Mdot
.25238 .23809 Mdot
.25714 .20128 Mdot
.2619 .29975 Mdot
.26667 .22744 Mdot
.27143 .27114 Mdot
.27619 .19905 Mdot
.28095 .30697 Mdot
.28571 .23127 Mdot
.29048 .29128 Mdot
.29524 .19559 Mdot
.3 .27284 Mdot
.30476 .28281 Mdot
.30952 .31373 Mdot
.31429 .30166 Mdot
.31905 .2805 Mdot
.32381 .32891 Mdot
.32857 .33075 Mdot
.33333 .26525 Mdot
.3381 .33988 Mdot
.34286 .30999 Mdot
.34762 .32312 Mdot
.35238 .28305 Mdot
.35714 .33791 Mdot
.3619 .32517 Mdot
.36667 .26567 Mdot
.37143 .26466 Mdot
.37619 .3578 Mdot
.38095 .28511 Mdot
.38571 .31868 Mdot
.39048 .2575 Mdot
.39524 .24498 Mdot
.4 .25025 Mdot
.40476 .36055 Mdot
.40952 .26282 Mdot
.41429 .30981 Mdot
.41905 .30735 Mdot
.42381 .25449 Mdot
.42857 .30559 Mdot
.43333 .37599 Mdot
.4381 .32738 Mdot
.44286 .27492 Mdot
.44762 .39378 Mdot
.45238 .3918 Mdot
.45714 .37533 Mdot
.4619 .312 Mdot
.46667 .33867 Mdot
.47143 .28409 Mdot
.47619 .28261 Mdot
.48095 .28103 Mdot
.48571 .31097 Mdot
.49048 .3 Mdot
.49524 .37347 Mdot
.5 .34058 Mdot
.50476 .29943 Mdot
.50952 .30324 Mdot
.51429 .37369 Mdot
.51905 .36725 Mdot
.52381 .4261 Mdot
.52857 .38517 Mdot
.53333 .32582 Mdot
.5381 .3745 Mdot
.54286 .3845 Mdot
.54762 .40992 Mdot
.55238 .40145 Mdot
.55714 .37033 Mdot
.5619 .39823 Mdot
.56667 .42788 Mdot
.57143 .43814 Mdot
.57619 .33809 Mdot
.58095 .34157 Mdot
.58571 .42806 Mdot
.59048 .44204 Mdot
.59524 .34583 Mdot
.6 .45614 Mdot
.60476 .42134 Mdot
.60952 .36411 Mdot
.61429 .43755 Mdot
.61905 .45675 Mdot
.62381 .42039 Mdot
.62857 .42947 Mdot
.63333 .37709 Mdot
.6381 .47421 Mdot
.64286 .48104 Mdot
.64762 .4172 Mdot
.65238 .45291 Mdot
.65714 .40778 Mdot
.6619 .39143 Mdot
.66667 .47283 Mdot
.67143 .4074 Mdot
.67619 .47113 Mdot
.68095 .42738 Mdot
.68571 .50078 Mdot
.69048 .40314 Mdot
.69524 .46565 Mdot
.7 .47217 Mdot
.70476 .39933 Mdot
.70952 .40016 Mdot
.71429 .48911 Mdot
.71905 .39818 Mdot
.72381 .51933 Mdot
.72857 .44897 Mdot
.73333 .52098 Mdot
.7381 .46866 Mdot
.74286 .44848 Mdot
.74762 .43275 Mdot
.75238 .40989 Mdot
.75714 .48751 Mdot
.7619 .53341 Mdot
.76667 .48423 Mdot
.77143 .50876 Mdot
.77619 .47047 Mdot
.78095 .43722 Mdot
.78571 .45572 Mdot
.79048 .55328 Mdot
.79524 .56099 Mdot
.8 .45661 Mdot
.80476 .44048 Mdot
.80952 .47779 Mdot
.81429 .48124 Mdot
.81905 .45194 Mdot
.82381 .57175 Mdot
.82857 .52235 Mdot
.83333 .48448 Mdot
.8381 .4708 Mdot
.84286 .52871 Mdot
.84762 .54406 Mdot
.85238 .56076 Mdot
.85714 .56952 Mdot
.8619 .5109 Mdot
.86667 .55136 Mdot
.87143 .4927 Mdot
.87619 .59231 Mdot
.88095 .58514 Mdot
.88571 .60332 Mdot
.89048 .5852 Mdot
.89524 .5858 Mdot
.9 .56238 Mdot
.90476 .48526 Mdot
.90952 .59619 Mdot
.91429 .56892 Mdot
.91905 .56388 Mdot
.92381 .58621 Mdot
.92857 .56144 Mdot
.93333 .56572 Mdot
.9381 .57763 Mdot
.94286 .5171 Mdot
.94762 .53245 Mdot
.95238 .55267 Mdot
.95714 .50892 Mdot
.9619 .5698 Mdot
.96667 .57071 Mdot
.97143 .58442 Mdot
.97619 .60154 Mdot
.5 Mabswid
.02381 .13537 m
.06244 .15344 L
.10458 .17314 L
.14415 .19164 L
.18221 .20944 L
.22272 .22838 L
.26171 .24662 L
.30316 .266 L
.34309 .28467 L
.3815 .30264 L
.42237 .32175 L
.46172 .34015 L
.49955 .35784 L
.53984 .37668 L
.57861 .39481 L
.61984 .41409 L
.65954 .43266 L
.69774 .45052 L
.73838 .46953 L
.77751 .48783 L
.81909 .50727 L
.85916 .52601 L
.89771 .54404 L
.93871 .56321 L
.97619 .58074 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00E@3oool2000000@0oooo0P00000c0?ooo`D00000
0P3oool2000000@0oooo0P00000`0?ooo`D000000P3oool2000000@0oooo0P00000`0?ooo`@00000
0`3oool2000000@0oooo0P0000030?ooo`00E03oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000003@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`00E`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool005D0
oooo0P0000030?ooo`040000003oool0oooo000003@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`020?ooo`8000000`3oool010000000oooo0?ooo`00000a0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`00E@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000003@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000;`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
05D0oooo0`0000030?ooo`800000=03oool2000000@0oooo0P0000040?ooo`800000<@3oool20000
00@0oooo0`0000030?ooo`800000<@3oool2000000@0oooo0P0000040?ooo`8000000`3oool00?l0
oooo8@3oool00?l0oooo8@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001D0
ooooo`000009000000<0oooo000K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`070?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00L0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?oo
o`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?oo
o`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool4
0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0
oooo0`3oool000L0oooo100000030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
2`3oool200000?D0oooo00070?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`040?ooo`8000001@3oool200000?D0oooo00080?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P00003l0?ooo`002@3oool0
0`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00070?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?ooo`<0oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool400000?l0oooo0P3oool001/0oooo00@000000?ooo`0000000000o`3oool20?ooo`00
6`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3o
ool001/0oooo0P00000S0?ooo`800000gP3oool001/0oooo0P00000;0?ooo`8000000P3oool20000
0180oooo0P00003N0?ooo`006`3oool010000000oooo0000000000090?ooo`8000000P3oool20000
0140oooo1000003M0?ooo`006`3oool010000000oooo0?ooo`3oool2000001X0oooo0P0000020?oo
o`@00000g@3oool001/0oooo00<000000?ooo`3oool00`3oool2000001@0oooo0P0000020?ooo`80
0000h`3oool001/0oooo0P0000060?ooo`8000004P3oool2000000/0oooo0P0000040?ooo`800000
e03oool001/0oooo0`0000050?ooo`@000002P3oool200000140oooo0P0000040?ooo`800000e03o
ool001/0oooo1@0000070?ooo`800000203oool200000>d0oooo000K0?ooo`030000003oool0oooo
0080000000<0oooo0000000000001P3oool200000?D0oooo000K0?ooo`800000103oool2000000P0
oooo0P0000080?ooo`800000j@3oool001/0oooo00<000000?ooo`3oool03`3oool2000000H0oooo
0P00003Y0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`D00000k03oool001@0oooo0P000005
0?ooo`030000003oool0oooo00T0oooo0P0000090?ooo`8000007@3oool2000000030?ooo`000000
00000<X0oooo000C0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0P00
00060?ooo`8000002`3oool2000000l0oooo0P00000:0?ooo`80000000<0oooo000000000000bP3o
ool001H0oooo00<000000?ooo`3oool00P3oool200000080oooo0P00000E0?ooo`8000003@3oool2
00000080oooo0P00003E0?ooo`00503oool2000000D0oooo00<000000?ooo`3oool0603oool40000
00l0oooo0P0000050?ooo`800000cP3oool001@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0L0?ooo`800000503oool200000<h0oooo000D0?ooo`<00000103oool00`000000oooo
0?ooo`0N0?ooo`8000007`3oool2000000<0oooo0P00002l0?ooo`006`3oool2000000h0oooo0P00
000;0?ooo`800000103oool2000000h0oooo0P0000080?ooo`8000000`3oool2000000<0oooo0P00
002l0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`8000001@3oool2000000/0oooo0P000002
0?ooo`8000000P3oool2000000`0oooo0P0000080?ooo`800000aP3oool001/0oooo00<000000?oo
o`3oool01P3oool2000001H0oooo0P0000040?ooo`800000g03oool001/0oooo00<000000?ooo`3o
ool09P3oool200000=X0oooo000K0?ooo`030000003oool0oooo00P0oooo0P00000N0?ooo`800000
f03oool001/0oooo0P0000090?ooo`8000002`3oool2000000D0oooo0P00000<0?ooo`800000eP3o
ool001/0oooo00<000000?ooo`3oool05@3oool2000000D0oooo0P00000>0?ooo`800000e03oool0
01/0oooo00<000000?ooo`3oool03`3oool5000001X0oooo0P00000<0?ooo`800000a03oool001/0
oooo00<000000?ooo`3oool03`3oool5000001`0oooo0`0000090?ooo`8000000`3oool200000;l0
oooo000K0?ooo`800000803oool2000000L0oooo0P0000090?ooo`800000303oool200000;l0oooo
000K0?ooo`030000003oool0oooo01l0oooo0P0000070?ooo`8000002`3oool2000000030?ooo`00
000000000<P0oooo000K0?ooo`030000003oool0oooo0340oooo0P0000040?ooo`<00000b03oool0
01/0oooo00<000000?ooo`3oool0<@3oool2000000H0oooo0P00000S0?ooo`800000XP3oool001/0
oooo0P00000^0?ooo`800000303oool200000240oooo0`00002Q0?ooo`006`3oool00`000000oooo
0?ooo`0]0?ooo`8000003P3oool200000200oooo0P0000050?ooo`800000VP3oool001/0oooo00<0
00000?ooo`3oool0903oool2000001T0oooo0P00000L0?ooo`8000001`3oool2000009X0oooo0009
0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0T
0?ooo`8000006`3oool2000001X0oooo0P0000030?ooo`800000WP3oool000T0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02T0oooo0P00000H
0?ooo`8000002@3oool2000000L0oooo0`0000080?ooo`800000WP3oool000T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000:P3oool200000180oooo0P0000060?oo
o`<000001P3oool2000000L0oooo0`00002X0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`80
00001@3oool00`000000oooo0?ooo`0m0?ooo`8000001P3oool2000000030?ooo`00000000000240
oooo0P00002E0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0A@3oool2000000<0oooo0P00000O0?ooo`800000U@3oool000L0oooo
100000090?ooo`<00000103oool00`000000oooo0?ooo`0^0?ooo`8000006P3oool4000002D0oooo
1000002;0?ooo`006`3oool2000002l0oooo0P00000F0?ooo`8000000P3oool200000080oooo0P00
00030?ooo`8000001@3oool2000001H0oooo1@00002;0?ooo`006`3oool00`000000oooo0?ooo`16
0?ooo`800000203oool5000000D0oooo0P00000F0?ooo`800000SP3oool001/0oooo00<000000?oo
o`3oool0=@3oool2000000/0oooo0P00000?0?ooo`800000[@3oool001/0oooo00<000000?ooo`3o
ool0=@3oool4000000T0oooo0P00000A0?ooo`<00000ZP3oool001/0oooo00<000000?ooo`3oool0
=`3oool200000080oooo0P00000K0?ooo`8000007@3oool200000080oooo0P0000250?ooo`006`3o
ool2000003`0oooo0P00000<0?ooo`8000003`3oool3000001X0oooo0P0000020?ooo`<00000Q03o
ool001/0oooo00<000000?ooo`3oool0@03oool2000000L0oooo0P00000B0?ooo`8000001@3oool2
000000030?ooo`000000000001<0oooo0P0000240?ooo`006`3oool00`000000oooo0?ooo`100?oo
o`8000003P3oool2000000d0oooo0P0000020?ooo`<0000000<0oooo0000000000001`3oool20000
00@0oooo0P00002:0?ooo`006`3oool00`000000oooo0?ooo`180?ooo`8000001P3oool2000000l0
oooo1000000;0?ooo`800000103oool2000008X0oooo000K0?ooo`800000B@3oool200000180oooo
0P0000050?ooo`800000W@3oool001/0oooo00<000000?ooo`3oool0DP3oool2000000P0oooo0P00
00070?ooo`<00000VP3oool001/0oooo00<000000?ooo`3oool0DP3oool2000000030?ooo`000000
00000140oooo0`00000G0?ooo`800000OP3oool001/0oooo00<000000?ooo`3oool0B`3oool40000
00H0oooo0P00000B0?ooo`<000005P3oool2000007h0oooo000K0?ooo`030000003oool0oooo04/0
oooo1000000M0?ooo`800000U03oool001/0oooo0P00001E0?ooo`800000603oool2000000030?oo
o`000000000001/0oooo0P00001b0?ooo`006`3oool00`000000oooo0?ooo`1?0?ooo`8000000`3o
ool2000001X0oooo0`0000070?ooo`8000004P3oool300000740oooo000=0?ooo`D000000P3oool2
000000D0oooo00<000000?ooo`3oool0C`3oool200000240oooo0P0000060?ooo`8000004`3oool2
00000080oooo0P00001]0?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`8000007@3oool2000006d0oooo000?0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`800000M`3oool2
000008X0oooo000?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo05T0oooo0P00000M0?ooo`800000R03oool000l0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F@3oool2
000000H0oooo0P00000G0?ooo`800000QP3oool000h0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`1Q0?ooo`8000006@3oool2000001P0oooo0P00001Z0?ooo`006`3oool2000007l0
oooo0`00000E0?ooo`800000JP3oool001/0oooo00<000000?ooo`3oool0N03oool2000000<0oooo
1@0000070?ooo`800000M`3oool001/0oooo00<000000?ooo`3oool0J03oool2000000@0oooo0P00
00080?ooo`8000000`3oool2000000<0oooo100000030?ooo`8000004P3oool2000006<0oooo000K
0?ooo`030000003oool0oooo06P0oooo0P0000040?ooo`800000503oool3000001H0oooo0P00001S
0?ooo`006`3oool00`000000oooo0?ooo`210?ooo`8000000P3oool4000007T0oooo000K0?ooo`80
0000PP3oool200000080oooo0P0000020?ooo`800000M`3oool001/0oooo00<000000?ooo`3oool0
K@3oool2000001`0oooo0P00000G0?ooo`800000G03oool001/0oooo00<000000?ooo`3oool0K03o
ool3000001h0oooo0P00000E0?ooo`800000G03oool001/0oooo00<000000?ooo`3oool0K03oool2
000001`0oooo0P0000030?ooo`8000007`3oool5000004d0oooo000K0?ooo`800000R03oool20000
00030?ooo`000000000000D0oooo0P00000I0?ooo`8000000P3oool5000004d0oooo000K0?ooo`03
0000003oool0oooo08L0oooo0P00000:0?ooo`8000003P3oool200000080oooo0P0000030?ooo`80
0000E03oool001/0oooo00<000000?ooo`3oool0QP3oool2000000d0oooo0P00000<0?ooo`800000
0P3oool2000001<0oooo0P0000140?ooo`006`3oool00`000000oooo0?ooo`260?ooo`8000003`3o
ool2000002<0oooo0P0000140?ooo`006`3oool00`000000oooo0?ooo`2I0?ooo`<000001@3oool2
000005l0oooo000K0?ooo`800000UP3oool2000000<0oooo100000030?ooo`800000G`3oool001/0
oooo00<000000?ooo`3oool0P03oool2000001<0oooo0P0000030?ooo`8000000P3oool300000640
oooo00000`3oool0000000000003000000030?ooo`0000000000008000000`3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0800oooo0P0000090?ooo`8000000`3oool2000000T0oooo
0P0000040?ooo`8000001P3oool2000005L0oooo00030?ooo`050000003oool0oooo0?ooo`000000
2`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo08/0oooo0P0000030?ooo`80
00002@3oool2000000H0oooo0`0000030?ooo`800000403oool2000004D0oooo00030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`800000
S@3oool2000000X0oooo0P00000<0?ooo`8000004`3oool2000000L0oooo0P00000l0?ooo`000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`030000003o
ool0oooo08`0oooo0P0000030?ooo`8000001@3oool2000000h0oooo0P00000J0?ooo`800000103o
ool2000003H0oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T@3oool2000001L0oooo0P00
000N0?ooo`800000=P3oool00080oooo0P0000040?ooo`8000002P3oool3000000@0oooo00<00000
0?ooo`3oool0[03oool2000000P0oooo0P0000020?ooo`800000AP3oool001/0oooo00<000000?oo
o`3oool0XP3oool2000000X0oooo0P0000060?ooo`8000000P3oool200000180oooo0P00000b0?oo
o`006`3oool2000009D0oooo0P0000030?ooo`8000001`3oool2000000`0oooo0P00000C0?ooo`80
00000P3oool2000000<0oooo0P00000b0?ooo`006`3oool00`000000oooo0?ooo`2D0?ooo`800000
0`3oool2000001L0oooo0P00000A0?ooo`8000000P3oool2000003L0oooo000K0?ooo`030000003o
ool0oooo0;@0oooo0P00001<0?ooo`006`3oool00`000000oooo0?ooo`2]0?ooo`8000001`3oool4
000004P0oooo000K0?ooo`800000Z@3oool2000000<0oooo0`0000080?ooo`<000001`3oool20000
00l0oooo0P00000]0?ooo`006`3oool00`000000oooo0?ooo`2N0?ooo`8000001P3oool4000000@0
oooo0P00000;0?ooo`8000001@3oool2000000l0oooo0P00000]0?ooo`006`3oool00`000000oooo
0?ooo`2N0?ooo`8000001P3oool2000001D0oooo0P00000<0?ooo`800000=@3oool001/0oooo00<0
00000?ooo`3oool0W`3oool2000001h0oooo0P00000:0?ooo`<00000=03oool001/0oooo0P00002P
0?ooo`800000703oool2000000040?ooo`0000000000000000T0oooo0P0000030?ooo`8000004@3o
ool2000001`0oooo000K0?ooo`030000003oool0oooo0;80oooo0P0000090?ooo`80000000@0oooo
000000000000oooo0P00000<0?ooo`8000004@3oool2000001`0oooo000K0?ooo`030000003oool0
oooo0;80oooo0P00000A0?ooo`800000503oool2000002D0oooo000K0?ooo`030000003oool0oooo
0<L0oooo0P00000B0?ooo`8000009@3oool001/0oooo00<000000?ooo`3oool0Z`3oool2000001`0
oooo0P00000g0?ooo`006`3oool200000:`0oooo0P00000N0?ooo`800000=@3oool001/0oooo00<0
00000?ooo`3oool0`@3oool2000000X0oooo0`00000R0?ooo`8000003P3oool000d0oooo1@000002
0?ooo`8000001@3oool00`000000oooo0?ooo`310?ooo`8000003@3oool2000000L0oooo0P00000G
0?ooo`8000003P3oool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0dP3oool2000000D0oooo0P00000C0?ooo`8000004P3oool0
00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000]P3oool40000
01/0oooo0P00000H0?ooo`8000004P3oool000l0oooo00<000000?ooo`3oool00P3oool2000000D0
oooo00<000000?ooo`3oool0]@3oool4000001L0oooo0P0000040?ooo`800000:P3oool000l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=00oooo
0P0000020?ooo`8000000P3oool3000002L0oooo000>0?ooo`800000103oool3000000@0oooo00<0
00000?ooo`3oool0e03oool2000000D0oooo0P00000B0?ooo`8000004@3oool001/0oooo00<00000
0?ooo`3oool0_`3oool2000001`0oooo0P00000@0?ooo`8000004@3oool001/0oooo0P0000300?oo
o`8000007P3oool200000240oooo000K0?ooo`030000003oool0oooo0=D0oooo0P00000:0?ooo`80
00007`3oool001/0oooo00<000000?ooo`3oool0e@3oool2000000`0oooo0P00000M0?ooo`006`3o
ool00`000000oooo0?ooo`3J0?ooo`8000002@3oool2000001/0oooo000K0?ooo`800000a`3oool2
00000180oooo0P00000;0?ooo`800000203oool2000000l0oooo000K0?ooo`030000003oool0oooo
0<H0oooo0P00000Q0?ooo`8000001P3oool2000000l0oooo000K0?ooo`030000003oool0oooo0<L0
oooo0P00000=0?ooo`8000002`3oool2000000D0oooo0`00000E0?ooo`006`3oool00`000000oooo
0?ooo`370?ooo`8000003@3oool2000000/0oooo0P0000030?ooo`P000004P3oool001/0oooo00<0
00000?ooo`3oool0f03oool2000000d0oooo0`0000020?ooo`8000000P3oool2000000040?ooo`00
00000000000000`0oooo000K0?ooo`800000d03oool2000000L0oooo0P00000=0?ooo`8000002@3o
ool4000000`0oooo000K0?ooo`030000003oool0oooo0<l0oooo0P00000L0?ooo`8000001P3oool2
000000/0oooo000K0?ooo`030000003oool0oooo0>d0oooo0P0000080?ooo`8000002@3oool001/0
oooo00<000000?ooo`3oool0gP3oool6000000D0oooo0P00000;0?ooo`8000002P3oool001/0oooo
0P00003O0?ooo`H000001@3oool2000000/0oooo0P00000:0?ooo`006`3oool00`000000oooo0?oo
o`3M0?ooo`8000008`3oool000030?ooo`000000000000<000000`3oool00`000000oooo0?ooo`02
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0g@3oool2000000H0oooo0P00000K
0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3U0?ooo`800000403oool2000000T0oooo00030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`800000h03oool2000001H0oooo0P0000090?ooo`000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo0=l0oooo0P00000Q0?ooo`00
0`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0`3oool00080oooo0P0000030?ooo`@00000
2@3oool3000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.7718, -1.68424, \
0.797744, 0.112969}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
We see that the experminetal realization of Mother Nature's True Function is \
\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(f \((t)\)\), " ", "=", 
      StyleBox[
        RowBox[{" ", 
          StyleBox[" ",
            "DisplayFormula"]}]], 
      StyleBox[\(3.58798\  + \ 0.0662225\ t\),
        "DisplayFormula"]}]], "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Creating Hypothetical Data Sets When the Distribution Is Known\
\>", "Subsubsection"],

Cell[TextData[{
  "Since we know the underlying distribution of the data points (the Random \
call I added), we can create a number of new data sets, and obtain estimates \
of the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " from them. Then we can get estimated errors in these parameters. \n\nWe \
are not getting new experimental values--we are ",
  StyleBox["simulating the experiement",
    FontSlant->"Italic"],
  " based on the fact that we know that underlying process that produced the \
data."
}], "Text"],

Cell["\<\
Here is one simulated data set. The different SeedRandom means that I get a \
different sequence of random numbers than when I \"did the experiment\" \
above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SeedRandom[3]\), "\[IndentingNewLine]", 
    \(\(datahyp0\  = \ 
        Table[{t, ftrue[t] + Random[Real, {\(-2\), 2}]}, {t, 1, 
            200}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(f[t_]\  = Fit[datahyp0, {1, t}, t]\), "\[IndentingNewLine]", 
    \(Regress[datahyp0, {1, t}, t, 
      RegressionReport \[Rule] {RSquared, 
          EstimatedVariance}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(dataplot\  = \ 
        ListPlot[datahyp0, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(modelplot\  = \ 
        Plot[f[t], {t, 0, 200}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(Show[dataplot, modelplot, 
      DisplayFunction \[Rule] $DisplayFunction]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(\(3.8034730487184483`\)\(\[InvisibleSpace]\)\) + 
      0.06343289175830516`\ t\)], "Output"],

Cell[BoxData[
    \({RSquared \[Rule] 0.9106590564562873`, 
      EstimatedVariance \[Rule] 1.3290962653176468`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0147151 0.0325993 [
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .09621 -18 -4.5 ]
[.01131 .09621 0 4.5 ]
[.01131 .17771 -6 -4.5 ]
[.01131 .17771 0 4.5 ]
[.01131 .25921 -18 -4.5 ]
[.01131 .25921 0 4.5 ]
[.01131 .34071 -12 -4.5 ]
[.01131 .34071 0 4.5 ]
[.01131 .42221 -24 -4.5 ]
[.01131 .42221 0 4.5 ]
[.01131 .50371 -12 -4.5 ]
[.01131 .50371 0 4.5 ]
[.01131 .5852 -24 -4.5 ]
[.01131 .5852 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(50)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(100)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(150)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(200)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09621 m
.03006 .09621 L
s
[(2.5)] .01131 .09621 1 0 Mshowa
.02381 .17771 m
.03006 .17771 L
s
[(5)] .01131 .17771 1 0 Mshowa
.02381 .25921 m
.03006 .25921 L
s
[(7.5)] .01131 .25921 1 0 Mshowa
.02381 .34071 m
.03006 .34071 L
s
[(10)] .01131 .34071 1 0 Mshowa
.02381 .42221 m
.03006 .42221 L
s
[(12.5)] .01131 .42221 1 0 Mshowa
.02381 .50371 m
.03006 .50371 L
s
[(15)] .01131 .50371 1 0 Mshowa
.02381 .5852 m
.03006 .5852 L
s
[(17.5)] .01131 .5852 1 0 Mshowa
.125 Mabswid
.02381 .03101 m
.02756 .03101 L
s
.02381 .04731 m
.02756 .04731 L
s
.02381 .06361 m
.02756 .06361 L
s
.02381 .07991 m
.02756 .07991 L
s
.02381 .11251 m
.02756 .11251 L
s
.02381 .12881 m
.02756 .12881 L
s
.02381 .14511 m
.02756 .14511 L
s
.02381 .16141 m
.02756 .16141 L
s
.02381 .19401 m
.02756 .19401 L
s
.02381 .21031 m
.02756 .21031 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24291 m
.02756 .24291 L
s
.02381 .27551 m
.02756 .27551 L
s
.02381 .29181 m
.02756 .29181 L
s
.02381 .30811 m
.02756 .30811 L
s
.02381 .32441 m
.02756 .32441 L
s
.02381 .35701 m
.02756 .35701 L
s
.02381 .37331 m
.02756 .37331 L
s
.02381 .38961 m
.02756 .38961 L
s
.02381 .40591 m
.02756 .40591 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .45481 m
.02756 .45481 L
s
.02381 .47111 m
.02756 .47111 L
s
.02381 .48741 m
.02756 .48741 L
s
.02381 .52 m
.02756 .52 L
s
.02381 .5363 m
.02756 .5363 L
s
.02381 .5526 m
.02756 .5526 L
s
.02381 .5689 m
.02756 .5689 L
s
.02381 .6015 m
.02756 .6015 L
s
.02381 .6178 m
.02756 .6178 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02857 .1598 Mdot
.03333 .13183 Mdot
.0381 .12499 Mdot
.04286 .17461 Mdot
.04762 .09267 Mdot
.05238 .20488 Mdot
.05714 .19685 Mdot
.0619 .19551 Mdot
.06667 .13303 Mdot
.07143 .18939 Mdot
.07619 .11883 Mdot
.08095 .21346 Mdot
.08571 .14147 Mdot
.09048 .12157 Mdot
.09524 .1339 Mdot
.1 .21915 Mdot
.10476 .16777 Mdot
.10952 .2263 Mdot
.11429 .18416 Mdot
.11905 .15217 Mdot
.12381 .18595 Mdot
.12857 .12969 Mdot
.13333 .18846 Mdot
.1381 .1947 Mdot
.14286 .22945 Mdot
.14762 .20335 Mdot
.15238 .14075 Mdot
.15714 .22995 Mdot
.1619 .21842 Mdot
.16667 .21269 Mdot
.17143 .16031 Mdot
.17619 .25303 Mdot
.18095 .17577 Mdot
.18571 .24626 Mdot
.19048 .26662 Mdot
.19524 .2669 Mdot
.2 .26382 Mdot
.20476 .22599 Mdot
.20952 .2362 Mdot
.21429 .15341 Mdot
.21905 .20389 Mdot
.22381 .24012 Mdot
.22857 .16426 Mdot
.23333 .24604 Mdot
.2381 .26493 Mdot
.24286 .2292 Mdot
.24762 .22715 Mdot
.25238 .17448 Mdot
.25714 .2912 Mdot
.2619 .28376 Mdot
.26667 .2161 Mdot
.27143 .2068 Mdot
.27619 .20684 Mdot
.28095 .20732 Mdot
.28571 .19422 Mdot
.29048 .22479 Mdot
.29524 .30426 Mdot
.3 .23644 Mdot
.30476 .20516 Mdot
.30952 .23764 Mdot
.31429 .32238 Mdot
.31905 .29456 Mdot
.32381 .25526 Mdot
.32857 .24231 Mdot
.33333 .27875 Mdot
.3381 .2169 Mdot
.34286 .25564 Mdot
.34762 .2935 Mdot
.35238 .31323 Mdot
.35714 .28928 Mdot
.3619 .33226 Mdot
.36667 .29458 Mdot
.37143 .33017 Mdot
.37619 .31584 Mdot
.38095 .29828 Mdot
.38571 .27207 Mdot
.39048 .30982 Mdot
.39524 .29719 Mdot
.4 .29491 Mdot
.40476 .24032 Mdot
.40952 .33117 Mdot
.41429 .25815 Mdot
.41905 .28934 Mdot
.42381 .33485 Mdot
.42857 .34314 Mdot
.43333 .30013 Mdot
.4381 .3728 Mdot
.44286 .30304 Mdot
.44762 .27708 Mdot
.45238 .29811 Mdot
.45714 .33422 Mdot
.4619 .35919 Mdot
.46667 .31568 Mdot
.47143 .36283 Mdot
.47619 .35815 Mdot
.48095 .29259 Mdot
.48571 .34606 Mdot
.49048 .27934 Mdot
.49524 .2944 Mdot
.5 .38763 Mdot
.50476 .40555 Mdot
.50952 .35363 Mdot
.51429 .37316 Mdot
.51905 .39276 Mdot
.52381 .32201 Mdot
.52857 .3453 Mdot
.53333 .33583 Mdot
.5381 .3121 Mdot
.54286 .36564 Mdot
.54762 .30373 Mdot
.55238 .35417 Mdot
.55714 .40239 Mdot
.5619 .35367 Mdot
.56667 .40331 Mdot
.57143 .41982 Mdot
.57619 .44526 Mdot
.58095 .44224 Mdot
.58571 .4469 Mdot
.59048 .33989 Mdot
.59524 .43307 Mdot
.6 .37876 Mdot
.60476 .45233 Mdot
.60952 .33243 Mdot
.61429 .33458 Mdot
.61905 .39493 Mdot
.62381 .39221 Mdot
.62857 .38536 Mdot
.63333 .37009 Mdot
.6381 .37297 Mdot
.64286 .34916 Mdot
.64762 .35396 Mdot
.65238 .3646 Mdot
.65714 .44652 Mdot
.6619 .35641 Mdot
.66667 .44336 Mdot
.67143 .40795 Mdot
.67619 .41038 Mdot
.68095 .40321 Mdot
.68571 .47583 Mdot
.69048 .41717 Mdot
.69524 .42481 Mdot
.7 .41515 Mdot
.70476 .46658 Mdot
.70952 .44732 Mdot
.71429 .38105 Mdot
.71905 .4304 Mdot
.72381 .47352 Mdot
.72857 .45429 Mdot
.73333 .46026 Mdot
.7381 .51451 Mdot
.74286 .43626 Mdot
.74762 .43449 Mdot
.75238 .43976 Mdot
.75714 .52002 Mdot
.7619 .43915 Mdot
.76667 .42892 Mdot
.77143 .48485 Mdot
.77619 .52701 Mdot
.78095 .49177 Mdot
.78571 .51913 Mdot
.79048 .44442 Mdot
.79524 .49594 Mdot
.8 .52066 Mdot
.80476 .47846 Mdot
.80952 .5287 Mdot
.81429 .46165 Mdot
.81905 .43713 Mdot
.82381 .54678 Mdot
.82857 .53507 Mdot
.83333 .55126 Mdot
.8381 .4858 Mdot
.84286 .48647 Mdot
.84762 .47097 Mdot
.85238 .56549 Mdot
.85714 .45007 Mdot
.8619 .45469 Mdot
.86667 .56651 Mdot
.87143 .45255 Mdot
.87619 .55058 Mdot
.88095 .56762 Mdot
.88571 .49529 Mdot
.89048 .47175 Mdot
.89524 .47681 Mdot
.9 .46868 Mdot
.90476 .47324 Mdot
.90952 .53077 Mdot
.91429 .51329 Mdot
.91905 .54954 Mdot
.92381 .50605 Mdot
.92857 .50241 Mdot
.93333 .51163 Mdot
.9381 .57082 Mdot
.94286 .54122 Mdot
.94762 .52357 Mdot
.95238 .60044 Mdot
.95714 .53075 Mdot
.9619 .51882 Mdot
.96667 .53925 Mdot
.97143 .60332 Mdot
.97619 .53119 Mdot
.5 Mabswid
.02381 .13871 m
.06244 .15548 L
.10458 .17378 L
.14415 .19096 L
.18221 .20749 L
.22272 .22508 L
.26171 .24201 L
.30316 .26001 L
.34309 .27735 L
.3815 .29403 L
.42237 .31178 L
.46172 .32887 L
.49955 .3453 L
.53984 .36279 L
.57861 .37963 L
.61984 .39753 L
.65954 .41478 L
.69774 .43136 L
.73838 .44901 L
.77751 .466 L
.81909 .48406 L
.85916 .50146 L
.89771 .5182 L
.93871 .53601 L
.97619 .55228 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00E@3oool2000000@0oooo0P00000c0?ooo`D00000
0P3oool2000000@0oooo0P00000`0?ooo`D000000P3oool2000000@0oooo0P00000`0?ooo`@00000
0`3oool2000000@0oooo0P0000030?ooo`00E03oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000003@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`00E`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool005D0
oooo0P0000030?ooo`040000003oool0oooo000003@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`020?ooo`8000000`3oool010000000oooo0?ooo`00000a0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`00E@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000003@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000;`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
05D0oooo0`0000030?ooo`800000=03oool2000000@0oooo0P0000040?ooo`800000<@3oool20000
00@0oooo0`0000030?ooo`800000<@3oool2000000@0oooo0P0000040?ooo`8000000`3oool00?l0
oooo8@3oool00?l0oooo8@3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo00<000000?ooo`3oool0o`3oool30?ooo`005@3ooooo000000T000000`3oool001/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?oo
o`006`3oool200000?l0oooo103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo0P00003o0?ooo`@0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo
00<000000?ooo`3oool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K
0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo0P00003o0?ooo`@0oooo000K0?ooo`03
0000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`800000o`3oool40?ooo`006`3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00070?ooo`@000000`3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0?l0oooo0`3oool000L0oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0P00003m0?ooo`00203oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000o@3oool000T0oooo00<0
00000?ooo`3oool0203oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`001`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool0
01/0oooo00<000000?ooo`3oool0o`3oool30?ooo`006`3oool200000?l0oooo103oool001/0oooo
00<000000?ooo`3oool02P3oool200000080oooo0P00003b0?ooo`006`3oool00`000000oooo0?oo
o`02000000P0oooo0P0000020?ooo`800000lP3oool001/0oooo00<000000?ooo`3oool00P00003o
0?ooo`40oooo000K0?ooo`@000001`3oool2000000h0oooo0P00003X0?ooo`006`3oool010000000
oooo0000000000070?ooo`8000001@3oool2000000L0oooo0P00003X0?ooo`006`3oool200000100
oooo0P00000=0?ooo`800000hP3oool001/0oooo00@000000?ooo`0000000000303oool2000000l0
oooo0P00003R0?ooo`006`3oool200000080oooo0P00000:0?ooo`800000l`3oool001/0oooo00<0
00000?ooo`3oool00`3oool200000100oooo0P00003[0?ooo`006`3oool00`000000oooo0?ooo`05
0?ooo`8000003P3oool2000001L0oooo0P00003B0?ooo`006`3oool3000000L0oooo0P00000U0?oo
o`800000dP3oool001/0oooo0`0000090?ooo`800000603oool200000=d0oooo000K0?ooo`030000
003oool0oooo00/0oooo0P00000F0?ooo`8000003@3oool200000<h0oooo000K0?ooo`030000003o
ool0oooo00d0oooo0P0000030?ooo`8000007P3oool200000<h0oooo000D0?ooo`8000001@3oool0
10000000oooo0?ooo`3oool2000000`0oooo0P0000000`3oool000000000000T0?ooo`800000b03o
ool001<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool2000000h0oooo
0`00000B0?ooo`800000403oool200000<P0oooo000F0?ooo`030000003oool0oooo0080oooo0P00
000E0?ooo`800000403oool200000=X0oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`0D
0?ooo`D00000j@3oool001@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?oo
o`8000002@3oool2000000030?ooo`000000000000800000i`3oool001@0oooo0`0000040?ooo`03
0000003oool0oooo00T0oooo0P00000>0?ooo`D00000i03oool001/0oooo0P0000060?ooo`<00000
4P3oool200000080oooo0P00000Q0?ooo`800000_`3oool001/0oooo00<000000?ooo`3oool01@3o
ool300000180oooo0P0000040?ooo`8000007`3oool200000;l0oooo000K0?ooo`030000003oool0
oooo00@0oooo0P00000G0?ooo`8000000`3oool2000000`0oooo0P00000D0?ooo`800000^P3oool0
01/0oooo00<000000?ooo`3oool0103oool2000001L0oooo0P0000050?ooo`8000002P3oool20000
00/0oooo1@0000040?ooo`800000^P3oool001/0oooo0P00000S0?ooo`8000000P3oool2000001D0
oooo1@0000300?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`8000005@3oool2000000@0oooo
0`00000A0?ooo`8000004@3oool200000;40oooo000K0?ooo`030000003oool0oooo00/0oooo0P00
00030?ooo`8000003`3oool2000000P0oooo0P00000?0?ooo`8000004@3oool200000;40oooo000K
0?ooo`030000003oool0oooo0100oooo0P00000?0?ooo`8000002P3oool300000=80oooo000K0?oo
o`030000003oool0oooo01<0oooo0P00000G0?ooo`8000000P3oool3000000@0oooo0P0000090?oo
o`800000_P3oool001/0oooo0P00000D0?ooo`8000001`3oool2000000030?ooo`000000000000/0
oooo0P0000050?ooo`80000000@0oooo00000000000000002@3oool200000;h0oooo000K0?ooo`03
0000003oool0oooo01`0oooo0P0000000`3oool000000000000D0?ooo`<00000bP3oool001/0oooo
00<000000?ooo`3oool0;@3oool2000000P0oooo0P00000<0?ooo`80000000<0oooo000000000000
^03oool001/0oooo00<000000?ooo`3oool0;@3oool200000080oooo0P0000060?ooo`8000002P3o
ool2000000030?ooo`000000000000<0oooo0P00000B0?ooo`800000W`3oool001/0oooo0P00000X
0?ooo`800000203oool4000000H0oooo0P00000@0?ooo`8000004P3oool2000009l0oooo000K0?oo
o`030000003oool0oooo02L0oooo0P00000:0?ooo`800000203oool300000<80oooo00090?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0T0?ooo`80
00006P3oool200000<00oooo00090?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0T0?ooo`800000703oool3000000H0oooo0P0000030?ooo`80
00004@3oool2000009d0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool2000004H0oooo0`0000030?ooo`8000000`3oool200000140oooo0P00002M0?ooo`002P3o
ool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`0[0?ooo`800000203o
ool200000140oooo0P00002h0?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0:03oool5000000P0oooo0P00000C0?ooo`800000]P3o
ool000L0oooo100000090?ooo`<00000103oool00`000000oooo0?ooo`0X0?ooo`<000008@3oool2
000000h0oooo0P00002T0?ooo`006`3oool2000004l0oooo0P00000<0?ooo`8000003P3oool20000
09@0oooo000K0?ooo`030000003oool0oooo04h0oooo1@00000I0?ooo`8000002@3oool2000008T0
oooo000K0?ooo`030000003oool0oooo03/0oooo0P00000A0?ooo`8000000`3oool200000280oooo
0P0000290?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`800000603oool300000:X0oooo000K
0?ooo`030000003oool0oooo03X0oooo0P00000H0?ooo`8000000P3oool2000000X0oooo0P00000?
0?ooo`800000R`3oool001/0oooo0P00000k0?ooo`8000003P3oool2000000H0oooo10000000103o
ool000000000003oool300000080oooo0P0000030?ooo`8000003`3oool2000000030?ooo`000000
000008P0oooo000K0?ooo`030000003oool0oooo04X0oooo0P0000060?ooo`8000000`3oool20000
00040?ooo`00000000000?ooo`@000001`3oool2000000<0oooo0P0000090?ooo`800000R03oool0
01/0oooo00<000000?ooo`3oool0A03oool2000001@0oooo0P0000020?ooo`<000001`3oool20000
00030?ooo`0000000000008000005`3oool2000007X0oooo000K0?ooo`030000003oool0oooo04@0
oooo0P00000K0?ooo`800000203oool2000001T0oooo0P00001j0?ooo`006`3oool2000005h0oooo
0P0000040?ooo`800000W@3oool001/0oooo00<000000?ooo`3oool0D`3oool2000000P0oooo0P00
00060?ooo`<000002@3oool200000140oooo0P00001l0?ooo`006`3oool00`000000oooo0?ooo`1C
0?ooo`800000103oool2000000d0oooo0P0000070?ooo`8000004@3oool2000007`0oooo000K0?oo
o`030000003oool0oooo04T0oooo0P00000>0?ooo`8000003`3oool3000001<0oooo0P0000200?oo
o`006`3oool2000004X0oooo0P00000R0?ooo`8000004@3oool200000800oooo000K0?ooo`030000
003oool0oooo05P0oooo0P00000E0?ooo`<00000T03oool001/0oooo00<000000?ooo`3oool0E@3o
ool2000000030?ooo`000000000000P0oooo0P00000:0?ooo`8000000P3oool200000280oooo1000
001X0?ooo`003@3oool500000080oooo0P0000050?ooo`030000003oool0oooo05D0oooo0P00000;
0?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`800000303oool200000180oooo1000001X
0?ooo`003`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1V0?ooo`8000003P3oool2000000X0oooo0P00000=0?ooo`800000K`3oool0
00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0P00001X
0?ooo`8000003@3oool4000000L0oooo0P00000>0?ooo`800000K`3oool000l0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0I`3oool2
000000d0oooo0P0000020?ooo`8000001@3oool2000001`0oooo0P00001Q0?ooo`003`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1l
0?ooo`<000002`3oool2000001<0oooo0P00001Q0?ooo`003P3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo07`0oooo0P0000000`3oool00000000000060?ooo`80000000<0oooo0000
000000005@3oool2000000030?ooo`000000000005`0oooo000K0?ooo`800000L@3oool200000003
0?ooo`000000000000`0oooo0`0000030?ooo`800000603oool2000000030?ooo`000000000005`0
oooo000K0?ooo`030000003oool0oooo0700oooo1@00000?0?ooo`<000006`3oool2000005h0oooo
000K0?ooo`030000003oool0oooo0780oooo0P00000A0?ooo`@000006@3oool2000005h0oooo000K
0?ooo`030000003oool0oooo08D0oooo0P0000020?ooo`8000004P3oool2000006<0oooo000K0?oo
o`800000JP3oool200000180oooo0P00000<0?ooo`800000403oool300000680oooo000K0?ooo`03
0000003oool0oooo06T0oooo0P00000B0?ooo`8000003P3oool2000000D0oooo0P0000080?ooo`80
0000HP3oool001/0oooo00<000000?ooo`3oool0S`3oool2000000<0oooo0P00000L0?ooo`800000
CP3oool001/0oooo00<000000?ooo`3oool0NP3oool2000001D0oooo0P0000080?ooo`8000005@3o
ool2000004h0oooo000K0?ooo`800000N`3oool2000001L0oooo0P0000060?ooo`800000I@3oool0
01/0oooo00<000000?ooo`3oool0O`3oool2000001@0oooo0P0000020?ooo`<00000IP3oool001/0
oooo00<000000?ooo`3oool0O`3oool2000001H0oooo1@00001V0?ooo`006`3oool00`000000oooo
0?ooo`290?ooo`8000003P3oool3000006H0oooo000K0?ooo`030000003oool0oooo07/0oooo0P00
000<0?ooo`@000003`3oool2000000/0oooo0P00001G0?ooo`006`3oool2000007`0oooo0P00000>
0?ooo`8000004@3oool3000000H0oooo1000001G0?ooo`006`3oool00`000000oooo0?ooo`2Q0?oo
o`800000103oool3000005P0oooo00000`3oool0000000000003000000030?ooo`00000000000080
00000`3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0:<0oooo0`0000060?ooo`@0
0000DP3oool000<0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0S03oool2000001P0oooo0P0000040?ooo`@00000DP3oool000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo0P00002=0?ooo`8000006P3oool300000080oooo0P00001C0?ooo`000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0:/0oooo
1000000A0?ooo`800000@03oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2C0?ooo`800000
603oool3000000<0oooo0P00000;0?ooo`800000@03oool00080oooo0P0000040?ooo`8000002P3o
ool3000000@0oooo00<000000?ooo`3oool0T`3oool2000001/0oooo0P0000000`3oool000000000
00050?ooo`<000004@3oool200000380oooo000K0?ooo`800000/`3oool2000000H0oooo10000000
0`3oool000000000000=0?ooo`800000<P3oool001/0oooo00<000000?ooo`3oool0S`3oool20000
01D0oooo0P00000<0?ooo`8000001P3oool2000000030?ooo`000000000000D0oooo0P00000j0?oo
o`006`3oool00`000000oooo0?ooo`2>0?ooo`@000004@3oool2000000030?ooo`000000000000T0
oooo0P0000030?ooo`8000003P3oool2000003X0oooo000K0?ooo`030000003oool0oooo08h0oooo
100000030?ooo`800000303oool2000000`0oooo0P0000050?ooo`<000007@3oool2000002P0oooo
000K0?ooo`030000003oool0oooo09D0oooo0P00000O0?ooo`8000000`3oool2000001/0oooo1@00
000U0?ooo`006`3oool200000;L0oooo0P0000050?ooo`8000006P3oool4000002D0oooo000K0?oo
o`030000003oool0oooo0;L0oooo0P0000060?ooo`8000002`3oool2000003@0oooo000K0?ooo`03
0000003oool0oooo0;00oooo0P0000050?ooo`800000203oool2000000T0oooo0P00000d0?ooo`00
6`3oool00`000000oooo0?ooo`2`0?ooo`8000004@3oool200000100oooo0P00000<0?ooo`800000
7@3oool001/0oooo0P00002f0?ooo`8000003P3oool3000000d0oooo0P0000090?ooo`80000000@0
oooo0000000000000000703oool001/0oooo00<000000?ooo`3oool0Z`3oool2000000P0oooo0P00
000A0?ooo`@00000503oool6000001`0oooo000K0?ooo`030000003oool0oooo0:/0oooo0P00000M
0?ooo`<000005@3oool2000001h0oooo000K0?ooo`030000003oool0oooo0<40oooo0P00000:0?oo
o`<000000`3oool3000002`0oooo000K0?ooo`800000`P3oool2000000d0oooo0P000000103oool0
000000000000000/0?ooo`006`3oool00`000000oooo0?ooo`340?ooo`800000303oool2000002h0
oooo000=0?ooo`D000000P3oool2000000D0oooo00<000000?ooo`3oool0a03oool2000000030?oo
o`000000000000/0oooo0P0000090?ooo`8000008@3oool000l0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0a`3oool2000000d0oooo
0P0000070?ooo`8000008@3oool000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`800000f@3oool3000000l0oooo0P00000F0?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`3K0?ooo`800000303oool3000001H0oooo000?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3M0?oo
o`<000002@3oool2000000030?ooo`000000000001@0oooo000>0?ooo`800000103oool3000000@0
oooo00<000000?ooo`3oool0^03oool2000002H0oooo0P0000050?ooo`8000000`3oool2000001@0
oooo000K0?ooo`030000003oool0oooo0;P0oooo0P0000030?ooo`8000001P3oool200000080oooo
0P00000G0?ooo`<000000P3oool2000000X0oooo0P00000=0?ooo`006`3oool200000;h0oooo0P00
00060?ooo`8000000P3oool2000001X0oooo0P0000080?ooo`8000000P3oool2000000d0oooo000K
0?ooo`030000003oool0oooo0<80oooo0P00000S0?ooo`8000001P3oool200000140oooo000K0?oo
o`030000003oool0oooo0<80oooo0P0000070?ooo`800000603oool200000080oooo0P0000070?oo
o`8000000`3oool2000000T0oooo000K0?ooo`030000003oool0oooo0</0oooo0P0000030?ooo`80
00004`3oool2000000@0oooo0P0000050?ooo`8000000`3oool2000000T0oooo000K0?ooo`800000
d@3oool2000001/0oooo0`0000040?ooo`800000303oool001/0oooo00<000000?ooo`3oool0kP3o
ool400000080oooo0P00000<0?ooo`006`3oool00`000000oooo0?ooo`3?0?ooo`8000007@3oool2
00000080oooo0`00000=0?ooo`006`3oool00`000000oooo0?ooo`3?0?ooo`800000303oool20000
00T0oooo0P00000;0?ooo`8000002`3oool001/0oooo0P00003B0?ooo`8000002P3oool2000000T0
oooo0P00000=0?ooo`8000002@3oool001/0oooo00<000000?ooo`3oool0d@3oool2000002l0oooo
000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0eP3oool2
000002X0oooo000K0?ooo`030000003oool0oooo0=H0oooo0P0000020?ooo`8000000P3oool20000
0280oooo000K0?ooo`800000f`3oool200000080oooo0P00000=0?ooo`8000004`3oool001/0oooo
00<000000?ooo`3oool0k@3oool2000001<0oooo00000`3oool0000000000003000000<0oooo00<0
00000?ooo`3oool00P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0`3o
ool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0o`3oool30?ooo`000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool200000?l0oooo103oool0
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`8000001@3oool00`00
0000oooo0?ooo`3o0?ooo`<0oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool30?oo
o`000P3oool2000000<0oooo100000090?ooo`<00000103oool00`000000oooo0?ooo`3a0?ooo`80
00003`3oool001/0oooo0P00003b0?ooo`8000000`3oool2000000X0oooo000K0?ooo`030000003o
ool0oooo0?H0oooo0P00000:0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?oo
o`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
6`3oool200000?l0oooo103oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-21.7718, -1.77175, \
0.797744, 0.116529}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Notice that we got different fit parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\ and\ b\)]],
  "."
}], "Text"],

Cell[TextData[{
  "What we can do, is rerun a great many simulations, and see what kind of \
distribution of the fit parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\ and\ b\)]],
  " we get from the simulation. Here, we shall do 2000 simulations of the \
experiment, creating 2000 data sets, and get 2000 estimates of the fit \
parameters."
}], "Text"],

Cell[BoxData[{
    \(\(numdatasets\  = \ 2000;\)\), "\[IndentingNewLine]", 
    \(\(alist\  = \ {};\)\), "\[IndentingNewLine]", 
    \(\(blist\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]{datahyp0\  = \ 
          Table[{t, ftrue[t] + Random[Real, {\(-2\), 2}]}, {t, 1, 
              200}], \[IndentingNewLine]\[IndentingNewLine]f[t_]\  = 
          Fit[datahyp0, {1, t}, 
            t], \[IndentingNewLine]\[IndentingNewLine]alist\  = \ 
          Append[alist, Part[f[t], 1]], \[IndentingNewLine]blist\  = \ 
          Append[blist, Part[f[t], 2, 1]]}, {i, 1, numdatasets}]\)}], "Input"],

Cell["\<\
The best way to present the information that we have collected for the \
parameters is in a histogram.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Histogram[alist, HistogramCategories \[Rule] 20, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Parameter a\>", \ "\<Number of \
Occurances\>"}]\), "\[IndentingNewLine]", 
    \(Histogram[blist, HistogramCategories \[Rule] 20, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Parameter b\>", \ "\<Number of \
Occurances\>"}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.56522 0.869565 0.0147151 0.00224658 [
[.04348 -0.0125 -3 -9 ]
[.04348 -0.0125 3 0 ]
[.21739 -0.0125 -9 -9 ]
[.21739 -0.0125 9 0 ]
[.3913 -0.0125 -9 -9 ]
[.3913 -0.0125 9 0 ]
[.56522 -0.0125 -9 -9 ]
[.56522 -0.0125 9 0 ]
[.73913 -0.0125 -9 -9 ]
[.73913 -0.0125 9 0 ]
[.91304 -0.0125 -3 -9 ]
[.91304 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -21.5625 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12704 -12 -4.5 ]
[-0.0125 .12704 0 4.5 ]
[-0.0125 .23937 -18 -4.5 ]
[-0.0125 .23937 0 4.5 ]
[-0.0125 .3517 -18 -4.5 ]
[-0.0125 .3517 0 4.5 ]
[-0.0125 .46403 -18 -4.5 ]
[-0.0125 .46403 0 4.5 ]
[-0.0125 .57636 -18 -4.5 ]
[-0.0125 .57636 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -62 ]
[-0.01875 .30902 -18 62 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04348 0 m
.04348 .00625 L
s
[(3)] .04348 -0.0125 0 1 Mshowa
.21739 0 m
.21739 .00625 L
s
[(3.2)] .21739 -0.0125 0 1 Mshowa
.3913 0 m
.3913 .00625 L
s
[(3.4)] .3913 -0.0125 0 1 Mshowa
.56522 0 m
.56522 .00625 L
s
[(3.6)] .56522 -0.0125 0 1 Mshowa
.73913 0 m
.73913 .00625 L
s
[(3.8)] .73913 -0.0125 0 1 Mshowa
.91304 0 m
.91304 .00625 L
s
[(4)] .91304 -0.0125 0 1 Mshowa
.125 Mabswid
.08696 0 m
.08696 .00375 L
s
.13043 0 m
.13043 .00375 L
s
.17391 0 m
.17391 .00375 L
s
.26087 0 m
.26087 .00375 L
s
.30435 0 m
.30435 .00375 L
s
.34783 0 m
.34783 .00375 L
s
.43478 0 m
.43478 .00375 L
s
.47826 0 m
.47826 .00375 L
s
.52174 0 m
.52174 .00375 L
s
.6087 0 m
.6087 .00375 L
s
.65217 0 m
.65217 .00375 L
s
.69565 0 m
.69565 .00375 L
s
.78261 0 m
.78261 .00375 L
s
.82609 0 m
.82609 .00375 L
s
.86957 0 m
.86957 .00375 L
s
.95652 0 m
.95652 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Parameter) show
123.000 12.813 moveto
(a) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12704 m
.00625 .12704 L
s
[(50)] -0.0125 .12704 1 0 Mshowa
0 .23937 m
.00625 .23937 L
s
[(100)] -0.0125 .23937 1 0 Mshowa
0 .3517 m
.00625 .3517 L
s
[(150)] -0.0125 .3517 1 0 Mshowa
0 .46403 m
.00625 .46403 L
s
[(200)] -0.0125 .46403 1 0 Mshowa
0 .57636 m
.00625 .57636 L
s
[(250)] -0.0125 .57636 1 0 Mshowa
.125 Mabswid
0 .03718 m
.00375 .03718 L
s
0 .05965 m
.00375 .05965 L
s
0 .08211 m
.00375 .08211 L
s
0 .10458 m
.00375 .10458 L
s
0 .14951 m
.00375 .14951 L
s
0 .17198 m
.00375 .17198 L
s
0 .19444 m
.00375 .19444 L
s
0 .21691 m
.00375 .21691 L
s
0 .26184 m
.00375 .26184 L
s
0 .2843 m
.00375 .2843 L
s
0 .30677 m
.00375 .30677 L
s
0 .32924 m
.00375 .32924 L
s
0 .37417 m
.00375 .37417 L
s
0 .39663 m
.00375 .39663 L
s
0 .4191 m
.00375 .4191 L
s
0 .44157 m
.00375 .44157 L
s
0 .4865 m
.00375 .4865 L
s
0 .50896 m
.00375 .50896 L
s
0 .53143 m
.00375 .53143 L
s
0 .55389 m
.00375 .55389 L
s
0 .59883 m
.00375 .59883 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -147.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
123 10.2813 translate
90 rotate
-123 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Number) show
105.000 12.813 moveto
(of) show
123.000 12.813 moveto
(Occurances) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04348 .61178 m
.04348 .61803 L
s
.21739 .61178 m
.21739 .61803 L
s
.3913 .61178 m
.3913 .61803 L
s
.56522 .61178 m
.56522 .61803 L
s
.73913 .61178 m
.73913 .61803 L
s
.91304 .61178 m
.91304 .61803 L
s
.125 Mabswid
.08696 .61428 m
.08696 .61803 L
s
.13043 .61428 m
.13043 .61803 L
s
.17391 .61428 m
.17391 .61803 L
s
.26087 .61428 m
.26087 .61803 L
s
.30435 .61428 m
.30435 .61803 L
s
.34783 .61428 m
.34783 .61803 L
s
.43478 .61428 m
.43478 .61803 L
s
.47826 .61428 m
.47826 .61803 L
s
.52174 .61428 m
.52174 .61803 L
s
.6087 .61428 m
.6087 .61803 L
s
.65217 .61428 m
.65217 .61803 L
s
.69565 .61428 m
.69565 .61803 L
s
.78261 .61428 m
.78261 .61803 L
s
.82609 .61428 m
.82609 .61803 L
s
.86957 .61428 m
.86957 .61803 L
s
.95652 .61428 m
.95652 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12704 m
1 .12704 L
s
.99375 .23937 m
1 .23937 L
s
.99375 .3517 m
1 .3517 L
s
.99375 .46403 m
1 .46403 L
s
.99375 .57636 m
1 .57636 L
s
.125 Mabswid
.99625 .03718 m
1 .03718 L
s
.99625 .05965 m
1 .05965 L
s
.99625 .08211 m
1 .08211 L
s
.99625 .10458 m
1 .10458 L
s
.99625 .14951 m
1 .14951 L
s
.99625 .17198 m
1 .17198 L
s
.99625 .19444 m
1 .19444 L
s
.99625 .21691 m
1 .21691 L
s
.99625 .26184 m
1 .26184 L
s
.99625 .2843 m
1 .2843 L
s
.99625 .30677 m
1 .30677 L
s
.99625 .32924 m
1 .32924 L
s
.99625 .37417 m
1 .37417 L
s
.99625 .39663 m
1 .39663 L
s
.99625 .4191 m
1 .4191 L
s
.99625 .44157 m
1 .44157 L
s
.99625 .4865 m
1 .4865 L
s
.99625 .50896 m
1 .50896 L
s
.99625 .53143 m
1 .53143 L
s
.99625 .55389 m
1 .55389 L
s
.99625 .59883 m
1 .59883 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .03044 L
.04348 .03044 L
.04348 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .03044 L
.04348 .03044 L
.04348 .01472 L
0 .01472 L
s
1 0 0 r
.04348 .01472 m
.04348 .03044 L
.08696 .03044 L
.08696 .01472 L
F
0 g
.04348 .01472 m
.04348 .03044 L
.08696 .03044 L
.08696 .01472 L
.04348 .01472 L
s
1 0 0 r
.08696 .01472 m
.08696 .05066 L
.13043 .05066 L
.13043 .01472 L
F
0 g
.08696 .01472 m
.08696 .05066 L
.13043 .05066 L
.13043 .01472 L
.08696 .01472 L
s
1 0 0 r
.13043 .01472 m
.13043 .08885 L
.17391 .08885 L
.17391 .01472 L
F
0 g
.13043 .01472 m
.13043 .08885 L
.17391 .08885 L
.17391 .01472 L
.13043 .01472 L
s
1 0 0 r
.17391 .01472 m
.17391 .17198 L
.21739 .17198 L
.21739 .01472 L
F
0 g
.17391 .01472 m
.17391 .17198 L
.21739 .17198 L
.21739 .01472 L
.17391 .01472 L
s
1 0 0 r
.21739 .01472 m
.21739 .25735 L
.26087 .25735 L
.26087 .01472 L
F
0 g
.21739 .01472 m
.21739 .25735 L
.26087 .25735 L
.26087 .01472 L
.21739 .01472 L
s
1 0 0 r
.26087 .01472 m
.26087 .3517 L
.30435 .3517 L
.30435 .01472 L
F
0 g
.26087 .01472 m
.26087 .3517 L
.30435 .3517 L
.30435 .01472 L
.26087 .01472 L
s
1 0 0 r
.30435 .01472 m
.30435 .36967 L
.34783 .36967 L
.34783 .01472 L
F
0 g
.30435 .01472 m
.30435 .36967 L
.34783 .36967 L
.34783 .01472 L
.30435 .01472 L
s
1 0 0 r
.34783 .01472 m
.34783 .43483 L
.3913 .43483 L
.3913 .01472 L
F
0 g
.34783 .01472 m
.34783 .43483 L
.3913 .43483 L
.3913 .01472 L
.34783 .01472 L
s
1 0 0 r
.3913 .01472 m
.3913 .60332 L
.43478 .60332 L
.43478 .01472 L
F
0 g
.3913 .01472 m
.3913 .60332 L
.43478 .60332 L
.43478 .01472 L
.3913 .01472 L
s
1 0 0 r
.43478 .01472 m
.43478 .57411 L
.47826 .57411 L
.47826 .01472 L
F
0 g
.43478 .01472 m
.43478 .57411 L
.47826 .57411 L
.47826 .01472 L
.43478 .01472 L
s
1 0 0 r
.47826 .01472 m
.47826 .51346 L
.52174 .51346 L
.52174 .01472 L
F
0 g
.47826 .01472 m
.47826 .51346 L
.52174 .51346 L
.52174 .01472 L
.47826 .01472 L
s
1 0 0 r
.52174 .01472 m
.52174 .39663 L
.56522 .39663 L
.56522 .01472 L
F
0 g
.52174 .01472 m
.52174 .39663 L
.56522 .39663 L
.56522 .01472 L
.52174 .01472 L
s
1 0 0 r
.56522 .01472 m
.56522 .30677 L
.6087 .30677 L
.6087 .01472 L
F
0 g
.56522 .01472 m
.56522 .30677 L
.6087 .30677 L
.6087 .01472 L
.56522 .01472 L
s
1 0 0 r
.6087 .01472 m
.6087 .23488 L
.65217 .23488 L
.65217 .01472 L
F
0 g
.6087 .01472 m
.6087 .23488 L
.65217 .23488 L
.65217 .01472 L
.6087 .01472 L
s
1 0 0 r
.65217 .01472 m
.65217 .18096 L
.69565 .18096 L
.69565 .01472 L
F
0 g
.65217 .01472 m
.65217 .18096 L
.69565 .18096 L
.69565 .01472 L
.65217 .01472 L
s
1 0 0 r
.69565 .01472 m
.69565 .07537 L
.73913 .07537 L
.73913 .01472 L
F
0 g
.69565 .01472 m
.69565 .07537 L
.73913 .07537 L
.73913 .01472 L
.69565 .01472 L
s
1 0 0 r
.73913 .01472 m
.73913 .04841 L
.78261 .04841 L
.78261 .01472 L
F
0 g
.73913 .01472 m
.73913 .04841 L
.78261 .04841 L
.78261 .01472 L
.73913 .01472 L
s
1 0 0 r
.78261 .01472 m
.78261 .03943 L
.82609 .03943 L
.82609 .01472 L
F
0 g
.78261 .01472 m
.78261 .03943 L
.82609 .03943 L
.82609 .01472 L
.78261 .01472 L
s
1 0 0 r
.82609 .01472 m
.82609 .01696 L
.86957 .01696 L
.86957 .01472 L
F
0 g
.82609 .01472 m
.82609 .01696 L
.86957 .01696 L
.86957 .01472 L
.82609 .01472 L
s
1 0 0 r
.86957 .01472 m
.86957 .0237 L
.91304 .0237 L
.91304 .01472 L
F
0 g
.86957 .01472 m
.86957 .0237 L
.91304 .0237 L
.91304 .01472 L
.86957 .01472 L
s
1 0 0 r
.91304 .01472 m
.91304 .01472 L
.95652 .01472 L
.95652 .01472 L
F
0 g
.91304 .01472 m
.91304 .01472 L
.95652 .01472 L
.95652 .01472 L
.91304 .01472 L
s
1 0 0 r
.95652 .01472 m
.95652 .01696 L
1 .01696 L
1 .01472 L
F
0 g
.95652 .01472 m
.95652 .01696 L
1 .01696 L
1 .01472 L
.95652 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P03oool3000000@0oooo1@00
00000`3oool000000000000200000080oooo1`000000103oool000000?ooo`0000020?ooo`<00000
0`3oool2000000@0oooo0`0000020?ooo`@00000203oool5000005h0oooo00210?ooo`030000003o
ool0oooo00<0oooo100000030?ooo`030000003oool0oooo0080oooo100000020?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`@00000G`3oool00840oooo0`0000060?ooo`05
0000003oool0oooo0?ooo`0000001`3oool02@000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0400000080oooo00<000000?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1M0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`<00000
0P3oool4000000<0oooo0`0000001P3oool00000000000000000oooo000000<0oooo0P0000020?oo
o`D000000`3oool2000000<0oooo100000090?ooo`<00000G`3oool00840oooo00@000000?ooo`3o
ool00000803oool00`000000oooo0?ooo`1h0?ooo`00P03oool4000009`0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000_0?ooo`8000008`3oool2000000@0oooo0P0000030?oo
o`@00000703oool2000000@0oooo0P0000050?ooo`<000006`3oool2000000@0oooo0P0000030?oo
o`<00000703oool2000000@0oooo0P0000040?ooo`800000903oool3000001L0oooo000^0?ooo`04
0000003oool0oooo00000240oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0L
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06@3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000001X0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000T0?ooo`030000003oool0oooo01H0oooo000`0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00L0oooo1@00000L0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000703oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo00000240oooo1@00000G0?ooo`00<@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3oool01P3o
ool3000001h0oooo00<000000?ooo`3oool01`3oool200000280oooo00@000000?ooo`3oool00000
603oool002h0oooo00@000000?ooo`3oool000008@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000001/0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000K
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool06P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000280oooo00<000000?ooo`000000603oool002l0oooo
0P00000S0?ooo`8000002P3oool2000001d0oooo0P00000;0?ooo`800000703oool2000000X0oooo
0`00000K0?ooo`8000002P3oool2000002@0oooo0P00000H0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009@3ooooh000000<0oooo000U
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`01
0?ooo`007P3oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`010?oo
o`007@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?@0oooo00<000000?oo
o`3oool00@3oool001d0oooo00@000000?ooo`3oool00000103ooooh000000<0oooo000M0?ooo`04
0000003oool0oooo000000@0oooo00<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`080?oo
o`030000003o0000o`0000L0o`0000<000000?ooo`3oool04`3oool00`000000oooo0?ooo`010?oo
o`007@3oool010000000oooo0?ooo`0000040?ooo`030000003o0000o`0000P0o`0000<000000?l0
003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?oo
o`3oool0203oool;000001D0oooo00<000000?ooo`3oool00@3oool001h0oooo0P0000050?ooo`03
0000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l00003
0000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l00003
0000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l00003
0000003o0000o`0000P0o`0000<000000?ooo`3oool0:03oool00`000000oooo0?ooo`010?ooo`00
9@3ooolG000000T0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0040oooo000U0?ooo`800000503oool00`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?ooo`3oool09`3oool2000000<0oooo000U0?ooo`030000003oool0
oooo01<0oooo00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000
o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000
o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000
o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000
o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000
o`0000L0o`0000<000000?l0003o0000203o000<000002X0oooo00<000000?ooo`3oool00@3oool0
02D0oooo00<000000?ooo`3oool04`3oool00`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`00
00L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`00
00L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003oool0oooo
03<0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool04`3oool00`000000
o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o000<000003D0
oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool04`3oool;000000X0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0040oooo
000U0?ooo`030000003oool0oooo01d0oooo00<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00080?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00070?l000030000003oool0oooo03h0oooo00<000000?ooo`3oool00@3oool002D0oooo0P00000N
0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`0m
0?ooo`8000000`3oool002D0oooo00<000000?ooo`3oool07@3oool00`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`010?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool07@3oool00`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`010?ooo`001@3oool6000001X0oooo00<000000?ooo`3oool0
7@3oool00`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o0000
203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000
203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`010?ooo`001P3oool200000080oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0M0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000080?l000030000003o0000o`0000P0o`002`0000100?ooo`030000003o
ool0oooo0040oooo00050?ooo`030000003oool0oooo008000006`3oool2000001h0oooo00<00000
0?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<00000
0?l0003o0000203o00000`000000oooo0?ooo`170?ooo`8000000`3oool000D0oooo1P00000J0?oo
o`030000003oool0oooo01d0oooo00<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`180?oo
o`030000003oool0oooo0040oooo00050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool07@3oool<000000X0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l00003
0000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l00003
0000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003oool0oooo04P0oooo00<000000?ooo`3oool00@3oool000L0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000
203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000
203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool0
0@3oool000L0oooo0`00000K0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02P0oooo00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000
o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000
o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000
o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000
o`0000P0o`0000<000000?ooo`3oool0B03oool00`000000oooo0?ooo`010?ooo`001`3oool00`00
0000oooo0000000K0?ooo`800000:@3oool00`000000o`000?l000080?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`00
00P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`170?ooo`8000000`3oool000L0
oooo1000000J0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`010?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02P0oooo
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?oo
o`00000J0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`010?ooo`001`3oool4000000d0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`0X0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool00@3oool000L0oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0:03oool00`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`00
00<000000?l0003o0000203o00000`000000oooo0?ooo`180?ooo`030000003oool0oooo0040oooo
00080?ooo`<000003`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
0`00000X0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003oool0oooo04H0oooo0`0000030?ooo`001`3oool00`000000oooo0?oo
o`0>0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02P0oooo
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`010?ooo`00203oool3000000d0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02P0oooo
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`00
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00/0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?oo
o`0X0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool00@3oool000D0oooo1P00000J
0?ooo`030000003oool0oooo02P0oooo00<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0B03oool00`000000oooo0?ooo`01
0?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`800000:@3oool00`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00007
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`17
0?ooo`8000000`3oool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`0X
0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00007
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00007
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003oool0oooo04P0oooo00<000000?ooo`3oool00@3oool000P0oooo0P00000K0?oo
o`030000003oool0oooo02P0oooo00<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?ooo`3oool0B03oool00`000000oooo0?ooo`010?oo
o`009@3oool00`000000oooo0?ooo`0X0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003oool0oooo04P0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool0:03oool00`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`180?ooo`030000
003oool0oooo0040oooo00080?ooo`8000006`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
ool0oooo04P0oooo00<000000?ooo`3oool00@3oool000L0oooo0P0000000`3oool000000?ooo`0I
0?ooo`800000:@3oool<000000X0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00007
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`17
0?ooo`8000000`3oool000L0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo
03<0oooo00<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`00
00L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003oool0oooo
04P0oooo00<000000?ooo`3oool00@3oool000P0oooo00<000000?ooo`0000006P3oool00`000000
oooo0?ooo`0c0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000
o`000?l000070?l000030000003o0000o`0000P0o`003000001:0?ooo`030000003oool0oooo0040
oooo000U0?ooo`030000003oool0oooo03<0oooo00<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo03<0oooo00<0
00000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<0
00000?l0003o0000203o00000`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0040oooo0007
0?ooo`040000003oool0oooo000001X0oooo0P00000d0?ooo`030000003o0000o`0000P0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?ooo`3oool0DP3oool2000000<0oooo00070?ooo`@000006P3oool00`000000oooo0?ooo`0c
0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l00007
0?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`01
0?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo03<0oooo00<00000
0?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<00000
0?l0003o0000203o00000`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0040oooo00070?oo
o`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0<`3oool00`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l00008
0?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l00008
0?l000030000003oool0oooo05<0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?oo
o`3oool0<`3oool00`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000080?l000030000003oool0oooo05<0oooo00<000000?oo
o`3oool00@3oool002D0oooo00<000000?ooo`3oool0<`3oool00`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l00003
0000003oool0oooo05<0oooo00<000000?ooo`3oool00@3oool002D0oooo0P00000d0?ooo`030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000
003o0000o`0000P0o`0000<000000?ooo`3oool0DP3oool2000000<0oooo000U0?ooo`030000003o
ool0oooo03<0oooo00<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000L0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0040oooo000U0?ooo`030000003oool0oooo03<0oooo00<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o0000
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0040oooo000A0?ooo`D000000P3oool20000
00@0oooo0P0000050?ooo`030000003oool0oooo03<0oooo00<000000?l0003o0000203o00000`00
0000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`00
0000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`00
0000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo0040oooo000C0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0<`3oool00`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?l0003o00001`3o000<000005D0oooo00<000000?ooo`3oool00@3oool001<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3o
ool3000003<0oooo00<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000L0o`0000<000000?ooo`3oool0G03oool3000000<0oooo00080?ooo`8000002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03<0oooo00<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`010?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0<`3oool00`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0
003o00001`3o00000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo00070?ooo`04
0000003oool0oooo000000L0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?oo
o`3oool0<`3oool00`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0
003o00001`3o00000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo00080?ooo`80
00006`3oool00`000000oooo0?ooo`0c0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000o`000?l000070?l000030000003oool0oooo05h0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool0<`3oool<000000T0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o0000
1`3o00000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000U0?ooo`800000?`3o
ool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0G@3o
ool2000000<0oooo00070?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0?P3o
ool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`010?ooo`001P3oool5000001X0oooo00<000000?ooo`3oool0?P3oool0
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo000000020?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0?P3oool00`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`00
00P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`00
00L0o`0000<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000
oooo000000020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0?P3oool00`000000
o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000
o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`010?ooo`009@3oool2000003l0oooo00<000000?l0003o00001`3o00000`000000o`00
0?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003oool0oooo05d0oooo0P0000030?ooo`009@3oool00`000000oooo0?oo
o`0n0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l0
00080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo03h0oooo00<00000
0?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000070?l000030000003oool0oooo05h0oooo00<00000
0?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0?P3oool00`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`010?oo
o`009@3oool00`000000oooo0?ooo`0n0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o
00001`3o00000`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000
003oool0oooo03h0oooo00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l000030000
003oool0oooo05h0oooo00<000000?ooo`3oool00@3oool002D0oooo0P00000o0?ooo`030000003o
0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`002`00001O0?ooo`8000000`3oool002D0oooo00<000000?ooo`3oool0?P3oool0
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool0
00H0oooo1000000K0?ooo`030000003oool0oooo03h0oooo00<000000?l0003o00001`3o00000`00
0000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo0040oooo00050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0n0?ooo`030000003o0000o`0000L0
o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0
o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0
o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0?P3oool00`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool000H0oooo1000
000K0?ooo`800000?`3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000o`000?l000080?l000030000003oool0oooo06L0oooo0P00
00030?ooo`009@3oool00`000000oooo0?ooo`0n0?ooo`030000003o0000o`0000L0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<00000
0?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`0n0?oo
o`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003o0000o`0000P0o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`010?oo
o`00203oool2000001/0oooo00<000000?ooo`3oool0?P3oool00`000000o`000?l000070?l00003
0000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000070?l00003
0000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool0
00001P3oool500000080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003o0000o`0000P0o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`010?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?P3oool0
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool0
00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool3000003h0oooo2`00000:0?l000030000003o
0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1V0?ooo`<000000`3o
ool001<0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`180?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3o
ool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0B03oool00`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo0040oooo00080?ooo`800000203oool2000000@0oooo0`0000030?ooo`8000001@3oool0
0`000000oooo0?ooo`180?ooo`030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool0
00L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`180?ooo``000002P3o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool0
00L0oooo00@000000?ooo`3oool000006P3oool2000005@0oooo00<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003oool0oooo06L0oooo0P0000030?ooo`001`3oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o0000203o0000
0`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o0000
0`000000o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool0
02D0oooo00<000000?ooo`3oool0D`3oool00`000000o`000?l000080?l000030000003o0000o`00
00L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003o0000o`00
00P0o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`010?ooo`001`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o0000203o00000`000000
o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool000L0oooo
0`00000K0?ooo`030000003oool0oooo05<0oooo00<000000?l0003o0000203o00000`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000o`00
0?l000080?l000030000003oool0oooo06P0oooo00<000000?ooo`3oool00@3oool000X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000P0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0040oooo0007
0?ooo`030000003oool0000001/0oooo0P00001D0?ooo`030000003o0000o`0000P0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`003000001Y
0?ooo`8000000`3oool000L0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?l0
003o0000203o00000`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0
003o0000203o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo000:0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0D`3oool00`000000o`000?l000080?l00003
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0
D`3oool00`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
203o00000`000000o`000?l000080?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool0
0@3oool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003o0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003o0000o`0000P0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`001`3o
ool4000001X0oooo0P00001D0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0LP3o
ool2000000<0oooo00070?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0D`3o
ool00`000000o`000?l000080?l000030000003o0000o`0000L0o`0000<000000?l0003o0000203o
00000`000000o`000?l000080?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool00@3o
ool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003o
0000o`0000P0o`0000<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o
0000o`0000P0o`0000<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`009@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003o0000o`0000P0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1C0?ooo``000002@3o00000`00
0000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`010?ooo`002@3oool2000001X0oooo00<000000?ooo`3oool0GP3oool00`000000
o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool00000000001X0
oooo0P00001O0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000
o`000?l000080?l000030000003oool0oooo0780oooo0P0000030?ooo`001`3oool010000000oooo
00000000000J0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00001`3o00000`000000
o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`010?ooo`001`3oool4000001X0oooo00<000000?ooo`3oool0GP3oool00`000000o`00
0?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo0040oooo000:0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0GP3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo0007
0?ooo`040000003oool0oooo000000H0oooo100000030?ooo`800000103oool2000000D0oooo00<0
00000?ooo`3oool0GP3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?l0003o0000203o00000`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0040oooo0007
0?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`00
00<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003oool0oooo07<0oooo
00<000000?ooo`3oool00@3oool000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool3000005h0
oooo00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0
o`0000<000000?ooo`3oool0L@3oool3000000<0oooo00070?ooo`030000003oool0oooo00T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0
003o0000203o00000`000000o`000?l000080?l000030000003oool0oooo07<0oooo00<000000?oo
o`3oool00@3oool000P0oooo0`0000060?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05h0oooo00<0
00000?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo0?ooo`05
0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05h0oooo00<00000
0?l0003o00001`3o00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1N0?oo
o`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l0
00030000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool000P0oooo0P00000K0?ooo`80
0000G`3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?l0003o
0000203o00000`000000oooo0?ooo`1b0?ooo`8000000`3oool000L0oooo00@000000?ooo`3oool0
00006P3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00@3oool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1N0?ooo`03
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l00003
0000003oool0oooo07<0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool0
00006P3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o
0000203o00000`000000o`000?l000080?l000030000003oool0oooo07<0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool0GP3oool00`000000o`000?l000070?l000030000
003o0000o`0000P0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo0040oooo000U0?ooo`030000003oool0oooo05h0oooo00<000000?l0003o00001`3o
00000`000000o`000?l000080?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`010?ooo`00203oool2000001/0oooo0P00001O0?ooo`030000003o0000
o`0000L0o`0000<000000?l0003o0000203o00000`000000o`000?l000080?l000030000003oool0
oooo0780oooo0P0000030?ooo`001`3oool2000000030?ooo`000000oooo01T0oooo00<000000?oo
o`3oool0GP3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`003000001e0?oo
o`030000003oool0oooo0040oooo00070?ooo`80000000<0oooo0000003oool06@3oool00`000000
oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo0040oooo00080?ooo`030000003oool0000001X0oooo
00<000000?ooo`3oool0GP3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`00
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?oo
o`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0040oooo000U0?ooo`800000G`3oool00`000000o`000?l00007
0?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0O@3oool2000000<0oooo00070?oo
o`80000000<0oooo0000003oool06@3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`00
00L0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
0040oooo00070?ooo`80000000<0oooo0000003oool06@3oool00`000000oooo0?ooo`1N0?ooo`03
0000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo0040oooo00070?ooo`80000000<0oooo0000003oool06@3oool00`000000oooo
0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo0040oooo00070?ooo`030000003oool0000001/0oooo00<0
00000?ooo`3oool0GP3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1N
0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o00000`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0040oooo000U0?ooo`800000G`3oool00`000000o`000?l000070?l0
00030000003o0000o`0000P0o`0000<000000?ooo`3oool0O@3oool2000000<0oooo000U0?ooo`03
0000003oool0oooo05h0oooo00<000000?l0003o00001`3o00000`000000o`000?l000080?l00003
0000003oool0oooo07h0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0
GP3oool00`000000o`000?l000070?l000030000003o0000o`0000P0o`0000<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`010?ooo`004@3oool4000000<0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o0000203o
00000`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0040oooo000A0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo05h0oooo00<000000?l0003o00001`3o00000`000000o`000?l000080?l000030000
003oool0oooo07h0oooo00<000000?ooo`3oool00@3oool00180oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00001N0?ooo`030000
003o0000o`0000L0o`003000001n0?ooo`<000000`3oool001<0oooo00<000000?ooo`3oool00P3o
ool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1N0?ooo`030000
003o0000o`0000L0o`0000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`004@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`010?ooo`004P3oool2000000@0oooo0`0000030?ooo`800000
1@3oool00`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?ooo`3oool0
R@3oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1N0?ooo`030000003o
0000o`0000L0o`0000<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`010?ooo`009@3oool0
0`000000oooo0?ooo`1N0?ooo`030000003o0000o`0000L0o`0000<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`010?ooo`009@3oool2000005l0oooo00<000000?l0003o00001`3o00000`00
0000oooo0?ooo`280?ooo`8000000`3oool002D0oooo00<000000?ooo`3oool0GP3oool;000008/0
oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0m03oool00`000000oooo
0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0040oooo000U
0?ooooP000000`3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {2.7735, -51.0653, \
0.00466688, 1.80637}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-6.94444 111.111 0.0147151 0.00200205 [
[.16667 -0.0125 -15 -9 ]
[.16667 -0.0125 15 0 ]
[.38889 -0.0125 -15 -9 ]
[.38889 -0.0125 15 0 ]
[.61111 -0.0125 -15 -9 ]
[.61111 -0.0125 15 0 ]
[.83333 -0.0125 -12 -9 ]
[.83333 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -21.5625 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11482 -12 -4.5 ]
[-0.0125 .11482 0 4.5 ]
[-0.0125 .21492 -18 -4.5 ]
[-0.0125 .21492 0 4.5 ]
[-0.0125 .31502 -18 -4.5 ]
[-0.0125 .31502 0 4.5 ]
[-0.0125 .41513 -18 -4.5 ]
[-0.0125 .41513 0 4.5 ]
[-0.0125 .51523 -18 -4.5 ]
[-0.0125 .51523 0 4.5 ]
[-0.0125 .61533 -18 -4.5 ]
[-0.0125 .61533 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -62 ]
[-0.01875 .30902 -18 62 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(0.064)] .16667 -0.0125 0 1 Mshowa
.38889 0 m
.38889 .00625 L
s
[(0.066)] .38889 -0.0125 0 1 Mshowa
.61111 0 m
.61111 .00625 L
s
[(0.068)] .61111 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(0.07)] .83333 -0.0125 0 1 Mshowa
.125 Mabswid
.22222 0 m
.22222 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.44444 0 m
.44444 .00375 L
s
.5 0 m
.5 .00375 L
s
.55556 0 m
.55556 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.11111 0 m
.11111 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.88889 0 m
.88889 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Parameter) show
123.000 12.813 moveto
(b) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11482 m
.00625 .11482 L
s
[(50)] -0.0125 .11482 1 0 Mshowa
0 .21492 m
.00625 .21492 L
s
[(100)] -0.0125 .21492 1 0 Mshowa
0 .31502 m
.00625 .31502 L
s
[(150)] -0.0125 .31502 1 0 Mshowa
0 .41513 m
.00625 .41513 L
s
[(200)] -0.0125 .41513 1 0 Mshowa
0 .51523 m
.00625 .51523 L
s
[(250)] -0.0125 .51523 1 0 Mshowa
0 .61533 m
.00625 .61533 L
s
[(300)] -0.0125 .61533 1 0 Mshowa
.125 Mabswid
0 .03474 m
.00375 .03474 L
s
0 .05476 m
.00375 .05476 L
s
0 .07478 m
.00375 .07478 L
s
0 .0948 m
.00375 .0948 L
s
0 .13484 m
.00375 .13484 L
s
0 .15486 m
.00375 .15486 L
s
0 .17488 m
.00375 .17488 L
s
0 .1949 m
.00375 .1949 L
s
0 .23494 m
.00375 .23494 L
s
0 .25496 m
.00375 .25496 L
s
0 .27498 m
.00375 .27498 L
s
0 .295 m
.00375 .295 L
s
0 .33504 m
.00375 .33504 L
s
0 .35506 m
.00375 .35506 L
s
0 .37508 m
.00375 .37508 L
s
0 .39511 m
.00375 .39511 L
s
0 .43515 m
.00375 .43515 L
s
0 .45517 m
.00375 .45517 L
s
0 .47519 m
.00375 .47519 L
s
0 .49521 m
.00375 .49521 L
s
0 .53525 m
.00375 .53525 L
s
0 .55527 m
.00375 .55527 L
s
0 .57529 m
.00375 .57529 L
s
0 .59531 m
.00375 .59531 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -147.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
123 10.2813 translate
90 rotate
-123 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Number) show
105.000 12.813 moveto
(of) show
123.000 12.813 moveto
(Occurances) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.16667 .61178 m
.16667 .61803 L
s
.38889 .61178 m
.38889 .61803 L
s
.61111 .61178 m
.61111 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.22222 .61428 m
.22222 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.44444 .61428 m
.44444 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55556 .61428 m
.55556 .61803 L
s
.66667 .61428 m
.66667 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.11111 .61428 m
.11111 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.88889 .61428 m
.88889 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11482 m
1 .11482 L
s
.99375 .21492 m
1 .21492 L
s
.99375 .31502 m
1 .31502 L
s
.99375 .41513 m
1 .41513 L
s
.99375 .51523 m
1 .51523 L
s
.99375 .61533 m
1 .61533 L
s
.125 Mabswid
.99625 .03474 m
1 .03474 L
s
.99625 .05476 m
1 .05476 L
s
.99625 .07478 m
1 .07478 L
s
.99625 .0948 m
1 .0948 L
s
.99625 .13484 m
1 .13484 L
s
.99625 .15486 m
1 .15486 L
s
.99625 .17488 m
1 .17488 L
s
.99625 .1949 m
1 .1949 L
s
.99625 .23494 m
1 .23494 L
s
.99625 .25496 m
1 .25496 L
s
.99625 .27498 m
1 .27498 L
s
.99625 .295 m
1 .295 L
s
.99625 .33504 m
1 .33504 L
s
.99625 .35506 m
1 .35506 L
s
.99625 .37508 m
1 .37508 L
s
.99625 .39511 m
1 .39511 L
s
.99625 .43515 m
1 .43515 L
s
.99625 .45517 m
1 .45517 L
s
.99625 .47519 m
1 .47519 L
s
.99625 .49521 m
1 .49521 L
s
.99625 .53525 m
1 .53525 L
s
.99625 .55527 m
1 .55527 L
s
.99625 .57529 m
1 .57529 L
s
.99625 .59531 m
1 .59531 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02272 L
.05556 .02272 L
.05556 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02272 L
.05556 .02272 L
.05556 .01472 L
0 .01472 L
s
1 0 0 r
.05556 .01472 m
.05556 .03073 L
.11111 .03073 L
.11111 .01472 L
F
0 g
.05556 .01472 m
.05556 .03073 L
.11111 .03073 L
.11111 .01472 L
.05556 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .05876 L
.16667 .05876 L
.16667 .01472 L
F
0 g
.11111 .01472 m
.11111 .05876 L
.16667 .05876 L
.16667 .01472 L
.11111 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .11882 L
.22222 .11882 L
.22222 .01472 L
F
0 g
.16667 .01472 m
.16667 .11882 L
.22222 .11882 L
.22222 .01472 L
.16667 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .16687 L
.27778 .16687 L
.27778 .01472 L
F
0 g
.22222 .01472 m
.22222 .16687 L
.27778 .16687 L
.27778 .01472 L
.22222 .01472 L
s
1 0 0 r
.27778 .01472 m
.27778 .26898 L
.33333 .26898 L
.33333 .01472 L
F
0 g
.27778 .01472 m
.27778 .26898 L
.33333 .26898 L
.33333 .01472 L
.27778 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .37909 L
.38889 .37909 L
.38889 .01472 L
F
0 g
.33333 .01472 m
.33333 .37909 L
.38889 .37909 L
.38889 .01472 L
.33333 .01472 L
s
1 0 0 r
.38889 .01472 m
.38889 .49921 L
.44444 .49921 L
.44444 .01472 L
F
0 g
.38889 .01472 m
.38889 .49921 L
.44444 .49921 L
.44444 .01472 L
.38889 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .60332 L
.5 .60332 L
.5 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.5 .60332 L
.5 .01472 L
.44444 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .56728 L
.55556 .56728 L
.55556 .01472 L
F
0 g
.5 .01472 m
.5 .56728 L
.55556 .56728 L
.55556 .01472 L
.5 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .4832 L
.61111 .4832 L
.61111 .01472 L
F
0 g
.55556 .01472 m
.55556 .4832 L
.61111 .4832 L
.61111 .01472 L
.55556 .01472 L
s
1 0 0 r
.61111 .01472 m
.61111 .40512 L
.66667 .40512 L
.66667 .01472 L
F
0 g
.61111 .01472 m
.61111 .40512 L
.66667 .40512 L
.66667 .01472 L
.61111 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .27298 L
.72222 .27298 L
.72222 .01472 L
F
0 g
.66667 .01472 m
.66667 .27298 L
.72222 .27298 L
.72222 .01472 L
.66667 .01472 L
s
1 0 0 r
.72222 .01472 m
.72222 .18489 L
.77778 .18489 L
.77778 .01472 L
F
0 g
.72222 .01472 m
.72222 .18489 L
.77778 .18489 L
.77778 .01472 L
.72222 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .08879 L
.83333 .08879 L
.83333 .01472 L
F
0 g
.77778 .01472 m
.77778 .08879 L
.83333 .08879 L
.83333 .01472 L
.77778 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .06276 L
.88889 .06276 L
.88889 .01472 L
F
0 g
.83333 .01472 m
.83333 .06276 L
.88889 .06276 L
.88889 .01472 L
.83333 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .03273 L
.94444 .03273 L
.94444 .01472 L
F
0 g
.88889 .01472 m
.88889 .03273 L
.94444 .03273 L
.94444 .01472 L
.88889 .01472 L
s
1 0 0 r
.94444 .01472 m
.94444 .02272 L
1 .02272 L
1 .01472 L
F
0 g
.94444 .01472 m
.94444 .02272 L
1 .02272 L
1 .01472 L
.94444 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00O`3oool3000000@0oooo1@00
00000`3oool000000000000200000080oooo1`000000103oool000000?ooo`0000020?ooo`<00000
0`3oool2000000@0oooo0`0000020?ooo`@000001`3oool400000640oooo00200?ooo`030000003o
ool0oooo00<0oooo100000030?ooo`030000003oool0oooo0080oooo100000020?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo00000600oooo00200?oo
o`<000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00T000000?ooo`3oool000000?oo
o`000000oooo0000003oool0100000020?ooo`030000003oool0oooo00<0oooo100000030?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool00000H03oool00800oooo00@000000?ooo`3o
ool000000`3oool300000080oooo100000030?ooo`<0000000H0oooo00000000000000000?ooo`00
00030?ooo`8000000P3oool5000000<0oooo0P0000030?ooo`@00000203oool300000640oooo0020
0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1Q0?ooo`00O`3oool4000003P0oooo0P00001S0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00@`3oool2000000@0oooo0P0000040?ooo`8000000`3oool3000000D0oooo0`00
000J0?ooo`800000103oool2000000@0oooo0P0000030?ooo`<000000`3oool3000001/0oooo0P00
00040?ooo`800000103oool2000000<0oooo0`0000040?ooo`8000007`3oool2000000@0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`0S0?ooo`00@P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`0H0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001T0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000007@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool08`3oool00480oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo1@00000I0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000001T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000007@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool08`3oool0
0480oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`<000000`3o
ool010000000oooo0?ooo`00000J0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool3000000<0oooo0`00000J0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool3000000@0oooo0P00000N0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0R0?ooo`00@P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0000000J0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000007@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000903oool004<0oooo0P00000:0?ooo`800000103oool3000000@0oooo0P00
000K0?ooo`8000002P3oool2000000@0oooo0`0000030?ooo`<000006P3oool2000000X0oooo0P00
00040?ooo`<000000`3oool2000001l0oooo0P00000:0?ooo`8000000`3oool4000002@0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000X
0?oooo8000001P3oool002P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00240oooo0P0000050?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`00
803oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3o
ool0103oool00200oooo00@000000?ooo`3oool00000103oooob000000H0oooo000P0?ooo`040000
003oool0oooo000000@0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool0103oool00200oooo00@000000?ooo`3oool0
0000103oool?000000`0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`003`0000060?ooo`008@3oool2000000D0oooo00<000000?ooo`3oool0
2`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003oool0oooo00/0oooo00<000000?ooo`3oool0
103oool002P0oooo0P00000<0?ooo`h00000303o00000`000000o`000?l0000;0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000h00000303o
ool2000000H0oooo000X0?ooo`030000003oool0oooo01P0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool0
02P0oooo00<000000?ooo`3oool0603oool00`000000o`000?l0000:0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`00:03oool00`000000
oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo000X0?ooo`030000003oool0oooo01P0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo01P0oooo
00<000000?ooo`3oool0103oool002P0oooo0P00000I0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`0G0?ooo`8000001P3oool002P0oooo00<00000
0?ooo`3oool0603oool>000000d0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0603oool00`000000oooo0?ooo`04
0?ooo`00203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool09@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o000>000001X0oooo00<000000?ooo`3oool0103oool000P0oooo1P00000J0?ooo`03
0000003oool0oooo02D0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`00
2@3oool200000080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0U0?ooo`030000
003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003oool0oooo02D0oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool00P00
000K0?ooo`8000009P3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0T0?ooo`8000001P3oool000P0oooo1P00000J
0?ooo`030000003oool0oooo02D0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`04
0?ooo`00203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo00<000000?l0
003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`040?ooo`002P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02D0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000l0
00009`3oool00`000000oooo0?ooo`040?ooo`002P3oool3000001/0oooo00<000000?ooo`3oool0
9@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0H0?ooo`8000009P3o
ool00`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<P3o
ool2000000H0oooo000:0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool09@3oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`040?ooo`002P3oool4000001X0oooo00<000000?ooo`3oool09@3oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool09@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`040?ooo`002P3oool010000000oooo
0?ooo`00000<0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0U0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0oooo000:0?ooo`@000003`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00000U0?ooo`030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0a0?ooo`<000001P3oool0
00X0oooo00<000000?ooo`3oool03P3oool2000000<0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0U0?ooo`l00000303o00000`000000o`000?l0000:0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00@0oooo000;0?ooo`<000003@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0<`3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo03<0oooo00<000000?ooo`3oool0103oool000X0oooo00<000000?ooo`3oool03P3oool30000
00<0oooo0P0000050?ooo`030000003oool0oooo03<0oooo00<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0oooo000;0?ooo`<000006P3oool00`000000
oooo0?ooo`0c0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`040?ooo`00203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo
0P00000d0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<P3oool2000000H0oooo
00080?ooo`H000006P3oool00`000000oooo0?ooo`0c0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`040?ooo`002P3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo03<0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00@0oooo000:0?ooo`040000003oool0oooo000001X0oooo00<0
00000?ooo`3oool0<`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0103oool000/0oooo0P00000K0?ooo`800000=03oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003oool0oooo0380oooo0P0000060?ooo`00:03oool00`000000oooo0?ooo`0c0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`040?oo
o`00:03oool00`000000oooo0?ooo`0c0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`040?ooo`002`3oool2000001/0oooo00<000000?ooo`3oool0
<`3oool>000000`0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003oool0oooo03<0oooo00<000000?ooo`3oool0103oool000X0oooo0P0000000`3oool000000?oo
o`0I0?ooo`030000003oool0oooo0400oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`040?ooo`002P3oool2000000030?ooo`000000oooo01T0oooo0P0000110?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo0380oooo0P0000060?ooo`002`3oool00`000000oooo0000000J0?ooo`030000003oool0oooo
0400oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`040?ooo`00:03oool00`000000
oooo0?ooo`100?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool002P0oooo
00<000000?ooo`3oool0@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
3P00000e0?ooo`030000003oool0oooo00@0oooo000:0?ooo`040000003oool0oooo000001X0oooo
00<000000?ooo`3oool0@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`002P3oool4000001X0oooo0P00
00110?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`0o0?ooo`8000001P3oool000X0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?oo
o`100?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`100?ooo`030000003oool0oooo00@0oooo000:0?ooo`040000003oool0oooo000001X0oooo00<0
00000?ooo`3oool0@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`00503oool500000080oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo000F0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000o`000?l0000:0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`005P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`<00000@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0?P3oool3000000H0oooo000F0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`040?ooo`005P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0400oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo
0400oooo00<000000?ooo`3oool0103oool001D0oooo0P0000040?ooo`800000103oool2000000D0
oooo00<000000?ooo`3oool0@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`040?ooo`00:03oool00`000000oooo
0?ooo`100?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`100?ooo`030000003oool0oooo00@0oooo000X0?ooo`800000@@3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0?`3oool2000000H0oooo000;
0?ooo`8000006`3oool00`000000oooo0?ooo`100?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo000:0?oo
o`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0@03oool00`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0@03oool00`000000oooo0?ooo`04
0?ooo`002P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo0400oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo0400oooo00<00000
0?ooo`3oool0103oool000/0oooo0P00000K0?ooo`800000@@3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0?`3oool2000000H0oooo000X0?ooo`03
0000003oool0oooo0400oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo0400oooo00<000000?ooo`3oool0103oool002P0oooo00<000000?ooo`3oool0
@03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`040?ooo`002P3oool010000000oooo0?ooo`00000J0?ooo`030000
003oool0oooo0400oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000
003oool0oooo0400oooo00<000000?ooo`3oool0103oool000T0oooo1@00000J0?ooo`030000003o
ool0oooo0400oooo3P00000=0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000:0?l000030000003oool0oooo0400oooo00<000000?ooo`3oool0103o
ool000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0H0?ooo`800000CP3oool0
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o000>
00000440oooo0P0000060?ooo`00203oool00`000000oooo000000020?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0C@3oool00`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00@0oooo000X0?ooo`030000003oool0oooo04d0oooo00<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`040?ooo`00:03oool00`000000oooo0?ooo`1=0?ooo`030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo04d0oooo
00<000000?ooo`3oool0103oool002P0oooo00<000000?ooo`3oool0C@3oool00`000000o`000?l0
000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo00@0oooo000X0?ooo`800000CP3oool00`000000o`000?l0000;
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1<
0?ooo`8000001P3oool002P0oooo00<000000?ooo`3oool0C@3oool00`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo00@0oooo000X0?ooo`030000003oool0oooo04d0oooo00<000000?l0003o
00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`040?ooo`00503oool500000080oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`1=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000;0?l000030000003oool0oooo04d0oooo00<000000?ooo`3oool0
103oool001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`030000003o0000o`0000/0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo04d0
oooo00<000000?ooo`3oool0103oool000T0oooo100000090?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000C@3oool00`000000
o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`1;0?ooo`<000001P3oool000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0C@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0
oooo00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`1=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000;0?l000030000003oool0oooo04d0oooo00<000000?ooo`3oool0103oool000T0oooo
100000080?ooo`800000103oool3000000<0oooo0P0000050?ooo`030000003oool0oooo04d0oooo
00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`040?ooo`00:03oool00`000000oooo0?oo
o`1=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000;0?l000030000003oool0oooo04d0oooo00<000000?ooo`3oool0103oool002P0oooo0P00001>
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;
0?l000030000003oool0oooo04`0oooo0P0000060?ooo`002`3oool2000001/0oooo00<000000?oo
o`3oool0C@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0oooo000:0?ooo`04
0000003oool0oooo000001X0oooo00<000000?ooo`3oool0C@3oool00`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo00@0oooo000:0?ooo`040000003oool0oooo000001X0oooo00<000000?oo
o`3oool0C@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0oooo000:0?ooo`04
0000003oool0oooo000001X0oooo0P00001>0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo04`0oooo0P0000060?oo
o`00:03oool00`000000oooo0?ooo`1=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0103oool002P0oooo00<000000?ooo`3oool0C@3oool00`000000o`000?l0000;0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo00@0oooo000;0?ooo`8000006`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0103oool000X0oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000;0?l000030000003oool0oooo04d0oooo00<000000?ooo`3oool0103o
ool000X0oooo00@000000?ooo`3oool000006P3oool2000004h0oooo00<000000?l0003o00002`3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0C03o
ool2000000H0oooo000:0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0C@3o
ool?000000`0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo00@0oooo000X0?ooo`030000003oool0oooo05/0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003oool0oooo04d0oooo00<000000?ooo`3oool0103oool0
00X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1K0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00@0oooo000:0?ooo`<000006`3oool00`000000oooo0?ooo`1K0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0
oooo000=0?ooo`030000003oool0oooo01P0oooo0P00001L0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`1<0?ooo`8000001P3oool000X0oooo00<0
00000?ooo`0000006`3oool00`000000oooo0?ooo`1K0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002`3o00000`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0oooo000:
0?ooo`@000006P3oool00`000000oooo0?ooo`1K0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`003`00001?
0?ooo`030000003oool0oooo00@0oooo000=0?ooo`030000003oool0oooo00@0oooo100000030?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool0F`3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo05/0oooo00<000000?ooo`3oool0103oool001@0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0F`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0103oool000X0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool3000005/0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1I0?ooo`<000001P3oool000X0oooo1000
00080?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0F`3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo05/0oooo00<000000?ooo`3oool0103oool000X0oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`1K0?ooo`030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`040?ooo`002P3oool010000000oooo0?ooo`00
00070?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo05/0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00@0oooo000X
0?ooo`030000003oool0oooo05/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo00@0oooo000X0?ooo`800000G03oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo05X0oooo0P0000060?ooo`00303oool2000001X0oooo00<000000?ooo`3o
ool0F`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0103oool000X0oooo00@000000?ooo`00000000006P3oool00`000000oooo0?ooo`1K0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`040?ooo`00
2P3oool010000000oooo00000000000J0?ooo`030000003oool0oooo05/0oooo00<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00@0oooo000:0?ooo`@00000
6P3oool00`000000oooo0?ooo`1K0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0H0?ooo`800000G03o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000:0?l000030000003oool0oooo05X0oooo0P0000060?ooo`002P3oool0
10000000oooo0?ooo`00000J0?ooo`030000003oool0oooo05/0oooo00<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o
00000`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00@0oooo000:0?ooo`@000006P3oool0
0`000000oooo0?ooo`1K0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`040?ooo`002P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
05/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00@0oooo000:0?ooo`030000003oool0oooo01/0oooo0P00001L0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0FP3oool2000000H0oooo000;0?ooo`<000006P3oool00`000000oooo
0?ooo`1K0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`040?ooo`003@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05/0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`003P00
001M0?ooo`030000003oool0oooo00@0oooo000X0?ooo`030000003oool0oooo05/0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`040?ooo`002`3oool2000001/0oooo00<000000?oo
o`3oool0F`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00@0oooo000:0?ooo`04
0000003oool0oooo000001X0oooo0P00001L0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo06L0oooo0P0000060?oo
o`002P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo05/0oooo3P00000<0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`040?oo
o`002P3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo06P0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo06P0oooo00<000000?oo
o`3oool0103oool001@0oooo100000030?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0J03oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`040?ooo`00503oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1X0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00@0oooo000;0?ooo`800000203oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000006P0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000;0?l000030000003oool0oooo06H0oooo0`0000060?oo
o`002P3oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool2000000<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1X0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
00@0oooo000:0?ooo`80000000<0oooo0000003oool01@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1X
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo00@0oooo000;0?ooo`030000003oool0000000L0oooo0P0000040?oo
o`<000000`3oool2000000D0oooo00<000000?ooo`3oool0J03oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`040?oo
o`00:03oool00`000000oooo0?ooo`1X0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00@0oooo000X0?ooo`800000
J@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0
I`3oool2000000H0oooo000:0?ooo`80000000<0oooo0000003oool06@3oool00`000000oooo0?oo
o`1X0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo00@0oooo000:0?ooo`80000000<0oooo0000003oool06@3oool0
0`000000oooo0?ooo`1X0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00@0oooo000:0?ooo`80000000<0oooo0000
003oool06@3oool00`000000oooo0?ooo`1X0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00@0oooo000:0?ooo`03
0000003oool0000001/0oooo00<000000?ooo`3oool0J03oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000/0o`0000<000000?ooo`3oool0J03oool00`000000oooo0?ooo`040?ooo`00
:03oool2000006T0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003oool0oooo06L0oooo0P0000060?ooo`00:03oool00`000000oooo0?ooo`1X0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo00@0oooo000X0?ooo`030000003oool0oooo06P0oooo00<000000?l0003o00002P3o000?
000006X0oooo00<000000?ooo`3oool0103oool002P0oooo00<000000?ooo`3oool0J03oool00`00
0000o`000?l0000:0?l000030000003oool0oooo07H0oooo00<000000?ooo`3oool0103oool002P0
oooo0P00001Y0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0M@3oool2000000H0
oooo000X0?ooo`030000003oool0oooo06P0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo00@0oooo000X0?ooo`030000003oool0oooo06P0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00@0oooo000X
0?ooo`030000003oool0oooo06P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo00@0oooo000X0?ooo`030000003oool0oooo06P0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00@0oooo000X0?ooo`80
0000J@3oool00`000000o`000?l0000:0?l000030000003oool0oooo07D0oooo0P0000060?ooo`00
:03oool00`000000oooo0?ooo`1X0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`040?ooo`00:03oool00`000000oooo0?ooo`1X0?ooo`h00000N03o
ool00`000000oooo0?ooo`040?ooo`005@3oool2000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`3^0?ooo`030000003oool0oooo00@0oooo000D0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`005P3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`<000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo0`0000060?ooo`005`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oooob000000H0oooo000D0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00003l0?ooo`005@3oool2
000000@0oooo0P0000040?ooo`800000o@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.0609714, -58.4133, \
3.74517*^-05, 2.07852}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can easily calculate the mean and standard deviation in our parameters:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[alist]\), "\[IndentingNewLine]", 
    \(StandardDeviation[alist]\)}], "Input"],

Cell[BoxData[
    \(3.4491921852726386`\)], "Output"],

Cell[BoxData[
    \(0.16513066503831503`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[blist]\), "\[IndentingNewLine]", 
    \(StandardDeviation[blist]\)}], "Input"],

Cell[BoxData[
    \(0.06699779274867279`\)], "Output"],

Cell[BoxData[
    \(0.001421246205033097`\)], "Output"]
}, Open  ]],

Cell["\<\
So our simulation of the experiment has allowed us to estimate Mother \
Nature's True Parameters as \
\>", "Text"],

Cell[BoxData[{
    RowBox[{"a", " ", "=", " ", 
      RowBox[{"3.45", " ", 
        StyleBox["\[PlusMinus]",
          "InlineFormula"], 
        StyleBox[" ",
          "InlineFormula"], 
        StyleBox["0.16",
          "InlineFormula"]}]}], "\[IndentingNewLine]", 
    RowBox[{"b", " ", "=", " ", 
      RowBox[{"0.0670", " ", 
        StyleBox["\[PlusMinus]",
          "InlineFormula"], 
        StyleBox["0.0014",
          "InlineFormula"]}]}]}], "DisplayFormula"],

Cell["\<\
Note that these numbers may be slightly different if we rerun the code, since \
the random numbers will be different resulting in different distributions. Of \
course, if we do a large number of simulations the numbers should not be very \
different at the end--that is the important point! There is large amount of \
random error in the original experiment, so we shouldn't expect that we can \
get much better than this. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the Original Data Set to Create New Data Sets", "Subsubsection"],

Cell[TextData[{
  "In what we did above, we knew something about the process that was \
creating the data set that was measured. But what if we don't know the \
process that created the original data set? Then we cannot reasonably expect \
to create simulated data sets out of thin air. A lovely idea that has gained \
acceptance is the bootstrap method, in which simulated data sets are created \
",
  StyleBox["from the original data set",
    FontSlant->"Italic"],
  ". The name \"bootstrap\" comes from, I assume, the phrase \"pick yourself \
up by your own bootstraps\". "
}], "Text"],

Cell[TextData[{
  "What a weird idea. The key property that your original data set must have \
for this to work is that the original data set consists of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "independent and identically distributed data points."
}], "Text"],

Cell["\<\
Here is the idea used to create a new, simulated data set, from a small data \
set so we can see what is happening. The simplest method of bootstrapping is \
to to pick randomly from the original data set until you have a new data set \
which is the same size as the original. This will result in some points being \
duplicated, and some being left out entirely.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data\  = \ Table[{i, i}, {i, 1, 20}];\)\), "\[IndentingNewLine]", 
    \(\(datahyp\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(SeedRandom[3]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]datahyp\  = \ 
        Append[datahyp, Part[data, Random[Integer, {1, 20}]]], {i, 1, 
        20}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(TableForm[Sort[datahyp]]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"2", "2"},
          {"2", "2"},
          {"3", "3"},
          {"4", "4"},
          {"4", "4"},
          {"6", "6"},
          {"10", "10"},
          {"10", "10"},
          {"10", "10"},
          {"11", "11"},
          {"12", "12"},
          {"13", "13"},
          {"13", "13"},
          {"15", "15"},
          {"16", "16"},
          {"17", "17"},
          {"18", "18"},
          {"20", "20"},
          {"20", "20"},
          {"20", "20"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
We see in the above table that five data points have been duplicated from the \
data set, and seven data points deleted.\
\>", "Text"],

Cell["\<\
Let's try this method on our larger data set, and see what we get. The \
original data set is data0.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(datahyp0\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]datahyp0\  = \ 
        Append[datahyp0, Part[data0, Random[Integer, {1, 200}]]], {i, 1, 
        200}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(f[t_]\  = Fit[datahyp0, {1, t}, t]\), "\[IndentingNewLine]", 
    \(Regress[datahyp0, {1, t}, t, 
      RegressionReport \[Rule] {RSquared, 
          EstimatedVariance}]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(dataplot\  = \ 
        ListPlot[datahyp0, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(modelplot\  = \ 
        Plot[f[t], {t, 0, 200}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(Show[dataplot, modelplot, 
      DisplayFunction \[Rule] $DisplayFunction]\)}], "Input"],

Cell[BoxData[
    \(\(\(3.513667756619571`\)\(\[InvisibleSpace]\)\) + 
      0.06708223397033922`\ t\)], "Output"],

Cell[BoxData[
    \({RSquared \[Rule] 0.9156444351860732`, 
      EstimatedVariance \[Rule] 1.420381864136466`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 -0.112408 0.0408893 [
[.2619 .03865 -6 -9 ]
[.2619 .03865 6 0 ]
[.5 .03865 -9 -9 ]
[.5 .03865 9 0 ]
[.7381 .03865 -9 -9 ]
[.7381 .03865 9 0 ]
[.97619 .03865 -9 -9 ]
[.97619 .03865 9 0 ]
[.01131 .13293 -6 -4.5 ]
[.01131 .13293 0 4.5 ]
[.01131 .21471 -6 -4.5 ]
[.01131 .21471 0 4.5 ]
[.01131 .29649 -12 -4.5 ]
[.01131 .29649 0 4.5 ]
[.01131 .37826 -12 -4.5 ]
[.01131 .37826 0 4.5 ]
[.01131 .46004 -12 -4.5 ]
[.01131 .46004 0 4.5 ]
[.01131 .54182 -12 -4.5 ]
[.01131 .54182 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .05115 m
.2619 .0574 L
s
[(50)] .2619 .03865 0 1 Mshowa
.5 .05115 m
.5 .0574 L
s
[(100)] .5 .03865 0 1 Mshowa
.7381 .05115 m
.7381 .0574 L
s
[(150)] .7381 .03865 0 1 Mshowa
.97619 .05115 m
.97619 .0574 L
s
[(200)] .97619 .03865 0 1 Mshowa
.125 Mabswid
.07143 .05115 m
.07143 .0549 L
s
.11905 .05115 m
.11905 .0549 L
s
.16667 .05115 m
.16667 .0549 L
s
.21429 .05115 m
.21429 .0549 L
s
.30952 .05115 m
.30952 .0549 L
s
.35714 .05115 m
.35714 .0549 L
s
.40476 .05115 m
.40476 .0549 L
s
.45238 .05115 m
.45238 .0549 L
s
.54762 .05115 m
.54762 .0549 L
s
.59524 .05115 m
.59524 .0549 L
s
.64286 .05115 m
.64286 .0549 L
s
.69048 .05115 m
.69048 .0549 L
s
.78571 .05115 m
.78571 .0549 L
s
.83333 .05115 m
.83333 .0549 L
s
.88095 .05115 m
.88095 .0549 L
s
.92857 .05115 m
.92857 .0549 L
s
.25 Mabswid
0 .05115 m
1 .05115 L
s
.02381 .13293 m
.03006 .13293 L
s
[(6)] .01131 .13293 1 0 Mshowa
.02381 .21471 m
.03006 .21471 L
s
[(8)] .01131 .21471 1 0 Mshowa
.02381 .29649 m
.03006 .29649 L
s
[(10)] .01131 .29649 1 0 Mshowa
.02381 .37826 m
.03006 .37826 L
s
[(12)] .01131 .37826 1 0 Mshowa
.02381 .46004 m
.03006 .46004 L
s
[(14)] .01131 .46004 1 0 Mshowa
.02381 .54182 m
.03006 .54182 L
s
[(16)] .01131 .54182 1 0 Mshowa
.125 Mabswid
.02381 .07159 m
.02756 .07159 L
s
.02381 .09204 m
.02756 .09204 L
s
.02381 .11248 m
.02756 .11248 L
s
.02381 .15337 m
.02756 .15337 L
s
.02381 .17382 m
.02756 .17382 L
s
.02381 .19426 m
.02756 .19426 L
s
.02381 .23515 m
.02756 .23515 L
s
.02381 .2556 m
.02756 .2556 L
s
.02381 .27604 m
.02756 .27604 L
s
.02381 .31693 m
.02756 .31693 L
s
.02381 .33738 m
.02756 .33738 L
s
.02381 .35782 m
.02756 .35782 L
s
.02381 .39871 m
.02756 .39871 L
s
.02381 .41915 m
.02756 .41915 L
s
.02381 .4396 m
.02756 .4396 L
s
.02381 .48049 m
.02756 .48049 L
s
.02381 .50093 m
.02756 .50093 L
s
.02381 .52138 m
.02756 .52138 L
s
.02381 .03071 m
.02756 .03071 L
s
.02381 .01026 m
.02756 .01026 L
s
.02381 .56227 m
.02756 .56227 L
s
.02381 .58271 m
.02756 .58271 L
s
.02381 .60316 m
.02756 .60316 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.97143 .58034 Mdot
.96667 .56367 Mdot
.41429 .24642 Mdot
.59524 .29022 Mdot
.07143 .08755 Mdot
.80952 .45068 Mdot
.17143 .03811 Mdot
.89048 .58129 Mdot
.34286 .24664 Mdot
.18095 .05246 Mdot
.66667 .44465 Mdot
.68571 .47863 Mdot
.78095 .40135 Mdot
.39524 .16759 Mdot
.28571 .15091 Mdot
.67619 .44258 Mdot
.65714 .36555 Mdot
.49524 .32383 Mdot
.76667 .45851 Mdot
.45238 .34612 Mdot
.87143 .46881 Mdot
.37619 .30478 Mdot
.62381 .38088 Mdot
.56667 .38999 Mdot
.60476 .38204 Mdot
.13333 .05135 Mdot
.03333 .01472 Mdot
.85238 .55157 Mdot
.78095 .40135 Mdot
.31905 .21078 Mdot
.31905 .21078 Mdot
.65714 .36555 Mdot
.21429 .21028 Mdot
.79524 .55185 Mdot
.09048 .03606 Mdot
.71905 .35388 Mdot
.86667 .54014 Mdot
.15238 .11726 Mdot
.62857 .39192 Mdot
.9 .55354 Mdot
.40952 .18928 Mdot
.40476 .30812 Mdot
.89524 .58202 Mdot
.05714 .05616 Mdot
.3381 .28299 Mdot
.12857 .0961 Mdot
.81429 .45487 Mdot
.63333 .32823 Mdot
.41429 .24642 Mdot
.78095 .40135 Mdot
.67619 .44258 Mdot
.82857 .50487 Mdot
.58571 .39021 Mdot
.60952 .31245 Mdot
.54762 .36815 Mdot
.25714 .11444 Mdot
.27143 .1994 Mdot
.67619 .44258 Mdot
.97143 .58034 Mdot
.88571 .60332 Mdot
.40952 .18928 Mdot
.29048 .22389 Mdot
.4381 .26778 Mdot
.97619 .60115 Mdot
.03333 .01472 Mdot
.82381 .56493 Mdot
.48095 .21143 Mdot
.90952 .59465 Mdot
.69048 .35991 Mdot
.02857 .05957 Mdot
.31905 .21078 Mdot
.58095 .28504 Mdot
.90476 .45976 Mdot
.37143 .19152 Mdot
.23333 .08766 Mdot
.11905 .13525 Mdot
.7619 .51831 Mdot
.08571 .11569 Mdot
.3381 .28299 Mdot
.68095 .38938 Mdot
.58571 .39021 Mdot
.7 .44384 Mdot
.8619 .49094 Mdot
.94762 .51715 Mdot
.82857 .50487 Mdot
.44286 .204 Mdot
.97143 .58034 Mdot
.94762 .51715 Mdot
.12857 .0961 Mdot
.42381 .17915 Mdot
.25238 .1592 Mdot
.09524 .14491 Mdot
.8619 .49094 Mdot
.92381 .58251 Mdot
.81905 .41925 Mdot
.15714 .15791 Mdot
.64762 .37701 Mdot
.52857 .33805 Mdot
.11905 .13525 Mdot
.40476 .30812 Mdot
.25238 .1592 Mdot
.19048 .1546 Mdot
.32381 .26964 Mdot
.95714 .48853 Mdot
.28571 .15091 Mdot
.17143 .03811 Mdot
.87143 .46881 Mdot
.4619 .24908 Mdot
.32381 .26964 Mdot
.3 .20146 Mdot
.49524 .32383 Mdot
.25238 .1592 Mdot
.36667 .19274 Mdot
.62381 .38088 Mdot
.77619 .44177 Mdot
.6619 .34567 Mdot
.19524 .19273 Mdot
.22857 .09864 Mdot
.39524 .16759 Mdot
.12857 .0961 Mdot
.82381 .56493 Mdot
.0381 .06371 Mdot
.90952 .59465 Mdot
.82381 .56493 Mdot
.11429 .08344 Mdot
.20952 .17219 Mdot
.46667 .28151 Mdot
.22857 .09864 Mdot
.58571 .39021 Mdot
.75714 .4625 Mdot
.78571 .42384 Mdot
.3619 .26509 Mdot
.67143 .36509 Mdot
.28571 .15091 Mdot
.88095 .58121 Mdot
.07619 .03504 Mdot
.31429 .23651 Mdot
.27619 .11174 Mdot
.2619 .23418 Mdot
.18571 .09249 Mdot
.51429 .3241 Mdot
.40952 .18928 Mdot
.45714 .32609 Mdot
.13333 .05135 Mdot
.51429 .3241 Mdot
.11429 .08344 Mdot
.81429 .45487 Mdot
.19048 .1546 Mdot
.45714 .32609 Mdot
.7381 .43958 Mdot
.0381 .06371 Mdot
.38571 .2572 Mdot
.20476 .05263 Mdot
.51429 .3241 Mdot
.34286 .24664 Mdot
.11905 .13525 Mdot
.79524 .55185 Mdot
.37619 .30478 Mdot
.32857 .27189 Mdot
.70952 .35628 Mdot
.09524 .14491 Mdot
.72381 .50119 Mdot
.40952 .18928 Mdot
.39524 .16759 Mdot
.4 .17399 Mdot
.95714 .48853 Mdot
.03333 .01472 Mdot
.40952 .18928 Mdot
.76667 .45851 Mdot
.62857 .39192 Mdot
.11905 .13525 Mdot
.82381 .56493 Mdot
.77619 .44177 Mdot
.56667 .38999 Mdot
.8 .42492 Mdot
.20476 .05263 Mdot
.8381 .44218 Mdot
.68571 .47863 Mdot
.53333 .26589 Mdot
.6381 .44633 Mdot
.2381 .22303 Mdot
.14762 .04471 Mdot
.52857 .33805 Mdot
.14286 .13491 Mdot
.29524 .10753 Mdot
.85714 .56222 Mdot
.77619 .44177 Mdot
.18095 .05246 Mdot
.89524 .58202 Mdot
.3619 .26509 Mdot
.78571 .42384 Mdot
.44762 .34853 Mdot
.52381 .38782 Mdot
.53333 .26589 Mdot
.9 .55354 Mdot
.72857 .41564 Mdot
.25714 .11444 Mdot
.7619 .51831 Mdot
.93333 .55759 Mdot
.31905 .21078 Mdot
.5 Mabswid
.02381 .03126 m
.06244 .05352 L
.10458 .07779 L
.14415 .10058 L
.18221 .1225 L
.22272 .14584 L
.26171 .1683 L
.30316 .19217 L
.34309 .21517 L
.3815 .2373 L
.42237 .26084 L
.46172 .28351 L
.49955 .3053 L
.53984 .32851 L
.57861 .35084 L
.61984 .37459 L
.65954 .39746 L
.69774 .41946 L
.73838 .44287 L
.77751 .46541 L
.81909 .48936 L
.85916 .51244 L
.89771 .53465 L
.93871 .55827 L
.97619 .57985 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo
000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0>`3oool2
000000@0oooo0P00000e0?ooo`D000000P3oool2000000@0oooo0P00000c0?ooo`D000000P3oool2
000000@0oooo0P00000c0?ooo`@000000`3oool2000000@0oooo0P0000030?ooo`003`3oool40000
03T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000f0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool000l0oooo00@000000?ooo`0000000000?03oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo03@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool000l0oooo
00<000000?ooo`3oool0>`3oool2000000<0oooo00@000000?ooo`3oool00000=P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0oooo000003@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo0@0000010?ooo`40
oooo000?0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000f0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000380oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo000?0?ooo`030000003oool0oooo03/0
oooo0`0000030?ooo`800000=P3oool2000000@0oooo0P0000040?ooo`800000=03oool2000000@0
oooo0`0000030?ooo`800000=03oool2000000@0oooo0P0000040?ooo`8000000`3oool000l0oooo
0P00003o0?oooa00oooo000?0?ooo`<000002`3oool200000080oooo0P00003m0?ooo`003`3oool0
10000000oooo0?ooo`00000:0?ooo`8000000P3oool2000001@0oooo0P00003W0?ooo`003`3oool0
10000000oooo0?ooo`3oool200000280oooo0P00003W0?ooo`003`3oool00`000000oooo0?ooo`03
0?ooo`8000006P3oool200000>d0oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05`3oool200000>d0oooo00080?ooool000005P0000030?ooo`003`3oool00`000000oooo
0?ooo`060?ooo`<0000000<0oooo0000003oool02`3oool010000000oooo0?ooo`3oool2000000L0
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`80000000<0oooo0000003oool0303oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`070?ooo`003`3oool3000000H0oooo0P0000000`3oool000000000000d0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00L0oooo000?0?ooo`D000002@3oool200000?l0oooo0P3oool000l0oooo00<0
00000?ooo`3oool00P00000;0?ooo`800000o`3oool000l0oooo00<000000?ooo`3oool03`3oool2
00000?d0oooo000?0?ooo`8000004P3oool200000?/0oooo000?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0n03oool000l0oooo00<000000?ooo`3oool0503oool300000?L0oooo
000?0?ooo`030000003oool0oooo01D0oooo0P00003g0?ooo`003`3oool00`000000oooo0?ooo`0:
0?ooo`8000002`3oool2000001d0oooo0P00003F0?ooo`003`3oool2000000/0oooo0P00000=0?oo
o`8000003P3oool2000000/0oooo0P00003F0?ooo`003`3oool00`000000oooo0?ooo`0I0?ooo`<0
00003@3oool200000><0oooo000?0?ooo`030000003oool0oooo01T0oooo0P0000000`3oool00000
0000000G0?ooo`800000e`3oool000l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0D0?ooo`800000e`3oool000l0oooo00<000000?ooo`3oool07`3oool2000002H0oooo0P000035
0?ooo`003`3oool00`000000oooo0?ooo`0Q0?ooo`8000007`3oool2000000<0oooo0P0000350?oo
o`003`3oool2000000h0oooo0P00000D0?ooo`800000603oool2000000<0oooo0P00003:0?ooo`00
3`3oool00`000000oooo0?ooo`0=0?ooo`8000004@3oool2000000<0oooo0P00000F0?ooo`800000
c`3oool000l0oooo00<000000?ooo`3oool0803oool2000000D0oooo0P00003U0?ooo`001`3oool3
000000D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3R0?ooo`001`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo02X0oooo0P00003R0?ooo`001`3oool01000
0000oooo0?ooo`0000040?ooo`<00000;03oool200000>00oooo00070?ooo`<000001@3oool00`00
0000oooo0?ooo`0G0?ooo`800000103oool2000000l0oooo0P00003N0?ooo`00203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo0P0000040?ooo`8000004@3oool200000=`0
oooo00080?ooo`<00000103oool00`000000oooo0?ooo`0@0?ooo`800000803oool200000=X0oooo
000?0?ooo`030000003oool0oooo0100oooo0P00000R0?ooo`030000003oool0oooo0=L0oooo000?
0?ooo`030000003oool0oooo03D0oooo0P00000>0?ooo`800000a`3oool000l0oooo0P00000[0?oo
o`8000002`3oool2000000`0oooo0P0000370?ooo`003`3oool00`000000oooo0?ooo`0Q0?ooo`80
00001`3oool2000000d0oooo1000003A0?ooo`003`3oool00`000000oooo0?ooo`0Q0?ooo`800000
603oool200000=40oooo000?0?ooo`030000003oool0oooo03d0oooo0P00003?0?ooo`003`3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo0P00002Y0?ooo`003`3oool00`00
0000oooo0?ooo`0`0?ooo`8000003P3oool200000240oooo0`00002X0?ooo`003`3oool200000340
oooo0P00000@0?ooo`030000003oool0oooo01l0oooo0P00002X0?ooo`003`3oool00`000000oooo
0?ooo`130?ooo`8000009P3oool200000:40oooo000?0?ooo`030000003oool0oooo04D0oooo0P00
000T0?ooo`800000X@3oool000l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`34
0?ooo`003`3oool00`000000oooo0?ooo`180?ooo`8000004P3oool2000000T0oooo0P00002U0?oo
o`003`3oool2000002d0oooo0P00000L0?ooo`030000003oool0oooo00h0oooo0`0000090?ooo`80
0000Y@3oool000l0oooo00<000000?ooo`3oool0;03oool2000001<0oooo0P0000080?ooo`800000
3P3oool200000;40oooo000?0?ooo`030000003oool0oooo0440oooo0P0000060?ooo`8000000P3o
ool200000;l0oooo000?0?ooo`030000003oool0oooo04T0oooo0P0000040?ooo`8000007`3oool2
000009`0oooo00080?ooo`8000001@3oool00`000000oooo0?ooo`0a0?ooo`8000007P3oool20000
01d0oooo0P00002L0?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0340oooo0P00000K0?ooo`8000000`3oool2000002D0oooo0P00002B0?ooo`001`3oool010000000
oooo0?ooo`0000040?ooo`<00000CP3oool2000000D0oooo00<000000?ooo`3oool08P3oool20000
0980oooo00080?ooo`8000001@3oool00`000000oooo0?ooo`1F0?ooo`800000]P3oool000L0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0g0?ooo`8000003@3oool200000100
oooo0P00002d0?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0=`3oool2000000d0oooo
0P00000B0?ooo`800000/P3oool000l0oooo00<000000?ooo`3oool0G03oool200000;00oooo000?
0?ooo`030000003oool0oooo03h0oooo0P00000N0?ooo`800000[P3oool000l0oooo0P00000o0?oo
o`800000303oool200000180oooo00<000000?ooo`3oool0Z`3oool000l0oooo00<000000?ooo`3o
ool0C03oool2000001<0oooo0P00002[0?ooo`003`3oool00`000000oooo0?ooo`1D0?ooo`800000
3@3oool00`000000oooo0?ooo`020?ooo`800000Y03oool000l0oooo00<000000?ooo`3oool0E03o
ool2000000h0oooo0P0000020?ooo`8000002`3oool2000009L0oooo000?0?ooo`030000003oool0
oooo06H0oooo0P00000=0?ooo`800000U`3oool000l0oooo0P00001Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`2S0?ooo`003`3oool00`000000oooo0?ooo`1P0?ooo`8000001`3oool200000:<0
oooo000?0?ooo`030000003oool0oooo05X0oooo0P00000?0?ooo`030000003oool0oooo0:00oooo
000?0?ooo`030000003oool0oooo05X0oooo0P00000@0?ooo`80000000<0oooo000000000000603o
ool2000008<0oooo000?0?ooo`030000003oool0oooo04l0oooo0`00000L0?ooo`<00000603oool2
000008<0oooo000?0?ooo`030000003oool0oooo04l0oooo0`00000N0?ooo`800000W03oool000l0
oooo0P00001c0?ooo`800000VP3oool000l0oooo00<000000?ooo`3oool0D`3oool2000001l0oooo
1000002F0?ooo`003`3oool00`000000oooo0?ooo`1C0?ooo`8000008@3oool2000001h0oooo0P00
001f0?ooo`003`3oool00`000000oooo0?ooo`1g0?ooo`8000007@3oool200000080oooo0P00001b
0?ooo`0000<0oooo0000000000000`0000020?ooo`8000001@3oool00`000000oooo0?ooo`1i0?oo
o`8000007`3oool200000780oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0T03oool000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo0`00001l0?oo
o`800000T03oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0GP3oool2000001h0oooo0P00002>0?ooo`000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1N0?oo
o`8000001@3oool2000001T0oooo00<000000?ooo`3oool0R`3oool00080oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`1U0?ooo`8000006P3oool2000008/0oooo000?0?ooo`030000
003oool0oooo08<0oooo0P00000I0?ooo`800000KP3oool000l0oooo0P0000260?ooo`8000005`3o
ool2000006h0oooo000?0?ooo`030000003oool0oooo08L0oooo0P0000250?ooo`003`3oool00`00
0000oooo0?ooo`1d0?ooo`800000203oool2000000@0oooo0P0000030?ooo`800000P`3oool000l0
oooo00<000000?ooo`3oool0M03oool2000000P0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0?ooo`0F0?ooo`800000J03oool000l0oooo00<000000?ooo`3oool0S03oool2000001H0oooo
0P00001X0?ooo`003`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo07d0oooo000?
0?ooo`800000R@3oool2000000D0oooo0P00001m0?ooo`003`3oool00`000000oooo0?ooo`280?oo
o`8000001`3oool2000007/0oooo000?0?ooo`030000003oool0oooo0740oooo1000000N0?ooo`03
0000003oool0oooo01H0oooo0P00001P0?ooo`003`3oool00`000000oooo0?ooo`1a0?ooo`@00000
7`3oool2000001H0oooo0P00001P0?ooo`003`3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo02<0oooo0P00001@0?ooo`003`3oool2000009P0oooo0P00000P0?ooo`80000000<0oooo
000000000000D03oool000l0oooo00<000000?ooo`3oool0V@3oool2000001T0oooo0P0000030?oo
o`800000D`3oool000l0oooo00<000000?ooo`3oool0V`3oool2000000h0oooo0P0000020?ooo`80
00000`3oool2000005P0oooo000?0?ooo`030000003oool0oooo08d0oooo0P00000>0?ooo`800000
303oool200000080oooo0P00001M0?ooo`0000<0oooo0000000000000`0000000`3oool000000000
0002000000@0oooo00<000000?ooo`3oool0S@3oool200000100oooo0P00001]0?ooo`000`3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`040?ooo`800000I03oool000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`<00000XP3oool2000000@0oooo0P00001T0?ooo`000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0W@3oool2000000<0oooo1000001X0?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`260?ooo`8000005@3oool2000000L0oooo0P00001V0?ooo`000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo08H0oooo0P00000:0?ooo`8000000`3oool2000000X0
oooo0P0000030?ooo`800000203oool2000005X0oooo000?0?ooo`030000003oool0oooo0980oooo
0P0000030?ooo`8000002P3oool2000000D0oooo0P0000060?ooo`800000FP3oool000l0oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`1O0?ooo`003`3oool200000:h0oooo0P00000N
0?ooo`800000?`3oool000l0oooo00<000000?ooo`3oool0[`3oool2000001`0oooo0P00000o0?oo
o`003`3oool00`000000oooo0?ooo`2a0?ooo`800000F`3oool000l0oooo00<000000?ooo`3oool0
/`3oool2000005T0oooo000?0?ooo`030000003oool0oooo0;D0oooo0P0000080?ooo`800000C@3o
ool000l0oooo0P00002h0?ooo`030000003oool0oooo00D0oooo0P00000G0?ooo`800000=03oool0
00l0oooo00<000000?ooo`3oool0^03oool2000001@0oooo0P0000080?ooo`800000=03oool000l0
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool2000003X0
oooo000?0?ooo`030000003oool0oooo0;/0oooo0P00000E0?ooo`800000>P3oool000l0oooo00<0
00000?ooo`3oool0_@3oool2000004l0oooo000?0?ooo`030000003oool0oooo0;l0oooo00<00000
0?ooo`3oool0C03oool000l0oooo0P00002a0?ooo`8000003P3oool3000000T0oooo0P00000?0?oo
o`800000;`3oool000l0oooo00<000000?ooo`3oool0YP3oool2000000H0oooo100000050?ooo`80
0000203oool2000000T0oooo0P00000?0?ooo`800000;`3oool000l0oooo00<000000?ooo`3oool0
YP3oool2000000H0oooo0P0000070?ooo`8000002P3oool2000004T0oooo000?0?ooo`030000003o
ool0oooo0<D0oooo0P00000>0?ooo`800000=`3oool000030?ooo`000000000000<000000`3oool3
000000<0oooo00<000000?ooo`3oool0a`3oool2000000`0oooo0`00000f0?ooo`000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0b@3oool20000
00/0oooo0P00000G0?ooo`8000007@3oool000<0oooo00@000000?ooo`3oool0oooo1@0000030?oo
o`<00000a`3oool600000280oooo0P00000M0?ooo`000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`370?ooo`800000103oool00`00
0000oooo0?ooo`0n0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0cP3oool2000001H0oooo0P00000V0?ooo`000P3oool2000000D0oooo
0P0000040?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool04`3oool2000002H0oooo
000?0?ooo`030000003oool0oooo0;<0oooo0P00000L0?ooo`800000>`3oool000l0oooo0P00002d
0?ooo`8000007P3oool2000003T0oooo000?0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool0=P3oool000l0oooo00<000000?ooo`3oool0eP3oool2000002H0oooo0P00000>0?ooo`00
3`3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0oooo00P0oooo0P00000I0?ooo`800000
3P3oool000l0oooo00<000000?ooo`3oool0f@3oool2000000P0oooo0P00000Y0?ooo`003`3oool0
0`000000oooo0?ooo`3K0?ooo`800000<@3oool000l0oooo0P00002n0?ooo`8000007P3oool20000
02l0oooo000?0?ooo`030000003oool0oooo0;d0oooo0P00000K0?ooo`8000000`3oool2000002d0
oooo000?0?ooo`030000003oool0oooo0=X0oooo0P0000050?ooo`800000:`3oool000l0oooo00<0
00000?ooo`3oool0h`3oool00`000000oooo0?ooo`0X0?ooo`003`3oool00`000000oooo0?ooo`38
0?ooo`8000006P3oool2000001D0oooo0P00000A0?ooo`003`3oool00`000000oooo0?ooo`380?oo
o`800000703oool2000001<0oooo0P00000A0?ooo`003`3oool200000>T0oooo0P00000T0?ooo`00
3`3oool00`000000oooo0?ooo`3Z0?ooo`8000008P3oool000l0oooo00<000000?ooo`3oool0k03o
ool200000200oooo00000`3oool0000000000003000000040?ooo`0000000000000000D0oooo00<0
00000?ooo`3oool0kP3oool00`000000oooo0?ooo`0M0?ooo`000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3U0?ooo`800000203o
ool2000001d0oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooo`<00000i@3oool2000000X0oooo00<000000?ooo`3oool06P3oool000<0oooo00@00000
0?ooo`3oool0oooo0`0000050?ooo`030000003oool0oooo0?80oooo0P00000J0?ooo`000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0h@3oool2
00000140oooo0P00000H0?ooo`000P3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo
0=40oooo0P00000>0?ooo`8000002`3oool2000000H0oooo00<000000?ooo`3oool05@3oool000l0
oooo00<000000?ooo`3oool0d@3oool2000001/0oooo0P0000070?ooo`8000005@3oool000l0oooo
00<000000?ooo`3oool0hP3oool2000001<0oooo0`00000D0?ooo`003`3oool200000=X0oooo0P00
00070?ooo`8000005P3oool2000000@0oooo0P00000<0?ooo`003`3oool00`000000oooo0?ooo`3I
0?ooo`8000008@3oool200000080oooo0P00000<0?ooo`003`3oool00`000000oooo0?ooo`3n0?oo
o`8000003P3oool000l0oooo00<000000?ooo`3oool0o`3oool10?ooo`800000303oool000l0oooo
00<000000?ooo`3oool0o`3oool30?ooo`8000002P3oool000l0oooo0P00003Z0?ooo`H000001@3o
ool2000000`0oooo0`0000090?ooo`003`3oool00`000000oooo0?ooo`3Y0?ooo`H000001@3oool2
000001P0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3o
ool0l@3oool2000001/0oooo000?0?ooo`030000003oool0oooo0?40oooo0P00000K0?ooo`003`3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo0P0000090?ooo`003`3oool200000>/0oooo0P00000G
0?ooo`8000002@3oool000l0oooo00<000000?ooo`3oool0jP3oool200000280oooo000?0?ooo`03
0000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`003`3o
ool00`000000oooo0?ooo`3o0?ooo`l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.767, 2.45813, 0.761756, \
0.0887128}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Well, we got something different. Let's try doing 2000 simulations, and \
seeing what we get for ",
  Cell[BoxData[
      \(TraditionalForm\`a\ and\ b\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(numdatasets\  = \ 2000;\)\), "\[IndentingNewLine]", 
    \(\(alist\  = \ {};\)\), "\[IndentingNewLine]", 
    \(\(blist\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Do[\[IndentingNewLine]{\[IndentingNewLine]datahyp0\  = \ {}, \
\[IndentingNewLine]Do[\[IndentingNewLine]datahyp0\  = \ 
            Append[datahyp0, Part[data0, Random[Integer, {1, 200}]]], {i, 1, 
            200}], \[IndentingNewLine]\[IndentingNewLine]f[t_]\  = 
          Fit[datahyp0, {1, t}, 
            t], \[IndentingNewLine]\[IndentingNewLine]alist\  = \ 
          Append[alist, Part[f[t], 1]], \[IndentingNewLine]blist\  = \ 
          Append[blist, Part[f[t], 2, 1]]}, {i, 1, numdatasets}]\)}], "Input"],

Cell["\<\
The best way to present the information that we have collected for the \
parameters is in a histogram.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Histogram[alist, HistogramCategories \[Rule] 20, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Parameter a\>", \ "\<Number of \
Occurances\>"}]\), "\[IndentingNewLine]", 
    \(Histogram[blist, HistogramCategories \[Rule] 20, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<Parameter b\>", \ "\<Number of \
Occurances\>"}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.36 0.8 0.0147151 0.00249408 [
[.04 -0.0125 -3 -9 ]
[.04 -0.0125 3 0 ]
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.36 -0.0125 -9 -9 ]
[.36 -0.0125 9 0 ]
[.52 -0.0125 -9 -9 ]
[.52 -0.0125 9 0 ]
[.68 -0.0125 -9 -9 ]
[.68 -0.0125 9 0 ]
[.84 -0.0125 -3 -9 ]
[.84 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -21.5625 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13942 -12 -4.5 ]
[-0.0125 .13942 0 4.5 ]
[-0.0125 .26412 -18 -4.5 ]
[-0.0125 .26412 0 4.5 ]
[-0.0125 .38883 -18 -4.5 ]
[-0.0125 .38883 0 4.5 ]
[-0.0125 .51353 -18 -4.5 ]
[-0.0125 .51353 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -62 ]
[-0.01875 .30902 -18 62 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04 0 m
.04 .00625 L
s
[(3)] .04 -0.0125 0 1 Mshowa
.2 0 m
.2 .00625 L
s
[(3.2)] .2 -0.0125 0 1 Mshowa
.36 0 m
.36 .00625 L
s
[(3.4)] .36 -0.0125 0 1 Mshowa
.52 0 m
.52 .00625 L
s
[(3.6)] .52 -0.0125 0 1 Mshowa
.68 0 m
.68 .00625 L
s
[(3.8)] .68 -0.0125 0 1 Mshowa
.84 0 m
.84 .00625 L
s
[(4)] .84 -0.0125 0 1 Mshowa
.125 Mabswid
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.4 0 m
.4 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.56 0 m
.56 .00375 L
s
.6 0 m
.6 .00375 L
s
.64 0 m
.64 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.8 0 m
.8 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Parameter) show
123.000 12.813 moveto
(a) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13942 m
.00625 .13942 L
s
[(50)] -0.0125 .13942 1 0 Mshowa
0 .26412 m
.00625 .26412 L
s
[(100)] -0.0125 .26412 1 0 Mshowa
0 .38883 m
.00625 .38883 L
s
[(150)] -0.0125 .38883 1 0 Mshowa
0 .51353 m
.00625 .51353 L
s
[(200)] -0.0125 .51353 1 0 Mshowa
.125 Mabswid
0 .03966 m
.00375 .03966 L
s
0 .0646 m
.00375 .0646 L
s
0 .08954 m
.00375 .08954 L
s
0 .11448 m
.00375 .11448 L
s
0 .16436 m
.00375 .16436 L
s
0 .1893 m
.00375 .1893 L
s
0 .21424 m
.00375 .21424 L
s
0 .23918 m
.00375 .23918 L
s
0 .28906 m
.00375 .28906 L
s
0 .31401 m
.00375 .31401 L
s
0 .33895 m
.00375 .33895 L
s
0 .36389 m
.00375 .36389 L
s
0 .41377 m
.00375 .41377 L
s
0 .43871 m
.00375 .43871 L
s
0 .46365 m
.00375 .46365 L
s
0 .48859 m
.00375 .48859 L
s
0 .53847 m
.00375 .53847 L
s
0 .56341 m
.00375 .56341 L
s
0 .58835 m
.00375 .58835 L
s
0 .6133 m
.00375 .6133 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -147.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
123 10.2813 translate
90 rotate
-123 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Number) show
105.000 12.813 moveto
(of) show
123.000 12.813 moveto
(Occurances) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04 .61178 m
.04 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.36 .61178 m
.36 .61803 L
s
.52 .61178 m
.52 .61803 L
s
.68 .61178 m
.68 .61803 L
s
.84 .61178 m
.84 .61803 L
s
.125 Mabswid
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13942 m
1 .13942 L
s
.99375 .26412 m
1 .26412 L
s
.99375 .38883 m
1 .38883 L
s
.99375 .51353 m
1 .51353 L
s
.125 Mabswid
.99625 .03966 m
1 .03966 L
s
.99625 .0646 m
1 .0646 L
s
.99625 .08954 m
1 .08954 L
s
.99625 .11448 m
1 .11448 L
s
.99625 .16436 m
1 .16436 L
s
.99625 .1893 m
1 .1893 L
s
.99625 .21424 m
1 .21424 L
s
.99625 .23918 m
1 .23918 L
s
.99625 .28906 m
1 .28906 L
s
.99625 .31401 m
1 .31401 L
s
.99625 .33895 m
1 .33895 L
s
.99625 .36389 m
1 .36389 L
s
.99625 .41377 m
1 .41377 L
s
.99625 .43871 m
1 .43871 L
s
.99625 .46365 m
1 .46365 L
s
.99625 .48859 m
1 .48859 L
s
.99625 .53847 m
1 .53847 L
s
.99625 .56341 m
1 .56341 L
s
.99625 .58835 m
1 .58835 L
s
.99625 .6133 m
1 .6133 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01721 L
.04 .01721 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01721 L
.04 .01721 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .01472 L
.08 .01472 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .01472 L
.08 .01472 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .0197 L
.12 .0197 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .0197 L
.12 .0197 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .04215 L
.16 .04215 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .04215 L
.16 .04215 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .03966 L
.2 .03966 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .03966 L
.2 .03966 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .0621 L
.24 .0621 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .0621 L
.24 .0621 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .15688 L
.28 .15688 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .15688 L
.28 .15688 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .17932 L
.32 .17932 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .17932 L
.32 .17932 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .30403 L
.36 .30403 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .30403 L
.36 .30403 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .33146 L
.4 .33146 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .33146 L
.4 .33146 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .42873 L
.44 .42873 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .42873 L
.44 .42873 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .57339 L
.48 .57339 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .57339 L
.48 .57339 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .54845 L
.52 .54845 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .54845 L
.52 .54845 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .60332 L
.56 .60332 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .60332 L
.56 .60332 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .53598 L
.6 .53598 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .53598 L
.6 .53598 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .4437 L
.64 .4437 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .4437 L
.64 .4437 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .36389 L
.68 .36389 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .36389 L
.68 .36389 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .24417 L
.72 .24417 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .24417 L
.72 .24417 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .17683 L
.76 .17683 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .17683 L
.76 .17683 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .09951 L
.8 .09951 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .09951 L
.8 .09951 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .06709 L
.84 .06709 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .06709 L
.84 .06709 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .04464 L
.88 .04464 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .04464 L
.88 .04464 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .02469 L
.92 .02469 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .02469 L
.92 .02469 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .01472 L
.96 .01472 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .01472 L
.96 .01472 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .0197 L
1 .0197 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .0197 L
1 .0197 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P03oool3000000@0oooo1@00
00000`3oool000000000000200000080oooo1`000000103oool000000?ooo`0000020?ooo`<00000
0`3oool2000000@0oooo0`0000020?ooo`@00000203oool5000005h0oooo00210?ooo`030000003o
ool0oooo00<0oooo100000030?ooo`030000003oool0oooo0080oooo100000020?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`@00000G`3oool00840oooo0`0000060?ooo`05
0000003oool0oooo0?ooo`0000001`3oool02@000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`0400000080oooo00<000000?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`1M0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`<00000
0P3oool4000000<0oooo0`0000001P3oool00000000000000000oooo000000<0oooo0P0000020?oo
o`D000000`3oool2000000<0oooo100000090?ooo`<00000G`3oool00840oooo00@000000?ooo`3o
ool00000803oool00`000000oooo0?ooo`1h0?ooo`00P03oool4000009`0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000^0?ooo`800000803oool2000000@0oooo0P0000030?oo
o`@00000603oool2000000@0oooo0P0000050?ooo`<000005`3oool2000000@0oooo0P0000030?oo
o`<000006P3oool2000000@0oooo0P0000040?ooo`800000803oool3000002T0oooo000]0?ooo`04
0000003oool0oooo000001h0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0H
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool05@3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000001P0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000P0?ooo`030000003oool0oooo02P0oooo000_0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00L0oooo1@00000H0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000006P3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000001d0oooo1@00000Y0?ooo`00<03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool01P3o
ool3000001`0oooo00<000000?ooo`3oool01`3oool2000001h0oooo00@000000?ooo`3oool00000
:P3oool002d0oooo00@000000?ooo`3oool000007P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000001L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000G
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0603oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`000000:P3oool002h0oooo
0P00000P0?ooo`8000002P3oool2000001T0oooo0P00000;0?ooo`800000603oool2000000X0oooo
0`00000I0?ooo`8000002P3oool200000200oooo0P00000Z0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009@3ooooh000000<0oooo000U
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00@3oool001h0oooo0P0000050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool00@3oool001d0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo0040oooo000M0?ooo`04
0000003oool0oooo000000@0oooon00000030?ooo`007@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0140oooo2`0000090?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?oo
o`3oool01`3oool;000000<0oooo000M0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool06`3oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000/000004`3oool00`000000oooo0?ooo`010?oo
o`007P3oool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003oool0oooo01/0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0
6`3oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003oool0oooo01/0oooo00<000000?ooo`3oool0
0@3oool002D0oooo00<000000?ooo`3oool06`3oool00`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00@3oool002D0oooo0P00000L0?ooo`030000003o0000
o`0000L0o`002`0000080?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool06P3oool2
000000<0oooo000U0?ooo`030000003oool0oooo01/0oooo2`0000090?ooo`030000003o0000o`00
00H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`00
00L0o`002`00000M0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo02l0
oooo00<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0040
oooo000U0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00001P3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo02l0oooo00<0
00000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001`3o00000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0040oooo000U
0?ooo`030000003oool0oooo02l0oooo00<000000?l0003o00001P3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00006
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0040oooo000U0?ooo`800000<03oool:000000T0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000070?l000030000003oool0oooo02@0oooo0P0000030?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0>03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`002`00000W0?ooo`03
0000003oool0oooo0040oooo00050?ooo`H000006P3oool00`000000oooo0?ooo`0h0?ooo`030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0040oooo00060?ooo`8000000P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool00P00000K
0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00006
0?l000030000003oool0oooo02l0oooo00<000000?ooo`3oool00@3oool000D0oooo1P00000J0?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l0
00030000003oool0oooo02l0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3o
ool07@3oool2000003T0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l00003
0000003oool0oooo02h0oooo0P0000030?ooo`001`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000
003oool0oooo02l0oooo00<000000?ooo`3oool00@3oool000L0oooo0`00000K0?ooo`030000003o
ool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o
ool0oooo02l0oooo00<000000?ooo`3oool00@3oool000X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0h0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`002P00000a0?ooo`030000003oool0
oooo0040oooo00070?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool0>03oool00`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool000L0
oooo1000000J0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000:0?ooo`030000003oool0oooo01P0oooo
0P00000i0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0=`3oool2000000<0oooo
00070?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0>03oool00`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool000L0oooo1000
000J0?ooo`030000003oool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0040oooo00070?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0>03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo03P0oooo00<00000
0?ooo`3oool00@3oool000P0oooo0`00000J0?ooo`030000003oool0oooo03P0oooo00<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo00070?ooo`03
0000003oool0oooo00h0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`00
203oool3000000`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo03P0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0040oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00000h0?oo
o`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?ooo`3oool0=P3oool3000000<0oooo00050?ooo`H0
00003@3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0h0?oo
o`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?oo
o`001`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0h0?ooo`030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00000=
0?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0>03oool00`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00006
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3oool000P0oooo0P00000K0?oo
o`030000003oool0oooo03P0oooo2`0000090?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0040oooo000U0?ooo`03
0000003oool0oooo0480oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`00
9@3oool2000004<0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?ooo`3oool0=`3oool2000000<0oooo00080?ooo`8000006`3o
ool00`000000oooo0?ooo`120?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003oool0oooo03P0oooo00<000000?ooo`3oool00@3o
ool000L0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo0480oooo00<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`010?ooo`001`3oool2000000030?ooo`000000oooo
01T0oooo00<000000?ooo`3oool0@P3oool;000000T0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003o0000o`0000L0o`002`00000j0?ooo`030000003oool0oooo
0040oooo00080?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool0C03oool00`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003oool0oooo0480oooo00<000000?ooo`3oool00@3oool002D0oooo
00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo0480oooo
00<000000?ooo`3oool00@3oool002D0oooo0P00001=0?ooo`030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?ooo`3oool0@@3oool2000000<0oooo00070?ooo`040000003oool0oooo000001X0oooo00<0
00000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo0480oooo00<0
00000?ooo`3oool00@3oool000L0oooo1000000J0?ooo`030000003oool0oooo04`0oooo00<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000oooo0?ooo`120?ooo`030000003oool0oooo0040oooo00070?oo
o`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0C03oool00`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003oool0oooo0480oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?oo
o`3oool000006P3oool00`000000oooo0?ooo`1<0?ooo`030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1<0?oo
o`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`010?oo
o`009@3oool2000004d0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`110?ooo`80
00000`3oool002D0oooo00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003oool0oooo0480oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0C03o
ool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003oool0oooo0480oooo00<000000?ooo`3oool00@3o
ool002D0oooo00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0
oooo0480oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0C03oool00`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003oool0oooo0480oooo00<000000?ooo`3oool00@3oool002D0
oooo00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo0480
oooo00<000000?ooo`3oool00@3oool002D0oooo0P00001=0?ooo`030000003o0000o`0000L0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?ooo`3oool0@@3oool2000000<0oooo00080?ooo`8000006`3oool00`000000oooo0?oo
o`1<0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000/00000A03oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo04`0oooo00<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`010?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo04`0oooo00<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`010?ooo`00203oool2000000L0oooo1@000002
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0C03oool00`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0040oooo000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C03o
ool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0040oooo000C0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo
0`00001<0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003oool0oooo04X0oooo0`0000030?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0040oooo00060?ooo`D00000203oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo04`0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000
o`0000L0o`0000<000000?ooo`3oool0C03oool00`000000oooo0?ooo`010?ooo`001@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0040oooo00050?ooo`030000003oool000000080oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1<0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
o`000?l000070?l000030000003oool0oooo04`0oooo00<000000?ooo`3oool00@3oool002D0oooo
00<000000?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?l0003o00001`3o00000`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0040oooo
000U0?ooo`800000C@3oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?l0003o00001`3o00000`000000oooo0?ooo`1;0?ooo`8000000`3oool002D0oooo00<00000
0?ooo`3oool0C03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0040oooo000U0?oo
o`030000003oool0oooo04`0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?ooo`3oool0C03oool00`000000oooo0?ooo`010?oo
o`009@3oool00`000000oooo0?ooo`1<0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000070?l000030000003oool0oooo04`0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool0C03oool;000000T0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1`3o00000`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003o
ool0oooo05H0oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
ool0oooo04`0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0EP3oool0
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`010?ooo`001P3oool4000001/0oooo0P00001G0?ooo`030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1;0?ooo`8000000`3oool000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05H0
oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo04`0
oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003oool0oooo04`0oooo00<000000?ooo`3oool00@3oool000H0oooo1000
000K0?ooo`030000003oool0oooo05H0oooo00<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l0
00070?l000030000003oool0oooo04`0oooo00<000000?ooo`3oool00@3oool002D0oooo00<00000
0?ooo`3oool0EP3oool;000000T0o`0000<000000?l0003o00001`3o00000`000000o`000?l00006
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0C03oool00`000000oooo0?ooo`01
0?ooo`009@3oool00`000000oooo0?ooo`1P0?ooo`030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`010?ooo`00203oool2000001/0oooo0P00001Q0?ooo`03
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?ooo`3oool0B`3oool2000000<0oooo00070?ooo`040000
003oool0oooo000001X0oooo00<000000?ooo`3oool0H03oool00`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003oool0oooo04`0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool0
00006P3oool00`000000oooo0?ooo`1P0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`03
0000003oool0oooo0600oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo0600oooo00<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o0000
1`3o00000`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003o
ool0oooo0600oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0040oooo00080?ooo`8000006`3oool200000640oooo00<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003o0000o`0000L0o`002`00001=0?ooo`8000000`3oool0
00L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1P0?ooo`030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool000006P3oool0
0`000000oooo0?ooo`1P0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
00L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1P0?ooo`030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0
oooo05H0oooo00<000000?ooo`3oool00@3oool00140oooo1@0000020?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool0H03oool00`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0040oooo00070?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1P
0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00006
0?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool000L0oooo0`0000090?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`<00000H03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000oooo0?ooo`1D0?ooo`<000000`3oool000X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0600oooo00<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`01
0?ooo`001`3oool00`000000oooo000000090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0600oooo00<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<00000
0?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001`3oool4000000L0oooo0P0000040?oo
o`<000000`3oool2000000D0oooo00<000000?ooo`3oool0H03oool00`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l0
00030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0040oooo000:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0H03oool00`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o
00001`3o00000`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000
003oool0oooo0600oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001`3o
ool010000000oooo0?ooo`00000J0?ooo`800000H@3oool00`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1E0?ooo`800000
0`3oool000L0oooo1000000J0?ooo`030000003oool0oooo0600oooo00<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`030000003o
ool0oooo0600oooo00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o
0000o`0000L0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`001`3oool0
10000000oooo0?ooo`00000J0?ooo`030000003oool0oooo0600oooo00<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o
00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1P0?ooo`/000002@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o0000
0`000000o`000?l000070?l000030000003oool0oooo05H0oooo00<000000?ooo`3oool00@3oool0
02D0oooo00<000000?ooo`3oool0JP3oool00`000000o`000?l000070?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`010?ooo`002@3oool2000001X0
oooo0P00001[0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
oooo0?ooo`1E0?ooo`8000000`3oool000L0oooo00@000000?ooo`00000000006P3oool00`000000
oooo0?ooo`1Z0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool00000000001X0
oooo00<000000?ooo`3oool0JP3oool00`000000o`000?l000070?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000/00000F03oool00`000000
oooo0?ooo`010?ooo`001`3oool4000001X0oooo00<000000?ooo`3oool0JP3oool00`000000o`00
0?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`00
0?l000070?l000030000003oool0oooo0600oooo00<000000?ooo`3oool00@3oool000X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`1Z0?ooo`030000003o0000o`0000L0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00
000J0?ooo`030000003oool0oooo06X0oooo00<000000?l0003o00001`3o00000`000000o`000?l0
00060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo0040oooo00070?ooo`@000006P3oool2000006/0oooo00<00000
0?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<00000
0?l0003o00001`3o00000`000000oooo0?ooo`1O0?ooo`8000000`3oool000L0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o0000o`0000L0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`010?ooo`001`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo06X0oooo00<000000?l0003o00001`3o00000`000000o`000?l000060?l00003
0000003o0000o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0040oooo00080?ooo`<000006P3oool00`000000oooo0?ooo`1Z0?ooo`030000
003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000
003o0000o`0000L0o`0000<000000?ooo`3oool0H03oool00`000000oooo0?ooo`010?ooo`002P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06X0oooo00<000000?l0003o00001`3o
00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0003o00001`3o
00000`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0
oooo06X0oooo00<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000
o`0000L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0040oooo00080?ooo`8000006`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o0000o`00
00L0o`0000<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`00
00L0o`0000<000000?ooo`3oool0H03oool00`000000oooo0?ooo`010?ooo`001`3oool010000000
oooo0?ooo`00000J0?ooo`800000J`3oool00`000000o`000?l000070?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo
05l0oooo0P0000030?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo
06X0oooo00<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`00
00L0o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
0040oooo00070?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0JP3oool00`00
0000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`00
0000o`000?l000070?l000030000003oool0oooo0600oooo00<000000?ooo`3oool00@3oool002D0
oooo00<000000?ooo`3oool0JP3oool00`000000o`000?l000070?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo0600
oooo00<000000?ooo`3oool00@3oool00140oooo100000030?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool0JP3oool00`000000o`000?l000070?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001`3o00000`000000o`000?l000070?l000030000003oool0oooo0600oooo
00<000000?ooo`3oool00@3oool000P0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06X0
oooo00<000000?l0003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0
o`0000<000000?l0003o00001`3o00000`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0040
oooo00070?ooo`80000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool3000006X0oooo00<000000?l0
003o00001`3o00000`000000o`000?l000060?l000030000003o0000o`0000L0o`0000<000000?l0
003o00001`3o00000`000000oooo0?ooo`1N0?ooo`<000000`3oool000L0oooo0P0000000`3oool0
00000?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0JP3oool00`000000o`000?l00007
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o00000`000000o`000?l00007
0?l000030000003oool0oooo0600oooo00<000000?ooo`3oool00@3oool000P0oooo00<000000?oo
o`0000001P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`1Z0?ooo`030000003o0000o`0000L0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`00
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`010?ooo`004P3oool2000000@0oooo0P00
00040?ooo`8000001@3oool00`000000oooo0?ooo`1Z0?ooo`030000003o0000o`0000L0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000070?l000030000003o0000o`0000L0o`0000<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1Z
0?ooo`030000003o0000o`0000L0o`0000<000000?l0003o00001P3o00000`000000o`000?l00007
0?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0H03oool00`000000oooo0?ooo`01
0?ooo`001`3oool2000000030?ooo`000000oooo01T0oooo00<000000?ooo`3oool0JP3oool00`00
0000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o00001`3o000;0000
0680oooo00<000000?ooo`3oool00@3oool000L0oooo0P0000000`3oool000000?ooo`0I0?ooo`80
0000J`3oool00`000000o`000?l000070?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001`3o00000`000000oooo0?ooo`1Y0?ooo`8000000`3oool000L0oooo0P0000000`3oool00000
0?ooo`0I0?ooo`030000003oool0oooo06X0oooo00<000000?l0003o00001`3o00000`000000o`00
0?l000060?l000030000003o0000o`0000L0o`0000<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`010?ooo`001`3oool00`000000oooo0000000K0?ooo`030000003oool0oooo06X0oooo00<0
00000?l0003o00001`3o000:000000T0o`0000<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`010?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000003o0000o`0000L0o`0000<00000
0?ooo`3oool01P3oool00`000000o`000?l000070?l000030000003oool0oooo06X0oooo00<00000
0?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000000o`000?l000070?l0
00030000003oool0oooo00H0oooo00<000000?l0003o00001`3o00000`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo06X0oooo00<000000?l0003o
00001`3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`0000L0o`0000<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`010?ooo`009@3oool2000006/0oooo00<000000?l0003o0000
1`3o00000`000000oooo0?ooo`060?ooo`030000003o0000o`0000L0o`0000<000000?ooo`3oool0
J@3oool2000000<0oooo000U0?ooo`030000003oool0oooo06X0oooo00<000000?l0003o00001`3o
00000`000000oooo0?ooo`060?ooo`030000003o0000o`0000L0o`0000<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`/00000203oool0
0`000000o`000?l000070?l000030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3oool0
02D0oooo00<000000?ooo`3oool0O@3oool00`000000o`000?l000070?l000030000003oool0oooo
06X0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0O@3oool00`000000
o`000?l000070?l000030000003oool0oooo06X0oooo00<000000?ooo`3oool00@3oool002D0oooo
00<000000?ooo`3oool0O@3oool00`000000o`000?l000070?l000030000003oool0oooo06X0oooo
00<000000?ooo`3oool00@3oool002D0oooo0P00001n0?ooo`030000003o0000o`0000L0o`0000<0
00000?ooo`3oool0J@3oool2000000<0oooo000U0?ooo`030000003oool0oooo07d0oooo00<00000
0?l0003o00001`3o00000`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo000U0?oo
o`030000003oool0oooo07d0oooo00<000000?l0003o00001`3o00000`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo07d0oooo00<000000?l0003o
00001`3o00000`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000
003oool0oooo07d0oooo2`00001/0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003o
ool0oooo0?@0oooo00<000000?ooo`3oool00@3oool002D0oooo0P0000080?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`8000000`3oool0
02D0oooon00000030?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {2.75815, -45.9978, \
0.0050727, 1.62712}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-6.47368 105.263 0.0147151 0.00205088 [
[.05263 -0.0125 -15 -9 ]
[.05263 -0.0125 15 0 ]
[.26316 -0.0125 -15 -9 ]
[.26316 -0.0125 15 0 ]
[.47368 -0.0125 -15 -9 ]
[.47368 -0.0125 15 0 ]
[.68421 -0.0125 -15 -9 ]
[.68421 -0.0125 15 0 ]
[.89474 -0.0125 -12 -9 ]
[.89474 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -21.5625 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11726 -12 -4.5 ]
[-0.0125 .11726 0 4.5 ]
[-0.0125 .2198 -18 -4.5 ]
[-0.0125 .2198 0 4.5 ]
[-0.0125 .32235 -18 -4.5 ]
[-0.0125 .32235 0 4.5 ]
[-0.0125 .42489 -18 -4.5 ]
[-0.0125 .42489 0 4.5 ]
[-0.0125 .52744 -18 -4.5 ]
[-0.0125 .52744 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -62 ]
[-0.01875 .30902 -18 62 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05263 0 m
.05263 .00625 L
s
[(0.062)] .05263 -0.0125 0 1 Mshowa
.26316 0 m
.26316 .00625 L
s
[(0.064)] .26316 -0.0125 0 1 Mshowa
.47368 0 m
.47368 .00625 L
s
[(0.066)] .47368 -0.0125 0 1 Mshowa
.68421 0 m
.68421 .00625 L
s
[(0.068)] .68421 -0.0125 0 1 Mshowa
.89474 0 m
.89474 .00625 L
s
[(0.07)] .89474 -0.0125 0 1 Mshowa
.125 Mabswid
.10526 0 m
.10526 .00375 L
s
.15789 0 m
.15789 .00375 L
s
.21053 0 m
.21053 .00375 L
s
.31579 0 m
.31579 .00375 L
s
.36842 0 m
.36842 .00375 L
s
.42105 0 m
.42105 .00375 L
s
.52632 0 m
.52632 .00375 L
s
.57895 0 m
.57895 .00375 L
s
.63158 0 m
.63158 .00375 L
s
.73684 0 m
.73684 .00375 L
s
.78947 0 m
.78947 .00375 L
s
.84211 0 m
.84211 .00375 L
s
.94737 0 m
.94737 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Parameter) show
123.000 12.813 moveto
(b) show
129.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11726 m
.00625 .11726 L
s
[(50)] -0.0125 .11726 1 0 Mshowa
0 .2198 m
.00625 .2198 L
s
[(100)] -0.0125 .2198 1 0 Mshowa
0 .32235 m
.00625 .32235 L
s
[(150)] -0.0125 .32235 1 0 Mshowa
0 .42489 m
.00625 .42489 L
s
[(200)] -0.0125 .42489 1 0 Mshowa
0 .52744 m
.00625 .52744 L
s
[(250)] -0.0125 .52744 1 0 Mshowa
.125 Mabswid
0 .03522 m
.00375 .03522 L
s
0 .05573 m
.00375 .05573 L
s
0 .07624 m
.00375 .07624 L
s
0 .09675 m
.00375 .09675 L
s
0 .13777 m
.00375 .13777 L
s
0 .15828 m
.00375 .15828 L
s
0 .17879 m
.00375 .17879 L
s
0 .19929 m
.00375 .19929 L
s
0 .24031 m
.00375 .24031 L
s
0 .26082 m
.00375 .26082 L
s
0 .28133 m
.00375 .28133 L
s
0 .30184 m
.00375 .30184 L
s
0 .34286 m
.00375 .34286 L
s
0 .36337 m
.00375 .36337 L
s
0 .38387 m
.00375 .38387 L
s
0 .40438 m
.00375 .40438 L
s
0 .4454 m
.00375 .4454 L
s
0 .46591 m
.00375 .46591 L
s
0 .48642 m
.00375 .48642 L
s
0 .50693 m
.00375 .50693 L
s
0 .54795 m
.00375 .54795 L
s
0 .56845 m
.00375 .56845 L
s
0 .58896 m
.00375 .58896 L
s
0 .60947 m
.00375 .60947 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -147.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
123 10.2813 translate
90 rotate
-123 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Number) show
105.000 12.813 moveto
(of) show
123.000 12.813 moveto
(Occurances) show
183.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05263 .61178 m
.05263 .61803 L
s
.26316 .61178 m
.26316 .61803 L
s
.47368 .61178 m
.47368 .61803 L
s
.68421 .61178 m
.68421 .61803 L
s
.89474 .61178 m
.89474 .61803 L
s
.125 Mabswid
.10526 .61428 m
.10526 .61803 L
s
.15789 .61428 m
.15789 .61803 L
s
.21053 .61428 m
.21053 .61803 L
s
.31579 .61428 m
.31579 .61803 L
s
.36842 .61428 m
.36842 .61803 L
s
.42105 .61428 m
.42105 .61803 L
s
.52632 .61428 m
.52632 .61803 L
s
.57895 .61428 m
.57895 .61803 L
s
.63158 .61428 m
.63158 .61803 L
s
.73684 .61428 m
.73684 .61803 L
s
.78947 .61428 m
.78947 .61803 L
s
.84211 .61428 m
.84211 .61803 L
s
.94737 .61428 m
.94737 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11726 m
1 .11726 L
s
.99375 .2198 m
1 .2198 L
s
.99375 .32235 m
1 .32235 L
s
.99375 .42489 m
1 .42489 L
s
.99375 .52744 m
1 .52744 L
s
.125 Mabswid
.99625 .03522 m
1 .03522 L
s
.99625 .05573 m
1 .05573 L
s
.99625 .07624 m
1 .07624 L
s
.99625 .09675 m
1 .09675 L
s
.99625 .13777 m
1 .13777 L
s
.99625 .15828 m
1 .15828 L
s
.99625 .17879 m
1 .17879 L
s
.99625 .19929 m
1 .19929 L
s
.99625 .24031 m
1 .24031 L
s
.99625 .26082 m
1 .26082 L
s
.99625 .28133 m
1 .28133 L
s
.99625 .30184 m
1 .30184 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .36337 m
1 .36337 L
s
.99625 .38387 m
1 .38387 L
s
.99625 .40438 m
1 .40438 L
s
.99625 .4454 m
1 .4454 L
s
.99625 .46591 m
1 .46591 L
s
.99625 .48642 m
1 .48642 L
s
.99625 .50693 m
1 .50693 L
s
.99625 .54795 m
1 .54795 L
s
.99625 .56845 m
1 .56845 L
s
.99625 .58896 m
1 .58896 L
s
.99625 .60947 m
1 .60947 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02087 L
.05263 .02087 L
.05263 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02087 L
.05263 .02087 L
.05263 .01472 L
0 .01472 L
s
1 0 0 r
.05263 .01472 m
.05263 .01882 L
.10526 .01882 L
.10526 .01472 L
F
0 g
.05263 .01472 m
.05263 .01882 L
.10526 .01882 L
.10526 .01472 L
.05263 .01472 L
s
1 0 0 r
.10526 .01472 m
.10526 .06189 L
.15789 .06189 L
.15789 .01472 L
F
0 g
.10526 .01472 m
.10526 .06189 L
.15789 .06189 L
.15789 .01472 L
.10526 .01472 L
s
1 0 0 r
.15789 .01472 m
.15789 .07829 L
.21053 .07829 L
.21053 .01472 L
F
0 g
.15789 .01472 m
.15789 .07829 L
.21053 .07829 L
.21053 .01472 L
.15789 .01472 L
s
1 0 0 r
.21053 .01472 m
.21053 .16238 L
.26316 .16238 L
.26316 .01472 L
F
0 g
.21053 .01472 m
.21053 .16238 L
.26316 .16238 L
.26316 .01472 L
.21053 .01472 L
s
1 0 0 r
.26316 .01472 m
.26316 .2157 L
.31579 .2157 L
.31579 .01472 L
F
0 g
.26316 .01472 m
.26316 .2157 L
.31579 .2157 L
.31579 .01472 L
.26316 .01472 L
s
1 0 0 r
.31579 .01472 m
.31579 .37362 L
.36842 .37362 L
.36842 .01472 L
F
0 g
.31579 .01472 m
.31579 .37362 L
.36842 .37362 L
.36842 .01472 L
.31579 .01472 L
s
1 0 0 r
.36842 .01472 m
.36842 .47411 L
.42105 .47411 L
.42105 .01472 L
F
0 g
.36842 .01472 m
.36842 .47411 L
.42105 .47411 L
.42105 .01472 L
.36842 .01472 L
s
1 0 0 r
.42105 .01472 m
.42105 .5582 L
.47368 .5582 L
.47368 .01472 L
F
0 g
.42105 .01472 m
.42105 .5582 L
.47368 .5582 L
.47368 .01472 L
.42105 .01472 L
s
1 0 0 r
.47368 .01472 m
.47368 .5623 L
.52632 .5623 L
.52632 .01472 L
F
0 g
.47368 .01472 m
.47368 .5623 L
.52632 .5623 L
.52632 .01472 L
.47368 .01472 L
s
1 0 0 r
.52632 .01472 m
.52632 .60332 L
.57895 .60332 L
.57895 .01472 L
F
0 g
.52632 .01472 m
.52632 .60332 L
.57895 .60332 L
.57895 .01472 L
.52632 .01472 L
s
1 0 0 r
.57895 .01472 m
.57895 .39413 L
.63158 .39413 L
.63158 .01472 L
F
0 g
.57895 .01472 m
.57895 .39413 L
.63158 .39413 L
.63158 .01472 L
.57895 .01472 L
s
1 0 0 r
.63158 .01472 m
.63158 .3285 L
.68421 .3285 L
.68421 .01472 L
F
0 g
.63158 .01472 m
.63158 .3285 L
.68421 .3285 L
.68421 .01472 L
.63158 .01472 L
s
1 0 0 r
.68421 .01472 m
.68421 .20955 L
.73684 .20955 L
.73684 .01472 L
F
0 g
.68421 .01472 m
.68421 .20955 L
.73684 .20955 L
.73684 .01472 L
.68421 .01472 L
s
1 0 0 r
.73684 .01472 m
.73684 .14597 L
.78947 .14597 L
.78947 .01472 L
F
0 g
.73684 .01472 m
.73684 .14597 L
.78947 .14597 L
.78947 .01472 L
.73684 .01472 L
s
1 0 0 r
.78947 .01472 m
.78947 .08855 L
.84211 .08855 L
.84211 .01472 L
F
0 g
.78947 .01472 m
.78947 .08855 L
.84211 .08855 L
.84211 .01472 L
.78947 .01472 L
s
1 0 0 r
.84211 .01472 m
.84211 .04138 L
.89474 .04138 L
.89474 .01472 L
F
0 g
.84211 .01472 m
.84211 .04138 L
.89474 .04138 L
.89474 .01472 L
.84211 .01472 L
s
1 0 0 r
.89474 .01472 m
.89474 .01882 L
.94737 .01882 L
.94737 .01472 L
F
0 g
.89474 .01472 m
.89474 .01882 L
.94737 .01882 L
.94737 .01472 L
.89474 .01472 L
s
1 0 0 r
.94737 .01472 m
.94737 .02497 L
1 .02497 L
1 .01472 L
F
0 g
.94737 .01472 m
.94737 .02497 L
1 .02497 L
1 .01472 L
.94737 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P03oool3000000@0oooo1@00
00000`3oool000000000000200000080oooo1`000000103oool000000?ooo`0000020?ooo`<00000
0`3oool2000000@0oooo0`0000020?ooo`@000001`3oool400000600oooo00210?ooo`030000003o
ool0oooo00<0oooo100000030?ooo`030000003oool0oooo0080oooo100000020?ooo`070000003o
ool000000?ooo`000000oooo000000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000005l0oooo00210?oo
o`<000001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00T000000?ooo`3oool000000?oo
o`000000oooo0000003oool0100000020?ooo`030000003oool0oooo00<0oooo100000030?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool00000G`3oool00840oooo00@000000?ooo`3o
ool000000`3oool300000080oooo100000030?ooo`<0000000H0oooo00000000000000000?ooo`00
00030?ooo`8000000P3oool5000000<0oooo0P0000030?ooo`@00000203oool300000600oooo0021
0?ooo`040000003oool0oooo00000200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1P0?ooo`00P03oool4000003P0oooo0P00001R0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`009@3oool2000000@0oooo0P0000040?ooo`8000000`3oool3000000<0oooo1000
000I0?ooo`800000103oool2000000@0oooo0P0000030?ooo`<000001@3oool3000001P0oooo0P00
00040?ooo`800000103oool2000000<0oooo0`0000030?ooo`<000006P3oool2000000@0oooo0P00
00040?ooo`8000000`3oool3000000@0oooo0P00000M0?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0180oooo000T0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01T0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000H
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000001/0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0180oooo000T0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo01P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo1@00000G0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000001P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000006`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04P3oool002@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo
0?ooo`0G0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool30000
00<0oooo00@000000?ooo`3oool00000603oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo0`0000030?ooo`<000006@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo0`0000040?ooo`800000703oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool04@3oool002@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000603oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000H0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000006`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000004`3oool002D0oooo
0P00000:0?ooo`800000103oool3000000<0oooo0P00000J0?ooo`8000002P3oool2000000@0oooo
0`0000040?ooo`8000006@3oool2000000X0oooo0P0000040?ooo`<000000`3oool3000001T0oooo
0P00000:0?ooo`800000103oool3000000<0oooo0P00000M0?ooo`8000002P3oool2000000<0oooo
1000000C0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`009@3ooooh000000<0oooo000U0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00@3oool001h0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0040oooo000M0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`010?oo
o`007@3oool010000000oooo0?ooo`0000040?ooooP000000`3oool001d0oooo00@000000?ooo`3o
ool00000103ooolK000000`0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00h00000303o00000`000000oooo0?ooo`010?ooo`007@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01L0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool02P3oool>000000<0oooo000N0?ooo`80
00001@3oool00`000000oooo0?ooo`0G0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo01L0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool05`3oool00`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0040oooo000U0?ooo`800000603oool00`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0F0?ooo`8000000`3o
ool002D0oooo00<000000?ooo`3oool05`3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`003P00000I0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo
01L0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo
02@0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool05`3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0903oool00`000000
oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`0G0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0040oooo
000U0?ooo`800000603oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?ooo`3oool08`3oool2000000<0oooo000U0?ooo`030000003oool0oooo01L0oooo3P00000<
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003oool0oooo02@0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?oo
o`3oool0903oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo02@0oooo00<000000?oo
o`3oool00@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo02@0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0040oooo00050?ooo`H000006P3oool00`000000oooo0?ooo`0T0?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0903oool00`000000oooo0?ooo`010?ooo`001P3o
ool200000080oooo00<000000?ooo`3oool0603oool2000002D0oooo3P00000<0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0S0?ooo`8000000`3o
ool000D0oooo00<000000?ooo`3oool00P00000K0?ooo`030000003oool0oooo0340oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`010?ooo`001@3oool6000001X0oooo00<000000?oo
o`3oool0<@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0040oooo00050?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0<@3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`003P00000V0?ooo`030000003oool0oooo0040oooo00070?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0<@3oool00`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`010?ooo`001`3o
ool3000001/0oooo0P00000b0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000oooo0?ooo`0`0?ooo`8000000`3oool000X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0a0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0040oooo00070?ooo`030000003oool00000
01/0oooo00<000000?ooo`3oool0<@3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`010?ooo`001`3oool4000000d0
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0a0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0040
oooo000:0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0340oooo00<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo0340oooo00<000000?ooo`3oool00@3oool000L0
oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo0`00000a0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`0_0?ooo`<000000`3oool000L0oooo1000000=0?ooo`8000000`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0340oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo0340oooo00<000000?ooo`3oool00@3oool0
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0<@3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`010?ooo`00203oool30000
00d0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`0a0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0040oooo00070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0<@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`010?ooo`00203oool3000001X0oooo0P00000b0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`0`0?ooo`8000000`3oool000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo0340oooo00<0
00000?ooo`3oool00@3oool000D0oooo1P00000J0?ooo`030000003oool0oooo0340oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o000>000003<0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?oo
o`3oool000006P3oool00`000000oooo0?ooo`0a0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00000J
0?ooo`030000003oool0oooo0340oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0040oooo00080?ooo`8000006`3oool200000380oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`0m0?ooo`8000000`3oool002D0oooo00<000000?ooo`3o
ool0<@3oool>000000`0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo03h0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0
?P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0040oooo00080?ooo`8000006`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003oool0oooo03h0oooo00<000000?ooo`3oool00@3o
ool000L0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo03h0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`010?ooo`001`3oool2000000030?ooo`000000oooo
01T0oooo0P00000o0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo03d0oooo0P0000030?ooo`00203oool00`000000
oooo0000000J0?ooo`030000003oool0oooo03h0oooo00<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`0n0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo03h0oooo
00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0?P3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool0oooo000001X0oooo00<0
00000?ooo`3oool0?P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0040oooo0007
0?ooo`@000006P3oool2000003l0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0?@3oool2000000<0oooo00070?oo
o`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0?P3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0040oooo00070?ooo`040000003oool0oooo000001X0oooo00<00000
0?ooo`3oool0?P3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0040oooo000A0?oo
o`D000000P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo03h0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000h00000@03oool00`000000oooo0?ooo`010?oo
o`004`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo3P00000<0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo04/0oooo00<000000?ooo`3oool00@3oool001<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool3000004/0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000oooo0?ooo`190?ooo`<000000`3oool001<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`010?ooo`004`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04/0
oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0040
oooo000B0?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04/0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0040oooo
000U0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0040oooo000U0?ooo`800000C03oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003oool0oooo04X0oooo0P0000030?ooo`00203oool2000001/0oooo00<000000?oo
o`3oool0B`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04/0oooo00<000000?oo
o`3oool00@3oool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1;0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`010?oo
o`001`3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0oooo04/0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0040oooo00080?ooo`80
00006`3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`010?ooo`009@3oool2000004`0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000oooo0?ooo`1:0?ooo`8000000`3oool002D0oooo00<000000?ooo`3oool0B`3o
ool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool00@3o
ool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1;0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`010?ooo`001P3oool5
000001X0oooo00<000000?ooo`3oool0B`3oool00`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo04/0oooo00<000000?ooo`3oool00@3oool000D0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0040oooo00050?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`010?ooo`009@3oool2000004`0oooo
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`1:0?ooo`8000000`3oool002D0oooo00<0
00000?ooo`3oool0B`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04/0oooo00<0
00000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0B`3oool00`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003oool0oooo04/0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?oo
o`3oool0B`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo04/0oooo00<000000?oo
o`3oool00@3oool002D0oooo00<000000?ooo`3oool0B`3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo04/0oooo00<000000?ooo`3oool00@3oool002D0oooo0P00001<0?ooo`030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0BP3oool2000000<0oooo000U0?ooo`030000003o
ool0oooo04/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0040oooo000U0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0040oooo00060?ooo`@000001`3oool50000
0080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`010?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1;
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`01
0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00001;
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0B@3oool3000000<0oooo00060?oo
o`@000002@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`003P00001=0?ooo`030000003oool0oooo0040oooo000C0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0F03oool00`000000oooo0?ooo`01
0?ooo`004P3oool2000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`1;0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l0
00030000003oool0oooo05P0oooo00<000000?ooo`3oool00@3oool000P0oooo0P00000K0?ooo`03
0000003oool0oooo04/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?ooo`3oool0F03oool00`000000oooo0?ooo`010?ooo`00
1`3oool010000000oooo0?ooo`00000J0?ooo`800000C03oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1G0?ooo`80
00000`3oool000L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1;0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo05P0oooo00<000000?ooo`3oool00@3oool000L0oooo00@000000?ooo`3oool0
00006P3oool00`000000oooo0?ooo`1;0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo05P0oooo00<000000?ooo`3o
ool00@3oool002D0oooo00<000000?ooo`3oool0B`3oool00`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0040oooo000U0?ooo`030000003oool0oooo04/0oooo00<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`010?ooo`00203oool2000001/0oooo0P00001<0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo05L0oooo0P0000030?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`030000003oool0
oooo04/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0F03oool00`000000oooo0?ooo`010?ooo`001`3oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo04/0oooo3P00000<0?l000030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0F03oool00`000000oooo0?ooo`010?ooo`001`3oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo05P0oooo00<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo05P0oooo00<000000?ooo`3oool00@3oool0
02D0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?ooo`3oool0F03oool00`000000oooo0?ooo`010?ooo`001`3oool00`000000
oooo0?ooo`0K0?ooo`800000F@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?ooo`3oool0E`3oool2000000<0oooo00070?ooo`<000006`3oool00`000000oooo
0?ooo`1H0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`00
0?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0040oooo000:0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0F03oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<0
00000?l0003o00002P3o00000`000000o`000?l0000:0?l000h00000FP3oool00`000000oooo0?oo
o`010?ooo`001`3oool00`000000oooo0000000K0?ooo`030000003oool0oooo05P0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00070?oo
o`@000006P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`010?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`80
0000F@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06@0oooo0P0000030?ooo`00
9@3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`00000J0?ooo`030000
003oool0oooo05P0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo0040oooo00070?ooo`@000001P3oool4000000<0oooo0P0000040?ooo`8000001@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`010?ooo`001`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo05P0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0040oooo00070?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo0`00001H
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0H`3oool3000000<0oooo000C0?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo06D0oooo00<000000?ooo`3oool00@3oool00140oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0F03oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3o
ool00@3oool000T0oooo0P0000070?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo05P0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo0040oooo00070?ooo`040000003oool00000000001X0oooo00<000000?ooo`3oool0
F03oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3oool0
0@3oool000L0oooo00@000000?ooo`00000000006P3oool2000005T0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o0000
2P3o00000`000000oooo0?ooo`1T0?ooo`8000000`3oool000L0oooo1000000J0?ooo`030000003o
ool0oooo05P0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0040oooo000:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F03oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool0
00L0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`001`3oool40000
01X0oooo00<000000?ooo`3oool0F03oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo
06D0oooo00<000000?ooo`3oool00@3oool000L0oooo00<000000?ooo`3oool06`3oool2000005T0
oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0
o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1T0?ooo`8000000`3oool000L0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1H0?ooo`030000003o0000o`0000X0o`00
00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`00
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`00203oool3000001X0oooo00<0
00000?ooo`3oool0F03oool>000000`0o`0000<000000?l0003o00002P3o00000`000000o`000?l0
000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool000X0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1U0?ooo`030000003o0000o`0000X0o`0000<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<00000
0?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0I@3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0040oooo00080?ooo`8000006`3oool2000006H0oooo00<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0I03oool2000000<0oooo00070?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3o
ool0I@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00070?ooo`040000
003oool0oooo000001X0oooo00<000000?ooo`3oool0I@3oool00`000000o`000?l0000:0?l00003
0000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0040oooo00070?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3o
ool0I@3oool00`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000
003oool0oooo06D0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`009@3o
ool2000006H0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o
0000o`0000X0o`0000<000000?ooo`3oool0I03oool2000000<0oooo00080?ooo`8000006`3oool0
0`000000oooo0?ooo`1U0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o0000
0`000000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool0
00L0oooo0P0000000`3oool000000?ooo`0I0?ooo`030000003oool0oooo06D0oooo00<000000?l0
003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`010?ooo`001`3oool2000000030?ooo`000000oooo00D0
oooo100000030?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0I@3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00080?ooo`030000003oool0000000H0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0I@3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0040oooo000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`<00000I@3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00X0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1S0?ooo`<000000`3oool001<0
oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1U0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3oool00@3oool000L0
oooo0P0000000`3oool000000?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06D0oooo00<00000
0?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`001`3oool2000000030?ooo`000000oooo
00H0oooo0P0000040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool0I@3oool00`00
0000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?l0003o00002P3o00000`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo00070?ooo`80000000<0oooo0000003o
ool06@3oool00`000000oooo0?ooo`1U0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o
00002P3o00000`000000o`000?l0000:0?l000030000003oool0oooo06D0oooo00<000000?ooo`3o
ool00@3oool000L0oooo00<000000?ooo`0000006`3oool2000006H0oooo00<000000?l0003o0000
2P3o00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0
I03oool2000000<0oooo000U0?ooo`030000003oool0oooo06D0oooo00<000000?l0003o00002P3o
00000`000000o`000?l0000:0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1U0?ooo`030000003o0000
o`0000X0o`0000<000000?l0003o00002P3o00000`000000o`000?l0000:0?l000030000003oool0
oooo06D0oooo00<000000?ooo`3oool00@3oool002D0oooo00<000000?ooo`3oool0I@3oool>0000
00`0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0040oooo000U0?ooo`030000003oool0oooo0780oooo3P00000<0?l000030000003oool0oooo06D0
oooo00<000000?ooo`3oool00@3oool002D0oooo0P0000200?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool0I03oool2000000<0oooo000U0?ooo`030000003oool0oooo07l0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000U
0?ooo`030000003oool0oooo07l0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo0040oooo000U0?ooo`030000003oool0oooo07l0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0040oooo000U0?ooo`03
0000003oool0oooo07l0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0040oooo000U0?ooo`800000P03oool00`000000o`000?l0000:0?l000030000
003oool0oooo06@0oooo0P0000030?ooo`009@3oool00`000000oooo0?ooo`1o0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`009@3oool0
0`000000oooo0?ooo`1o0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`010?ooo`009@3oool00`000000oooo0?ooo`1o0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`010?ooo`009@3oool00`000000
oooo0?ooo`1o0?ooo`h00000I`3oool00`000000oooo0?ooo`010?ooo`009@3oool200000?@0oooo
0P0000030?ooo`009@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`009@3ooooh000000<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.060042, -55.9381, \
3.85526*^-05, 1.97874}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can easily calculate the mean and standard deviation in our parameters:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[alist]\), "\[IndentingNewLine]", 
    \(StandardDeviation[alist]\)}], "Input"],

Cell[BoxData[
    \(3.5929537529717464`\)], "Output"],

Cell[BoxData[
    \(0.17355963788689213`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Mean[blist]\), "\[IndentingNewLine]", 
    \(StandardDeviation[blist]\)}], "Input"],

Cell[BoxData[
    \(0.06620219560596861`\)], "Output"],

Cell[BoxData[
    \(0.001438682423858412`\)], "Output"]
}, Open  ]],

Cell["\<\
So our simulation of the experiment has allowed us to estimate Mother \
Nature's True Parameters as \
\>", "Text"],

Cell[BoxData[{
    RowBox[{"a", " ", "=", " ", 
      RowBox[{"3.59", " ", 
        StyleBox["\[PlusMinus]",
          "InlineFormula"], 
        StyleBox[" ",
          "InlineFormula"], 
        StyleBox["0.17",
          "InlineFormula"]}]}], "\[IndentingNewLine]", 
    RowBox[{"b", " ", "=", " ", 
      RowBox[{"0.0662", " ", 
        StyleBox["\[PlusMinus]",
          "InlineFormula"], 
        StyleBox["0.0014",
          "InlineFormula"]}]}]}], "DisplayFormula"],

Cell["\<\
These numbers agree, within the error we calculated, with the numbers we \
found using simulated data sets that were not created from the original \
distribution. Obviously, the previous method is preferred when you know the \
process that created the data set. But our little experiement seems to \
indicate that it really isn't such a crazy idea to create new data sets from \
the best indicator of the underlying process that created the original data \
set--the data set itself!\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subsubsection"],

Cell["\<\
The BootStrap Method (excellent discussion which appeared in the New York \
Times):\
\>", "Text"],

Cell[TextData[ButtonBox["http://www.mste.uiuc.edu/stat/bootarticle.html",
  ButtonData:>{
    URL[ "http://www.mste.uiuc.edu/stat/bootarticle.html"], None},
  ButtonStyle->"Hyperlink"]], "Text"],

Cell["\<\
W.H.Press,S.A.Teukolsky,W.T.Vetterling\\&B.P.Flannery,Numerical Recipes in \
Fortran 77,2nd ed,Cambridge University Press (New York) 1992.
\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 991}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 47, 0, 59, "Section"],
Cell[1777, 54, 121, 2, 50, "Input"],
Cell[1901, 58, 971, 17, 242, "Text"],

Cell[CellGroupData[{
Cell[2897, 79, 100, 2, 43, "Subsubsection"],
Cell[3000, 83, 335, 6, 90, "Text"],
Cell[3338, 91, 713, 20, 109, "Text"],
Cell[4054, 113, 167, 3, 70, "Input"],
Cell[4224, 118, 226, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[4475, 128, 41, 1, 30, "Input"],
Cell[4519, 131, 40, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4608, 138, 63, 0, 43, "Subsubsection"],
Cell[4674, 140, 574, 11, 128, "Text"],
Cell[5251, 153, 279, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[5555, 163, 866, 18, 310, "Input"],
Cell[6424, 183, 115, 2, 29, "Output"],
Cell[6542, 187, 125, 2, 29, "Output"],
Cell[6670, 191, 24246, 685, 186, 7576, 475, "GraphicsData", "PostScript", \
"Graphics"],
Cell[30919, 878, 130, 3, 29, "Output"]
}, Open  ]],
Cell[31064, 884, 103, 3, 33, "Text"],
Cell[31170, 889, 243, 7, 25, "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31450, 901, 95, 2, 43, "Subsubsection"],
Cell[31548, 905, 594, 15, 128, "Text"],
Cell[32145, 922, 182, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[32352, 930, 827, 17, 310, "Input"],
Cell[33182, 949, 115, 2, 29, "Output"],
Cell[33300, 953, 126, 2, 29, "Output"],
Cell[33429, 957, 24302, 691, 186, 7636, 481, "GraphicsData", "PostScript", \
"Graphics"],
Cell[57734, 1650, 130, 3, 29, "Output"]
}, Open  ]],
Cell[57879, 1656, 139, 5, 33, "Text"],
Cell[58021, 1663, 360, 8, 71, "Text"],
Cell[58384, 1673, 633, 10, 270, "Input"],
Cell[59020, 1685, 126, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[59171, 1692, 397, 7, 110, "Input"],
Cell[59571, 1701, 60143, 1390, 186, 10146, 768, "GraphicsData", "PostScript", \
"Graphics"],
Cell[119717, 3093, 130, 3, 29, "Output"],
Cell[119850, 3098, 56312, 1280, 186, 9190, 694, "GraphicsData", "PostScript", \
"Graphics"],
Cell[176165, 4380, 130, 3, 29, "Output"]
}, Open  ]],
Cell[176310, 4386, 156, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[176491, 4394, 104, 2, 50, "Input"],
Cell[176598, 4398, 53, 1, 29, "Output"],
Cell[176654, 4401, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176745, 4407, 104, 2, 50, "Input"],
Cell[176852, 4411, 54, 1, 29, "Output"],
Cell[176909, 4414, 55, 1, 29, "Output"]
}, Open  ]],
Cell[176979, 4418, 124, 3, 52, "Text"],
Cell[177106, 4423, 473, 14, 44, "DisplayFormula"],
Cell[177582, 4439, 447, 7, 109, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178066, 4451, 76, 0, 43, "Subsubsection"],
Cell[178145, 4453, 589, 11, 128, "Text"],
Cell[178737, 4466, 273, 6, 71, "Text"],
Cell[179013, 4474, 386, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[179424, 4484, 462, 8, 210, "Input"],
Cell[179889, 4494, 707, 28, 343, "Output"]
}, Open  ]],
Cell[180611, 4525, 144, 3, 52, "Text"],
Cell[180758, 4530, 124, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[180907, 4537, 843, 16, 330, "Input"],
Cell[181753, 4555, 114, 2, 29, "Output"],
Cell[181870, 4559, 125, 2, 29, "Output"],
Cell[181998, 4563, 22604, 648, 186, 7291, 454, "GraphicsData", "PostScript", \
"Graphics"],
Cell[204605, 5213, 130, 3, 29, "Output"]
}, Open  ]],
Cell[204750, 5219, 192, 6, 52, "Text"],
Cell[204945, 5227, 723, 11, 350, "Input"],
Cell[205671, 5240, 126, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[205822, 5247, 363, 6, 90, "Input"],
Cell[206188, 5255, 62441, 1451, 186, 9366, 791, "GraphicsData", "PostScript", \
"Graphics"],
Cell[268632, 6708, 130, 3, 29, "Output"],
Cell[268765, 6713, 57913, 1310, 186, 9399, 707, "GraphicsData", "PostScript", \
"Graphics"],
Cell[326681, 8025, 130, 3, 29, "Output"]
}, Open  ]],
Cell[326826, 8031, 156, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[327007, 8039, 104, 2, 50, "Input"],
Cell[327114, 8043, 53, 1, 29, "Output"],
Cell[327170, 8046, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[327261, 8052, 104, 2, 50, "Input"],
Cell[327368, 8056, 54, 1, 29, "Output"],
Cell[327425, 8059, 55, 1, 29, "Output"]
}, Open  ]],
Cell[327495, 8063, 124, 3, 52, "Text"],
Cell[327622, 8068, 473, 14, 44, "DisplayFormula"],
Cell[328098, 8084, 506, 8, 128, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[328641, 8097, 35, 0, 43, "Subsubsection"],
Cell[328679, 8099, 107, 3, 33, "Text"],
Cell[328789, 8104, 194, 3, 33, "Text"],
Cell[328986, 8109, 163, 4, 71, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

