(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8269,        210]*)
(*NotebookOutlinePosition[      8911,        232]*)
(*  CellTagsIndexPosition[      8867,        228]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Example of Random Search to Find Minimum", "Section"],

Cell[TextData[{
  "First, let's define the function for which we want to find the minimum. \
This is a function for which the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " cannot find the minimum (at least, the NSolve below took so long that I \
finally gave up waiting and aborted the calculation!)."
}], "Text"],

Cell[BoxData[{
    \(f[x_, y_]\  = \ \((Cos[x] + Sin[x]\  - Cos[x\ y])\) 
        Exp[\(-x^2\) - y^2]\), "\[IndentingNewLine]", 
    \(Plot3D[f[x, y], {x, \(-2\), 2}, {y, \(-3\), 3}, 
      AxesLabel \[Rule] {x, y, z}, PlotPoints \[Rule] 35, 
      ColorFunction \[Rule] Hue, 
      PlotRange \[Rule] {\(-1\), 1}]\), "\[IndentingNewLine]", 
    \(eq1\  = \ D[f[x, y], y] \[Equal] 0\), "\[IndentingNewLine]", 
    \(eq2\  = \ D[f[x, y], x] \[Equal] 0\)}], "Input"],

Cell[BoxData[
    \(NSolve[{eq1, eq2}, {x, y}]\)], "Input"],

Cell["\<\
Instead, let's find a rough estimate of the minimum using a random search \
technique\
\>", "Text"],

Cell[BoxData[{
    \(xlower = \(-2\)\), "\[IndentingNewLine]", 
    \(xupper = \(+2\)\), "\[IndentingNewLine]", 
    \(ylower = \(-2\)\), "\[IndentingNewLine]", 
    \(\(\(yupper = \(+2\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(xmin\  = \ Random[Real, {xlower, xupper}]\), "\[IndentingNewLine]", 
    \(ymin\  = \ Random[Real, {yupper, ylower}]\), "\[IndentingNewLine]", 
    \(\(\(zmin\  = \ f[xmin, ymin]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(n = 10000\), "\[IndentingNewLine]", 
    \(Do[{xr\  = \ 
          Random[Real, {xlower, xupper}], \[IndentingNewLine]yr\  = \ 
          Random[Real, {yupper, ylower}], \[IndentingNewLine]zr\  = \ 
          f[xr, yr], \[IndentingNewLine]If[
          zr < zmin, \[IndentingNewLine]{zmin = zr, xmin = xr, 
            ymin = yr}]}, {i, 1, n}]\), "\[IndentingNewLine]", 
    \(Print["\< \>" xmin, "\< \>" ymin, "\< \>" zmin]\)}], "Input"],

Cell[TextData[{
  "Once we have a global estimate of the minimum, we use these values to \
initialize a local procedure to refine our rough estimate. Essentially, \
global means quickly find a rough estimate, and local means take a rough \
estimate and make it better. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", you can use the built in function FindRoot to do this for you."
}], "Text"],

Cell[BoxData[
    \(FindRoot[{eq1, eq2}, {x, \(-0.72769\)}, {y, \(-0.0105025\)}]\)], "Input"],

Cell[BoxData[
    \(f[\(-0.7471\), 0.0000]\)], "Input"],

Cell["There is also the function FindMinimum:", "Text"],

Cell[BoxData[
    \(FindMinimum[f[x, y], {x, \(-0.72769\)}, {y, \(-0.0105025\)}]\)], "Input"],

Cell["\<\
Notice how the FindRoot will find a different root (the maximum), if we \
initialize with different numbers. Finding the global estimate is important \
so that we can initialize any local methods as accurately as possible.\
\>", "Text"],

Cell[BoxData[
    \(FindRoot[{eq1, eq2}, {x, 0}, {y, 0}]\)], "Input"],

Cell["\<\
Finding an accurate answer using a global method is not an efficient use of \
resources. Although it certainly will work, taking a large number of random \
points in an interval is not the best way to proceed!\
\>", "Text"],

Cell[BoxData[{
    \(\(xlower = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(xupper = \(+2\);\)\), "\[IndentingNewLine]", 
    \(\(ylower = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(\(yupper = \(+2\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(xmin\  = \ 
        Random[Real, {xlower, xupper}];\)\), "\[IndentingNewLine]", 
    \(\(ymin\  = \ 
        Random[Real, {yupper, ylower}];\)\), "\[IndentingNewLine]", 
    \(\(\(zmin\  = \ f[xmin, ymin];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(n = 100000;\)\), "\[IndentingNewLine]", 
    \(Do[{xr\  = \ 
          Random[Real, {xlower, xupper}], \[IndentingNewLine]yr\  = \ 
          Random[Real, {yupper, ylower}], \[IndentingNewLine]zr\  = \ 
          f[xr, yr], \[IndentingNewLine]If[
          zr < zmin, \[IndentingNewLine]{zmin = zr, xmin = xr, 
            ymin = yr}]}, {i, 1, n}]\), "\[IndentingNewLine]", 
    \(Print["\< \>" xmin, "\< \>" ymin, "\< \>" zmin]\)}], "Input"],

Cell["\<\
Here you can see how the random numbers fill space. I put two points in to \
begin to hold the plot at the proper width.\
\>", "Text"],

Cell[BoxData[{
    \(\(xlower = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(xupper = \(+2\);\)\), "\[IndentingNewLine]", 
    \(\(ylower = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(\(yupper = \(+2\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(pointlist\  = \ {{\(-2\), 0}, {2, 0}};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(n = 100;\)\), "\[IndentingNewLine]", 
    \(Do[{\[IndentingNewLine]xr\  = \ 
          Random[Real, {xlower, xupper}], \[IndentingNewLine]yr\  = \ 
          Random[Real, {yupper, ylower}], \[IndentingNewLine]pointlist\  = \ 
          Append[pointlist, {xr, yr}], \[IndentingNewLine]If[n > 20, 
          ListPlot[pointlist, Axes \[Rule] False, 
            PlotRange \[Rule] {\(-2\), 2}, 
            Frame \[Rule] True]]\[IndentingNewLine]}, {i, 1, n}]\)}], "Input"],

Cell[TextData[{
  "Here is an example of how random points fill a region. Pick an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " value, and then rerun to see how the points change. How large should ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " be to cover the region? n bigger than 10 000 will take a long time to \
run. What does it mean to cover a region? Notice that even for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " there are still gaps in the region being covered."
}], "Text"],

Cell[BoxData[{
    \(\(xlower = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(xupper = \(+2\);\)\), "\[IndentingNewLine]", 
    \(\(ylower = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(\(yupper = \(+2\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(pointlist\  = \ {};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(n = 10000;\)\), "\[IndentingNewLine]", 
    \(Do[{\[IndentingNewLine]xr\  = \ 
          Random[Real, {xlower, xupper}], \[IndentingNewLine]yr\  = \ 
          Random[Real, {yupper, ylower}], \[IndentingNewLine]pointlist\  = \ 
          Append[pointlist, {xr, yr}]\[IndentingNewLine]}, {i, 1, 
        n}]\), "\[IndentingNewLine]", 
    \(ListPlot[pointlist, Axes \[Rule] True, Ticks \[Rule] False]\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 59, 0, 59, "Section"],
Cell[1789, 54, 326, 7, 71, "Text"],
Cell[2118, 63, 463, 8, 110, "Input"],
Cell[2584, 73, 59, 1, 30, "Input"],
Cell[2646, 76, 109, 3, 33, "Text"],
Cell[2758, 81, 935, 17, 330, "Input"],
Cell[3696, 100, 407, 8, 90, "Text"],
Cell[4106, 110, 93, 1, 30, "Input"],
Cell[4202, 113, 55, 1, 30, "Input"],
Cell[4260, 116, 55, 0, 33, "Text"],
Cell[4318, 118, 93, 1, 30, "Input"],
Cell[4414, 121, 246, 4, 71, "Text"],
Cell[4663, 127, 69, 1, 30, "Input"],
Cell[4735, 130, 233, 4, 71, "Text"],
Cell[4971, 136, 986, 19, 330, "Input"],
Cell[5960, 157, 144, 3, 52, "Text"],
Cell[6107, 162, 848, 15, 310, "Input"],
Cell[6958, 179, 519, 12, 90, "Text"],
Cell[7480, 193, 773, 14, 290, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

