(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9538,        271]*)
(*NotebookOutlinePosition[     10180,        293]*)
(*  CellTagsIndexPosition[     10136,        289]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Difference Equations", "Section"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a package that can help you solve difference equations. It is called \
RSolve (for recurrence solve). It has to be loaded into the kernel."
}], "Text"],

Cell[BoxData[
    \(<< DiscreteMath`RSolve`\)], "Input"],

Cell[BoxData[
    \(req\  = \ y[n + 1]\  \[Equal] \ \ \(-y[n]\)/2 + 6\)], "Input"],

Cell[BoxData[{
    \(RSolve[req, y[n], n]\), "\[IndentingNewLine]", 
    \(TeXForm[
      2\^\(-n\)\ \((\(-4\)\ \((\(-1\))\)\^n + 
            2\^\(2 + n\) + \(\((\(-1\))\)\^n\) c)\)]\)}], "Input"],

Cell["The equilibrium solution can be found by solving:", "Text"],

Cell[BoxData[
    \(Solve[y \[Equal] \(-y\)/2 + 6, y]\)], "Input"],

Cell["\<\
If we actually have an initial condition, we can solve the initial value \
difference equation in a manner similar to differential equations.\
\>", "Text"],

Cell[BoxData[
    \(RSolve[{req, y[0] \[Equal] 2}, y[n], n]\)], "Input"],

Cell[BoxData[{
    \(ysol[
        n_] = \(-2\)\ \((\(-2\) + \((\(-\(1\/2\)\))\)\^n)\)\), "\
\[IndentingNewLine]", 
    \(data\  = \ Table[{n, ysol[n]}\ , {n, 0, 10}]\), "\[IndentingNewLine]", 
    \(ListPlot[data, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<y_n\>"}]\), "\[IndentingNewLine]", 
    \(ListPlot[data, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<y_n\>"}, 
      PlotJoined \[Rule] True]\)}], "Input"],

Cell[TextData[{
  "If ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can't solve it using RSolve, you can always generate the solution by \
iterating the difference equation. Note teh delayed assignments for y[0] and \
y[n]."
}], "Text"],

Cell[BoxData[{
    \(y[0]\  := \ 2\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \ \(-y[n - 1]\)/2 + 6\), "\[IndentingNewLine]", 
    \(data2\  = \ Table[{n, y[n]}, {n, 0, 10}]\), "\[IndentingNewLine]", 
    \(ListPlot[data2]\), "\[IndentingNewLine]", 
    \(TeXForm[data2]\), "\[IndentingNewLine]", 
    \(TeXForm[N[data2]]\)}], "Input"],

Cell[BoxData[
    \(Plot[{x, \(-x\)/2 + 6}, {x, 0, 6}]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Discrete Logistic Equation, Computational Thoughts, and Chaos\
\>", "Subsection"],

Cell[BoxData[
    \(Clear[y]\)], "Input"],

Cell[TextData[{
  "Before we go any further, we should note that we are not being very smart \
with our programming. By recursively defining things in the following manner, \
we are forcing ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to climb down the tree to calculute each y[n]. For large n this is a lot \
of tree climbing! The ShowTime package will show us this."
}], "Text"],

Cell[BoxData[
    \(<< Utilities`ShowTime`\)], "Input"],

Cell[BoxData[
    \(Clear[y, data2]\)], "Input"],

Cell[BoxData[{
    \(y[0]\  := \ 1/3. \), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \ 4\ y[n - 1]\ \((\ 
          1 - \ y[n - 1])\)\), "\[IndentingNewLine]", 
    \(data2\  = \ Table[{n, y[n]}, {n, 0, 20}]\), "\[IndentingNewLine]", 
    \(plot1\  = \ ListPlot[data2, PlotJoined \[Rule] True]\)}], "Input"],

Cell[BoxData[{
    \(y[0]\  := \ 1/3. \), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \(y[n] = \ 
        4\ y[n - 1]\ \((\ 1 - \ y[n - 1])\)\)\), "\[IndentingNewLine]", 
    \(data2\  = \ Table[{n, y[n]}, {n, 0, 20}]\), "\[IndentingNewLine]", 
    \(plot1\  = \ ListPlot[data2, PlotJoined \[Rule] True]\)}], "Input"],

Cell[CellGroupData[{

Cell["The Discrete Logistic Equation", "Subsubsection"],

Cell[BoxData[{
    \(Clear[data2, y]\), "\[IndentingNewLine]", 
    \(y[0]\  := \ 1/3. \), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \ 3.65\ y[n - 1]\ \((\ 
          1 - \ y[n - 1])\)\), "\[IndentingNewLine]", 
    \(\(data2\  = \ {{0, Evaluate[y[0]]}};\)\), "\[IndentingNewLine]", 
    \(Do[{y[n]\  = \ Evaluate[y[n]], \[IndentingNewLine]data2\  = 
          Append[data2, {n, y[n]}]}, {n, 1, 40}]\), "\[IndentingNewLine]", 
    \(plot1\  = \ ListPlot[data2, PlotJoined \[Rule] True]\)}], "Input"],

Cell[BoxData[{
    \(Clear[data2, y]\), "\[IndentingNewLine]", 
    \(y[0]\  := \ 1/3. \  + \ 0.001\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \ 3.65\ y[n - 1]\ \((\ 
          1 - \ y[n - 1])\)\), "\[IndentingNewLine]", 
    \(\(data2\  = \ {{0, Evaluate[y[0]]}};\)\), "\[IndentingNewLine]", 
    \(Do[{y[n]\  = \ Evaluate[y[n]], \[IndentingNewLine]data2\  = 
          Append[data2, {n, y[n]}]}, {n, 1, 40}]\), "\[IndentingNewLine]", 
    \(plot2\  = \ 
      ListPlot[data2, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {Hue[1], Dashing[{0.01, 0.01}]}]\)}], "Input"],

Cell[BoxData[
    \(Show[plot1, plot2, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<n\>", "\<y_n\>"}]\)], "Input"],

Cell[BoxData[{
    \(Clear[y]\), "\[IndentingNewLine]", 
    \(RSolve[{y[n + 1] \[Equal] 3.65\ y[n]\ \((\ 1 - \ y[n])\), 
        y[0] \[Equal] a}, y[n], n]\)}], "Input"],

Cell["Here is a numerical solution to a differential equation.", "Text"],

Cell[BoxData[{
    \(Clear[f]\), "\[IndentingNewLine]", 
    \(NDSolve[{\(f'\)[t] \[Equal] f[t] \((\ 2.65 - 3.65\ f[t])\), 
        f[0] \[Equal] 1/3}, f[t], {t, 0, 10}]\), "\[IndentingNewLine]", 
    \(f[t_]\  = \ f[t]\  /. \ f[t]\  \[Rule] \ Part[%, 1, 1, 2]\)}], "Input"],

Cell[BoxData[
    \(Plot[f[t], {t, 0, 4}, PlotRange \[Rule] {0.3, 0.9}, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<t\>", "\<y(t)\>"}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NonChaotic Regime", "Subsubsection"],

Cell[BoxData[{
    \(Clear[data2, y]\), "\[IndentingNewLine]", 
    \(y[0]\  := \ 1/10\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \ 2\ y[n - 1]\ \((\ 1 - \ y[n - 1])\)\  + \ 
        y[n - 1]\), "\[IndentingNewLine]", 
    \(\(data2\  = \ {{0, Evaluate[y[0]]}};\)\), "\[IndentingNewLine]", 
    \(Do[{y[n]\  = \ Evaluate[y[n]], \[IndentingNewLine]data2\  = 
          Append[data2, {n, y[n]}]}, {n, 1, 10}]\), "\[IndentingNewLine]", 
    \(N[data2]\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ListPlot[data2, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {Hue[1], Dashing[{0.01, 0.01}]}]\)}], "Input"],

Cell[BoxData[{
    \(Clear[f]\), "\[IndentingNewLine]", 
    \(DSolve[{\(f'\)[t] \[Equal] 2  f[t] \((\ 1 - \ f[t])\), 
        f[0] \[Equal] 1/10}, f[t], t]\)}], "Input"],

Cell[BoxData[{
    \(sol[
        t_]\  = \[ExponentialE]\^\(2\ t\)\/\(9 + \[ExponentialE]\^\(2\ \
t\)\)\), "\n", 
    \(plot2\  = \ 
      Plot[sol[t], {t, 0, 10}, PlotRange \[Rule] {0, 1.1}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y(t)\>"}]\)}], "Input"],

Cell[BoxData[
    \(Show[plot2, plot1, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<t\>", "\<\>"}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making the time delay smaller", "Subsubsection"],

Cell[BoxData[{
    \(Clear[data2, y]\), "\[IndentingNewLine]", 
    \(y[0]\  := \ 1/10\), "\[IndentingNewLine]", 
    \(y[n_]\  := \ \ 0.2\ y[n - 1]\ \((\ 1 - \ y[n - 1])\)\  + \ 
        y[n - 1]\), "\[IndentingNewLine]", 
    \(\(data2\  = \ {{0, Evaluate[y[0]]}};\)\), "\[IndentingNewLine]", 
    \(Do[{y[n]\  = \ Evaluate[y[n]], \[IndentingNewLine]data2\  = 
          Append[data2, {n, y[n]}]}, {n, 1, 40}]\), "\[IndentingNewLine]", 
    \(N[data2]\), "\[IndentingNewLine]", 
    \(plot1\  = \ 
      ListPlot[data2, PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {Hue[1], Dashing[{0.01, 0.01}]}]\)}], "Input"],

Cell[BoxData[{
    \(sol[
        t_]\  = \[ExponentialE]\^\(0.2\ t\)\/\(9 + \[ExponentialE]\^\(0.2\ \
t\)\)\), "\n", 
    \(plot2\  = \ 
      Plot[sol[t], {t, 0, 40}, PlotRange \[Rule] {0, 1.1}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<t\>", "\<y(t)\>"}]\), "\[IndentingNewLine]", 
    \(Show[plot2, plot1, Frame \[Rule] True, 
      FrameLabel \[Rule] {"\<t\>", "\<\>"}]\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 997}, {0, 721}},
WindowSize->{499, 563},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 39, 0, 59, "Section"],
Cell[1769, 54, 227, 5, 52, "Text"],
Cell[1999, 61, 56, 1, 30, "Input"],
Cell[2058, 64, 82, 1, 30, "Input"],
Cell[2143, 67, 197, 4, 51, "Input"],
Cell[2343, 73, 65, 0, 33, "Text"],
Cell[2411, 75, 66, 1, 30, "Input"],
Cell[2480, 78, 165, 3, 52, "Text"],
Cell[2648, 83, 72, 1, 30, "Input"],
Cell[2723, 86, 444, 9, 123, "Input"],
Cell[3170, 97, 249, 7, 52, "Text"],
Cell[3422, 106, 338, 6, 130, "Input"],
Cell[3763, 114, 67, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[3855, 119, 91, 2, 47, "Subsection"],
Cell[3949, 123, 41, 1, 30, "Input"],
Cell[3993, 126, 394, 8, 90, "Text"],
Cell[4390, 136, 55, 1, 30, "Input"],
Cell[4448, 139, 48, 1, 30, "Input"],
Cell[4499, 142, 307, 5, 90, "Input"],
Cell[4809, 149, 316, 5, 90, "Input"],

Cell[CellGroupData[{
Cell[5150, 158, 55, 0, 43, "Subsubsection"],
Cell[5208, 160, 500, 8, 150, "Input"],
Cell[5711, 170, 579, 10, 170, "Input"],
Cell[6293, 182, 119, 2, 30, "Input"],
Cell[6415, 186, 170, 3, 70, "Input"],
Cell[6588, 191, 72, 0, 33, "Text"],
Cell[6663, 193, 274, 4, 90, "Input"],
Cell[6940, 199, 153, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7130, 206, 42, 0, 43, "Subsubsection"],
Cell[7175, 208, 618, 11, 190, "Input"],
Cell[7796, 221, 170, 3, 70, "Input"],
Cell[7969, 226, 286, 7, 86, "Input"],
Cell[8258, 235, 116, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8411, 242, 54, 0, 43, "Subsubsection"],
Cell[8468, 244, 620, 11, 190, "Input"],
Cell[9091, 257, 407, 9, 106, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

